@@ -62,7 +62,7 @@ public:
 	{
 		input->setText(text);
 	}
-    void SelectAll()
+    void selectAll()
     {
         input->setSelection(0,(input->getText()).length());
     };
