@@ -13,8 +13,6 @@
 #include "TextLabel.h"
 #include "BrowseInputDialog.h"
 
-// Used to limit the dialog size when long file names are used
-#define MAX_MESSAGE_LENGTH 128
 
 extern FXString homedir;
 
@@ -141,7 +139,7 @@ long BrowseInputDialog::onCmdBrowsePath(FXObject* o,FXSelector s,void* p)
 	else
 		browse.setSelectMode(SELECT_FILE_MIXED);
 		
-	if(browse.execute())
+	if (browse.execute())
 	{
 		FXString path=browse.getFilename();
 		input->setText(path);
@@ -193,7 +191,7 @@ void BrowseInputDialog::setIcon(FXIcon* icon)
 	iconlabel->setIcon(icon);
 }
 
-void BrowseInputDialog::SelectAll()
+void BrowseInputDialog::selectAll()
 {
 	input->setSelection(0,(input->getText()).length());
 }
