@@ -36,7 +36,7 @@ public:
         ID_BROWSE_PATH=DialogBox::ID_LAST,
         ID_LAST
     };
-    BrowseInputDialog(FXWindow*,FXString,FXString,FXString,FXString label="",FXIcon *ic=NULL, FXuint browse=BROWSE_INPUT_FILE, FXbool option=FALSE, FXString=FXString::null);
+    BrowseInputDialog(FXWindow*,FXString,FXString,FXString,FXString label="",FXIcon *ic=NULL, FXuint browse=BROWSE_INPUT_FILE, FXbool option=false, FXString=FXString::null);
     virtual void create();
     virtual ~BrowseInputDialog();
     long onCmdKeyPress(FXObject*,FXSelector,void*);
@@ -46,7 +46,7 @@ public:
 	void setDirectory(const FXString&);
     FXString getText();
 	void setText(const FXString&);
-    void SelectAll();
+    void selectAll();
     void CursorEnd();
   	void setSelection(int, int);
 };
