@@ -87,13 +87,13 @@ CommandWindow::CommandWindow(FXApp* a, const FXString& name, FXString strcmd, in
 void CommandWindow::create()
 {
     // Initialize variables
-	killed=FALSE;
-	closed=FALSE;
+	killed=false;
+	closed=false;
 
     // Set text font
 	FXString fontspec;
 	fontspec=getApp()->reg().readStringEntry("SETTINGS","textfont","Helvetica,100,normal,regular");
-	if(!fontspec.empty())
+	if (!fontspec.empty())
 	{
     	FXFont* font=new FXFont(getApp(),fontspec);
 		font->create();
@@ -111,7 +111,7 @@ void CommandWindow::create()
 long CommandWindow::onCmdKillProcess(FXObject*,FXSelector,void*)
 {
 	kill((-1*pid), SIGTERM); // Kills the process group
-	killed=TRUE;
+	killed=true;
     return 0;
 }
 
@@ -273,13 +273,13 @@ long CommandWindow::onWatchProcess(FXObject*,FXSelector,void*)
 // Close dialog when clicking on the close button
 long CommandWindow::onCmdClose(FXObject*,FXSelector,void*)
 {
-    getApp()->stopModal(this,TRUE);
+    getApp()->stopModal(this,true);
     hide();
-	closed=TRUE;
+	closed=true;
 	
-	// If cancel was previously pressed, the object can delete itself
-	if (killed)
-		delete this;
+	// Object deletes itself
+	delete this;
+    
     return 1;
 }
 
