@@ -42,7 +42,7 @@ DialogBox::DialogBox(FXApp* a,const FXString& name,FXuint opts,int x,int y,int w
 // Close window & cancel out of dialog
 long DialogBox::onClose(FXObject*,FXSelector,void*)
 {
-    if(target && target->handle(this,FXSEL(SEL_CLOSE,message),NULL))
+    if (target && target->handle(this,FXSEL(SEL_CLOSE,message),NULL))
         return 1;
     handle(this,FXSEL(SEL_COMMAND,DialogBox::ID_CANCEL),NULL);
     return 1;
@@ -52,7 +52,7 @@ long DialogBox::onClose(FXObject*,FXSelector,void*)
 // Close dialog with an accept
 long DialogBox::onCmdAccept(FXObject*,FXSelector,void*)
 {
-    getApp()->stopModal(this,TRUE);
+    getApp()->stopModal(this,true);
     hide();
     return 1;
 }
@@ -61,7 +61,7 @@ long DialogBox::onCmdAccept(FXObject*,FXSelector,void*)
 // Close dialog with a cancel
 long DialogBox::onCmdCancel(FXObject*,FXSelector,void*)
 {
-    getApp()->stopModal(this,FALSE);
+    getApp()->stopModal(this,false);
     hide();
     return 1;
 }
@@ -102,7 +102,7 @@ void DialogBox::show(FXuint placement)
     getRoot()->getCursorPosition(x,y,state);
 
     // Place such that mouse in the middle
-    if(x<wx || y<wy || wx+ww<=x || wy+wh<=y)
+    if (x<wx || y<wy || wx+ww<=x || wy+wh<=y)
     {
 
         // Get root window size
@@ -110,23 +110,23 @@ void DialogBox::show(FXuint placement)
         rh=getRoot()->getHeight();
 
         // Move by the minimal amount
-        if(x<wx)
+        if (x<wx)
             wx=x-20;
-        else if(wx+ww<=x)
+        else if (wx+ww<=x)
             wx=x-ww+20;
-        if(y<wy)
+        if (y<wy)
             wy=y-20;
-        else if(wy+wh<=y)
+        else if (wy+wh<=y)
             wy=y-wh+20;
 
         // Adjust so dialog is fully visible
-        if(wx<0)
+        if (wx<0)
             wx=10;
-        if(wy<0)
+        if (wy<0)
             wy=10;
-        if(wx+ww>rw)
+        if (wx+ww>rw)
             wx=rw-ww-10;
-        if(wy+wh>rh)
+        if (wy+wh>rh)
             wy=rh-wh-10;
 
         move(wx,wy);
