@@ -208,26 +208,26 @@ public:
     // Create server-side resources
     virtual void create();
 
-    // Scan the directories and update the items if needed, or if force is TRUE
-    void scan(FXbool force=TRUE);
+    // Scan the directories and update the items if needed, or if force is true
+    void scan(FXbool force=true);
 
-    // Return TRUE if item is a directory
+    // Return true if item is a directory
     FXbool isItemDirectory(const TreeItem* item) const;
 
-    // Return TRUE if item is a file
+    // Return true if item is a file
     FXbool isItemFile(const TreeItem* item) const;
 
-    // Return TRUE if item is executable
+    // Return true if item is executable
     FXbool isItemExecutable(const TreeItem* item) const;
 
     // Collapse tree
-    virtual FXbool collapseTree(TreeItem* tree,FXbool notify=FALSE);
+    virtual FXbool collapseTree(TreeItem* tree,FXbool notify=false);
 
     // Expand tree
-    virtual FXbool expandTree(TreeItem* tree,FXbool notify=FALSE);
+    virtual FXbool expandTree(TreeItem* tree,FXbool notify=false);
 
     // Set current file
-    void setCurrentFile(const FXString& file,FXbool notify=FALSE);
+    void setCurrentFile(const FXString& file,FXbool notify=false);
 
     // Return current file
     FXString getCurrentFile() const;
@@ -265,13 +265,13 @@ public:
     // Change wildcard matching mode
     void setMatchMode(FXuint mode);
 
-    // Return TRUE if showing files as well as directories
+    // Return true if showing files as well as directories
     FXbool showFiles() const;
 
     // Show or hide normal files
     void showFiles(FXbool showing);
 
-    // Return TRUE if showing hidden files and directories
+    // Return true if showing hidden files and directories
     FXbool shownHiddenFiles() const;
 
     // Show or hide hidden files and directories
