@@ -44,7 +44,7 @@ protected:
 
 
 public:
-DirPanel(FXWindow *owner,FXComposite *p,FXColor listbackcolor=FXRGB(255,255,255),FXColor listforecolor=FXRGB(0,0,0), FXbool smoothscroll=TRUE,
+DirPanel(FXWindow *owner,FXComposite *p,FXColor listbackcolor=FXRGB(255,255,255),FXColor listforecolor=FXRGB(0,0,0), FXbool smoothscroll=true,
          FXuint opts=0,int x=0,int y=0,int w=0,int h=0);
     DirPanel()
     {}
@@ -72,6 +72,8 @@ DirPanel(FXWindow *owner,FXComposite *p,FXColor listbackcolor=FXRGB(255,255,255)
 		ID_XTERM,
 		ID_COPY_CLIPBOARD,
 		ID_CUT_CLIPBOARD,
+        ID_ADDCOPY_CLIPBOARD,
+        ID_ADDCUT_CLIPBOARD,
 		ID_PASTE_CLIPBOARD,
         ID_TOGGLE_TREE,
 		ID_TITLE,
@@ -152,7 +154,7 @@ public:
 	}
 
 	// Set current directory
-	void setDirectory(const FXString& pathname,FXbool notify=FALSE)
+	void setDirectory(const FXString& pathname,FXbool notify=false)
 	{
 		list->setDirectory(pathname,notify);
 	}
