@@ -80,12 +80,12 @@ FileSelector::FileSelector(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint op
 
  	// File list
  	FXuint options;
-	FXbool smoothscroll=getApp()->reg().readUnsignedEntry("SETTINGS","smooth_scroll",TRUE);	
+	FXbool smoothscroll=getApp()->reg().readUnsignedEntry("SETTINGS","smooth_scroll",true);	
 	if (smoothscroll)
 		options=_ICONLIST_MINI_ICONS|_ICONLIST_BROWSESELECT|LAYOUT_FILL_X|LAYOUT_FILL_Y;
 	else
 		options=_ICONLIST_MINI_ICONS|_ICONLIST_BROWSESELECT|LAYOUT_FILL_X|LAYOUT_FILL_Y|SCROLLERS_DONT_TRACK;
-	FXbool thumbnails=getApp()->reg().readUnsignedEntry("FILEDIALOG","thumbnails",FALSE);
+	FXbool thumbnails=getApp()->reg().readUnsignedEntry("FILEDIALOG","thumbnails",false);
     list=new FileList(this,cont,this,ID_FILELIST,thumbnails,options);
     
 	// Set list colors and columns size for detailed mode
@@ -102,7 +102,7 @@ FileSelector::FileSelector(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint op
 	
 	// Set file selector options
 	FXuint listmode=getApp()->reg().readUnsignedEntry("FILEDIALOG","listmode",_ICONLIST_MINI_ICONS);
-	FXbool hiddenfiles=getApp()->reg().readUnsignedEntry("FILEDIALOG","hiddenfiles",FALSE);
+	FXbool hiddenfiles=getApp()->reg().readUnsignedEntry("FILEDIALOG","hiddenfiles",false);
 	showHiddenFiles(hiddenfiles);
 	setFileBoxStyle	(listmode);
 
@@ -194,7 +194,7 @@ FileSelector::FileSelector(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint op
     pathlink = new PathLinker(pathframe,list,NULL,LAYOUT_FILL_X);
 
     readonly->hide();
-  	if(table)
+  	if (table)
 	{
  		FXString key;
 		FXHotKey hotkey;
@@ -235,7 +235,7 @@ FileSelector::FileSelector(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint op
 void FileSelector::create()
 {
 	// Display or hide path linker
-	FXbool show_pathlink=getApp()->reg().readUnsignedEntry("SETTINGS","show_pathlinker",TRUE);
+	FXbool show_pathlink=getApp()->reg().readUnsignedEntry("SETTINGS","show_pathlinker",true);
 	if (show_pathlink)
 	{
 		pathtext->hide();
@@ -256,16 +256,16 @@ void FileSelector::create()
 long FileSelector::onCmdItemDoubleClicked(FXObject*,FXSelector,void* ptr)
 {
     FXlong index=(FXlong)ptr;
-    if(index<0)
+    if (index<0)
         return 1;
 
     // If directory, open the directory
-    if(list->isItemDirectory(index))
+    if (list->isItemDirectory(index))
     {
 		FXString pathname=list->getItemPathname(index);
 
 		// Does not have access
-		if(!::isReadExecutable(pathname))
+		if (!::isReadExecutable(pathname))
 		{
 			MessageBox::error(this,BOX_OK,_("Error"),_(" Permission to: %s denied."), pathname.text());
 			return 0;
@@ -278,13 +278,13 @@ long FileSelector::onCmdItemDoubleClicked(FXObject*,FXSelector,void* ptr)
     }
 
     // Only return if we wanted a file
-    if((selectmode!=SELECT_FILE_DIRECTORY) && (selectmode!=SELECT_FILE_MIXED))
+    if ((selectmode!=SELECT_FILE_DIRECTORY) && (selectmode!=SELECT_FILE_MIXED))
     {
-        if(list->isItemFile(index))
+        if (list->isItemFile(index))
         {
             FXObject *tgt=accept->getTarget();
             FXSelector sel=accept->getSelector();
-            if(tgt)
+            if (tgt)
                 tgt->handle(accept,FXSEL(SEL_COMMAND,sel),(void*)1);
         }
     }
@@ -298,16 +298,16 @@ long FileSelector::onCmdItemClicked(FXObject*,FXSelector,void* ptr)
 	if (single_click != SINGLE_CLICK_NONE)
 	{		
 		FXlong index=(FXlong)ptr;
-		if(index<0)
+		if (index<0)
 			return 1;
 
 		// In detailed mode, avoid single click when cursor is not over the first column
 		int x, y;
 		FXuint state;
 		getCursorPosition(x,y,state);
-		FXbool allow=TRUE;
+		FXbool allow=true;
 		if (!(list->getListStyle()&(_ICONLIST_BIG_ICONS|_ICONLIST_MINI_ICONS)) && (x-list->getXPosition())>list->getHeaderSize(0))
-			allow=FALSE;
+			allow=false;
 
 		// Single click with control or shift
 		if (state&(CONTROLMASK|SHIFTMASK))
@@ -317,12 +317,12 @@ long FileSelector::onCmdItemClicked(FXObject*,FXSelector,void* ptr)
 		else
 		{
 			// If directory, open the directory
-			if(single_click != SINGLE_CLICK_NONE && list->isItemDirectory(index) && allow)
+			if (single_click != SINGLE_CLICK_NONE && list->isItemDirectory(index) && allow)
 			{
 				FXString pathname=list->getItemPathname(index);
 
 				// Does not have access
-				if(!::isReadExecutable(pathname))
+				if (!::isReadExecutable(pathname))
 				{
 					MessageBox::error(this,BOX_OK,_("Error"),_(" Permission to: %s denied."), pathname.text());
 					return 0;
@@ -332,11 +332,11 @@ long FileSelector::onCmdItemClicked(FXObject*,FXSelector,void* ptr)
 				pathtext->setText(pathname);
 				return 1;
 			}
-			else if((single_click==SINGLE_CLICK_DIR_FILE) && list->isItemFile(index) && allow)
+			else if ((single_click==SINGLE_CLICK_DIR_FILE) && list->isItemFile(index) && allow)
 			{
 				FXObject *tgt=accept->getTarget();
 				FXSelector sel=accept->getSelector();
-				if(tgt)
+				if (tgt)
 					tgt->handle(accept,FXSEL(SEL_COMMAND,sel),(void*)1);
 			}
 		}
@@ -350,35 +350,35 @@ long FileSelector::onCmdItemSelected(FXObject*,FXSelector,void* ptr)
     FXlong index=(FXlong)ptr;
     FXString text,file;
 
-    if(selectmode==SELECT_FILE_MULTIPLE)
+    if (selectmode==SELECT_FILE_MULTIPLE)
     {
-        for(int i=0; i<list->getNumItems(); i++)
+        for (int i=0; i<list->getNumItems(); i++)
         {
-            if(list->isItemFile(i) && list->isItemSelected(i))
+            if (list->isItemFile(i) && list->isItemSelected(i))
             {
-                if(!text.empty())
+                if (!text.empty())
                     text+=' ';
                 text+=::quote(list->getItemFilename(i));
             }
         }
         filename->setText(text);
     }
-    else if(selectmode==SELECT_FILE_MULTIPLE_ALL)
+    else if (selectmode==SELECT_FILE_MULTIPLE_ALL)
     {
-        for(int i=0; i<list->getNumItems(); i++)
+        for (int i=0; i<list->getNumItems(); i++)
         {
-            if(list->isItemSelected(i) && list->getItemFilename(i)!="..")
+            if (list->isItemSelected(i) && list->getItemFilename(i)!="..")
             {
-                if(!text.empty())
+                if (!text.empty())
                     text+=' ';
                 text+=::quote(list->getItemFilename(i));
             }
         }
         filename->setText(text);
     }
-    else if(selectmode==SELECT_FILE_DIRECTORY)
+    else if (selectmode==SELECT_FILE_DIRECTORY)
     {
-        if(list->isItemDirectory(index))
+        if (list->isItemDirectory(index))
         {
 			if (list->getItemFilename(index)!="..")
 			{
@@ -388,7 +388,7 @@ long FileSelector::onCmdItemSelected(FXObject*,FXSelector,void* ptr)
         }
     }
     // Mode added to select both directories and files
-	else if(selectmode==SELECT_FILE_MIXED)
+	else if (selectmode==SELECT_FILE_MIXED)
     {
 		if (list->getItemFilename(index)!="..")
 		{
@@ -398,7 +398,7 @@ long FileSelector::onCmdItemSelected(FXObject*,FXSelector,void* ptr)
     }
     else
     {
-        if(list->isItemFile(index))
+        if (list->isItemFile(index))
         {
             text=list->getItemFilename(index);
             filename->setText(text);
@@ -412,26 +412,26 @@ long FileSelector::onCmdItemSelected(FXObject*,FXSelector,void* ptr)
 long FileSelector::onCmdItemDeselected(FXObject*,FXSelector,void*)
 {
     FXString text,file;
-    if(selectmode==SELECT_FILE_MULTIPLE)
+    if (selectmode==SELECT_FILE_MULTIPLE)
     {
-        for(int i=0; i<list->getNumItems(); i++)
+        for (int i=0; i<list->getNumItems(); i++)
         {
-            if(list->isItemFile(i) && list->isItemSelected(i))
+            if (list->isItemFile(i) && list->isItemSelected(i))
             {
-                if(!text.empty())
+                if (!text.empty())
                     text+=' ';
                 text+=::quote(list->getItemFilename(i));
             }
         }
         filename->setText(text);
     }
-    else if(selectmode==SELECT_FILE_MULTIPLE_ALL)
+    else if (selectmode==SELECT_FILE_MULTIPLE_ALL)
     {
-        for(int i=0; i<list->getNumItems(); i++)
+        for (int i=0; i<list->getNumItems(); i++)
         {
-            if(list->isItemSelected(i) && list->getItemFilename(i)!="..")
+            if (list->isItemSelected(i) && list->getItemFilename(i)!="..")
             {
-                if(!text.empty())
+                if (!text.empty())
                     text+=' ';
                 text+=::quote(list->getItemFilename(i));
             }
@@ -452,22 +452,22 @@ long FileSelector::onCmdAccept(FXObject*,FXSelector,void*)
     FXString path=getFilename();
 	
 	// If filename is empty, we get the current directory
-	if(path.empty())
+	if (path.empty())
 	{
 		path=list->getDirectory();
         filename->setText(path);
 	}
 	
     // Only do something if a selection was made
-    if(!path.empty())
+    if (!path.empty())
     {
         // Is directory?
-        if(::isDirectory(path))
+        if (::isDirectory(path))
         {
             // In directory mode:- we got our answer!
-            if(selectmode==SELECT_FILE_DIRECTORY || selectmode==SELECT_FILE_MULTIPLE_ALL || selectmode==SELECT_FILE_MIXED)
+            if (selectmode==SELECT_FILE_DIRECTORY || selectmode==SELECT_FILE_MULTIPLE_ALL || selectmode==SELECT_FILE_MIXED)
             {
-                if(tgt)
+                if (tgt)
                    tgt->handle(accept,FXSEL(SEL_COMMAND,sel),(void*)1);
                 return 1;
             }
@@ -484,36 +484,36 @@ long FileSelector::onCmdAccept(FXObject*,FXSelector,void*)
         FXString dir=FXPath::directory(path);
 
         // In file mode, directory part of path should exist
-        if(::isDirectory(dir))
+        if (::isDirectory(dir))
         {
 
             // In any mode, existing directory part is good enough
-            if(selectmode==SELECT_FILE_ANY)
+            if (selectmode==SELECT_FILE_ANY)
             {
-                if(tgt)
+                if (tgt)
                     tgt->handle(accept,FXSEL(SEL_COMMAND,sel),(void*)1);
                 return 1;
             }
 
             // In existing mode, the whole filename must exist and be a file
-            else if(selectmode==SELECT_FILE_EXISTING)
+            else if (selectmode==SELECT_FILE_EXISTING)
             {
-                if(::isFile(path))
+                if (::isFile(path))
                 {
-                    if(tgt)
+                    if (tgt)
                         tgt->handle(accept,FXSEL(SEL_COMMAND,sel),(void*)1);
                     return 1;
                 }
             }
 
             // In multiple mode, return if all selected files exist
-            else if(selectmode==SELECT_FILE_MULTIPLE)
+            else if (selectmode==SELECT_FILE_MULTIPLE)
             {
-                for(int i=0; i<list->getNumItems(); i++)
+                for (int i=0; i<list->getNumItems(); i++)
                 {
-                    if(list->isItemSelected(i) && list->isItemFile(i))
+                    if (list->isItemSelected(i) && list->isItemFile(i))
                     {
-                        if(tgt)
+                        if (tgt)
                             tgt->handle(accept,FXSEL(SEL_COMMAND,sel),(void*)1);
                         return 1;
                     }
@@ -523,11 +523,11 @@ long FileSelector::onCmdAccept(FXObject*,FXSelector,void*)
             // Multiple files and/or directories
             else
             {
-                for(int i=0; i<list->getNumItems(); i++)
+                for (int i=0; i<list->getNumItems(); i++)
                 {
-                    if(list->isItemSelected(i) && list->getItemFilename(i)!="..")
+                    if (list->isItemSelected(i) && list->getItemFilename(i)!="..")
                     {
-                        if(tgt)
+                        if (tgt)
                             tgt->handle(accept,FXSEL(SEL_COMMAND,sel),(void*)1);
                         return 1;
                     }
@@ -545,7 +545,7 @@ long FileSelector::onCmdAccept(FXObject*,FXSelector,void*)
         pathtext->setText(list->getDirectory());
 
         // Put the tail end back for further editing
-        if(ISPATHSEP(path[dir.length()]))
+        if (ISPATHSEP(path[dir.length()]))
             path.erase(0,dir.length()+1);
         else
             path.erase(0,dir.length());
@@ -572,7 +572,7 @@ long FileSelector::onCmdDirUp(FXObject*,FXSelector,void*)
 // Can we still go up
 long FileSelector::onUpdDirUp(FXObject* sender,FXSelector,void*)
 {
-    if(FXPath::isTopDirectory(list->getDirectory()))
+    if (FXPath::isTopDirectory(list->getDirectory()))
         sender->handle(this,FXSEL(SEL_COMMAND,ID_DISABLE),NULL);
     else
         sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),NULL);
@@ -601,7 +601,7 @@ long  FileSelector::onCmdDirBack(FXObject*,FXSelector s,void* p)
 	forwardhist->insertFirstItem(list->getDirectory());
 	
 	// Go to to the previous directory
-	list->setDirectory(pathname,FALSE);
+	list->setDirectory(pathname,false);
    	pathlink->setPath(list->getDirectory());
    	pathtext->setText(list->getDirectory());
 
@@ -649,7 +649,7 @@ long  FileSelector::onCmdDirForward(FXObject*,FXSelector s,void* p)
 	backhist->insertFirstItem(list->getDirectory());
 	
 	// Go to to the previous directory
-	list->setDirectory(pathname,FALSE);
+	list->setDirectory(pathname,false);
    	pathlink->setPath(list->getDirectory());
    	pathtext->setText(list->getDirectory());
 
@@ -696,7 +696,7 @@ long  FileSelector::onCmdDirBackHist(FXObject *sender,FXSelector sel,void* ptr)
 		
 		// Get string items
 		item=backhist->getFirst();
-		for(int i=0; i<=num-1; i++)
+		for (int i=0; i<=num-1; i++)
 		{
 			if (item)
 			{
@@ -734,7 +734,7 @@ long  FileSelector::onCmdDirBackHist(FXObject *sender,FXSelector sel,void* ptr)
 	
 			// Go to to the selected directory
 			pathname=dirs[pos];
-			list->setDirectory(pathname,FALSE);
+			list->setDirectory(pathname,false);
    			pathlink->setPath(list->getDirectory());
    			pathtext->setText(list->getDirectory());
 		}
@@ -784,7 +784,7 @@ long  FileSelector::onCmdDirForwardHist(FXObject *sender,FXSelector sel,void* pt
 		
 		// Get string items
 		item=forwardhist->getFirst();
-		for(int i=0; i<=num-1; i++)
+		for (int i=0; i<=num-1; i++)
 		{
 			if (item)
 			{
@@ -821,7 +821,7 @@ long  FileSelector::onCmdDirForwardHist(FXObject *sender,FXSelector sel,void* pt
 	
 			// Go to to the selected directory
 			pathname=dirs[pos];
-			list->setDirectory(pathname,FALSE);
+			list->setDirectory(pathname,false);
    			pathlink->setPath(list->getDirectory());
    			pathtext->setText(list->getDirectory());
 		}
@@ -868,15 +868,15 @@ long FileSelector::onCmdNewDir(FXObject*,FXSelector,void*)
 
     FXString dirname="";	
     FXString dirpath=list->getDirectory();
-    if(dirpath!=ROOTDIR)
+    if (dirpath!=ROOTDIR)
         dirpath+=PATHSEPSTRING;
 
     InputDialog* dialog=new InputDialog(this,dirname,_("Create new folder..."),_("New Folder"));
     dialog->CursorEnd();
-    if(dialog->execute(PLACEMENT_CURSOR))
+    if (dialog->execute(PLACEMENT_CURSOR))
     {
 		dirname=dirpath+dialog->getText();
-        if(dirname!=dirpath)
+        if (dirname!=dirpath)
         {
 			// Create the new dir according to the current umask
 			int mask;
@@ -912,18 +912,18 @@ long FileSelector::onCmdNewFile(FXObject*,FXSelector,void*)
     list->setFocus();
 
     FXString pathname=list->getDirectory();
-    if(pathname!=ROOTDIR)
+    if (pathname!=ROOTDIR)
         pathname+=PATHSEPSTRING;
 
     InputDialog* dialog=new InputDialog(this,filename,_("Create new file..."),_("New File"));
     dialog->CursorEnd();
     
 	// Accept was pressed
-    if(dialog->execute(PLACEMENT_CURSOR))
+    if (dialog->execute(PLACEMENT_CURSOR))
     {	
 		filename=pathname+dialog->getText();
 		FILE *file;
-		if(filename!=pathname)
+		if (filename!=pathname)
         {
 			// Test some error conditions
 			if (::exists(filename))
@@ -982,7 +982,7 @@ FXString FileSelector::patternFromText(const FXString& pattern)
     int beg,end;
     end=pattern.rfind(')');         // Search from the end so we can allow ( ) in the pattern name itself
     beg=pattern.rfind('(',end-1);
-    if(0<=beg && beg<end)
+    if (0<=beg && beg<end)
         return pattern.mid(beg+1,end-beg-1);
     return pattern;
 }
@@ -995,16 +995,16 @@ FXString FileSelector::extensionFromPattern(const FXString& pattern)
 {
     int beg,end,c;
     beg=0;
-    if(pattern[beg]=='*')
+    if (pattern[beg]=='*')
     {
         beg++;
-        if(pattern[beg]=='.')
+        if (pattern[beg]=='.')
         {
             beg++;
             end=beg;
             while((c=pattern[end])!='\0' && c!=',' && c!='|')
             {
-                if(c=='*' || c=='?' || c=='[' || c==']' || c=='^' || c=='!')
+                if (c=='*' || c=='?' || c=='[' || c==']' || c=='^' || c=='!')
                     return FXString::null;
                 end++;
             }
@@ -1020,13 +1020,13 @@ long FileSelector::onCmdFilter(FXObject*,FXSelector,void* ptr)
 {
     FXString pat=patternFromText((char*)ptr);
     list->setPattern(pat);
-    if(selectmode==SELECT_FILE_ANY)
+    if (selectmode==SELECT_FILE_ANY)
     {
         FXString ext=extensionFromPattern(pat);
-        if(!ext.empty())
+        if (!ext.empty())
         {
             FXString name=FXPath::stripExtension(filename->getText());
-            if(!name.empty())
+            if (!name.empty())
                 filename->setText(name+"."+ext);
         }
     }
@@ -1042,7 +1042,7 @@ void FileSelector::setDirectory(const FXString& path)
    	pathlink->setPath(list->getDirectory());
    	pathtext->setText(list->getDirectory());
 
-    if(selectmode!=SELECT_FILE_ANY)
+    if (selectmode!=SELECT_FILE_ANY)
         filename->setText(FXString::null);
 }
 
@@ -1069,25 +1069,25 @@ void FileSelector::setFilename(const FXString& path)
 FXString FileSelector::getFilename() const
 {
     register int i;
-    if(selectmode==SELECT_FILE_MULTIPLE_ALL)
+    if (selectmode==SELECT_FILE_MULTIPLE_ALL)
     {
-        for(i=0; i<list->getNumItems(); i++)
+        for (i=0; i<list->getNumItems(); i++)
         {
-            if(list->isItemSelected(i) && list->getItemFilename(i)!="..")
+            if (list->isItemSelected(i) && list->getItemFilename(i)!="..")
                 return FXPath::absolute(list->getDirectory(),list->getItemFilename(i));
         }
     }
-    else if(selectmode==SELECT_FILE_MULTIPLE)
+    else if (selectmode==SELECT_FILE_MULTIPLE)
     {
-        for(i=0; i<list->getNumItems(); i++)
+        for (i=0; i<list->getNumItems(); i++)
         {
-            if(list->isItemSelected(i) && list->isItemFile(i))
+            if (list->isItemSelected(i) && list->isItemFile(i))
                 return FXPath::absolute(list->getDirectory(),list->getItemFilename(i));
         }
     }
     else
     {
-        if(!filename->getText().empty())
+        if (!filename->getText().empty())
             return FXPath::absolute(list->getDirectory(),filename->getText());
     }
     return FXString::null;
@@ -1099,21 +1099,21 @@ FXString* FileSelector::getFilenames() const
 {
     register FXString *files=NULL;
     register int i,n;
-    if(list->getNumItems())
+    if (list->getNumItems())
     {
-        if(selectmode==SELECT_FILE_MULTIPLE_ALL)
+        if (selectmode==SELECT_FILE_MULTIPLE_ALL)
         {
-            for(i=n=0; i<list->getNumItems(); i++)
+            for (i=n=0; i<list->getNumItems(); i++)
             {
-                if(list->isItemSelected(i) && list->getItemFilename(i)!="..")
+                if (list->isItemSelected(i) && list->getItemFilename(i)!="..")
                     n++;
             }
-            if(n)
+            if (n)
             {
                 files=new FXString [n+1];
-                for(i=n=0; i<list->getNumItems(); i++)
+                for (i=n=0; i<list->getNumItems(); i++)
                 {
-                    if(list->isItemSelected(i) && list->getItemFilename(i)!="..")
+                    if (list->isItemSelected(i) && list->getItemFilename(i)!="..")
                         files[n++]=list->getItemPathname(i);
                 }
                 files[n]=FXString::null;
@@ -1121,17 +1121,17 @@ FXString* FileSelector::getFilenames() const
         }
         else
         {
-            for(i=n=0; i<list->getNumItems(); i++)
+            for (i=n=0; i<list->getNumItems(); i++)
             {
-                if(list->isItemSelected(i) && list->isItemFile(i))
+                if (list->isItemSelected(i) && list->isItemFile(i))
                     n++;
             }
-            if(n)
+            if (n)
             {
                 files=new FXString [n+1];
-                for(i=n=0; i<list->getNumItems(); i++)
+                for (i=n=0; i<list->getNumItems(); i++)
                 {
-                    if(list->isItemSelected(i) && list->isItemFile(i))
+                    if (list->isItemSelected(i) && list->isItemFile(i))
                         files[n++]=list->getItemPathname(i);
                 }
                 files[n]=FXString::null;
@@ -1146,7 +1146,7 @@ FXString* FileSelector::getFilenames() const
 void FileSelector::setPatternList(const char **ptrns)
 {
     filefilter->clearItems();
-    if(ptrns)
+    if (ptrns)
     {
         while(ptrns[0] && ptrns[1])
         {
@@ -1154,7 +1154,7 @@ void FileSelector::setPatternList(const char **ptrns)
             ptrns+=2;
         }
     }
-    if(!filefilter->getNumItems())
+    if (!filefilter->getNumItems())
         filefilter->appendItem(allfiles);
     setCurrentPattern(0);
 }
@@ -1166,9 +1166,9 @@ void FileSelector::setPatternList(const FXString& patterns)
     FXString pat;
     int i;
     filefilter->clearItems();
-    for(i=0; !(pat=patterns.section('\n',i)).empty(); i++)
+    for (i=0; !(pat=patterns.section('\n',i)).empty(); i++)
         filefilter->appendItem(pat);
-    if(!filefilter->getNumItems())
+    if (!filefilter->getNumItems())
         filefilter->appendItem(allfiles);
     setCurrentPattern(0);
 }
@@ -1179,9 +1179,9 @@ FXString FileSelector::getPatternList() const
 {
     FXString pat;
     int i;
-    for(i=0; i<filefilter->getNumItems(); i++)
+    for (i=0; i<filefilter->getNumItems(); i++)
     {
-        if(!pat.empty())
+        if (!pat.empty())
             pat+='\n';
         pat+=filefilter->getItemText(i);
     }
@@ -1227,7 +1227,7 @@ void FileSelector::setPatternText(int patno,const FXString& text)
 	if ((FXuint)patno >= (FXuint)filefilter->getNumItems())
         fxerror("%s::setPatternText: index out of range.\n",getClassName());
     filefilter->setItemText(patno,text);
-    if(patno==filefilter->getCurrentItem())
+    if (patno==filefilter->getCurrentItem())
         setPattern(patternFromText(text));
 }
 
@@ -1276,23 +1276,23 @@ void FileSelector::setSelectMode(FXuint mode)
     switch(mode)
     {
     case SELECT_FILE_EXISTING:
-        list->showOnlyDirectories(FALSE);
+        list->showOnlyDirectories(false);
         list->setListStyle((list->getListStyle()&~FILELISTMASK)|_ICONLIST_BROWSESELECT);
         break;
     case SELECT_FILE_MULTIPLE:
     case SELECT_FILE_MULTIPLE_ALL:
-        list->showOnlyDirectories(FALSE);
+        list->showOnlyDirectories(false);
         list->setListStyle((list->getListStyle()&~FILELISTMASK)|_ICONLIST_EXTENDEDSELECT);
         break;
     case SELECT_FILE_DIRECTORY:
-        list->showOnlyDirectories(TRUE);
+        list->showOnlyDirectories(true);
         list->setListStyle((list->getListStyle()&~FILELISTMASK)|_ICONLIST_BROWSESELECT);
         break;
     case SELECT_FILE_MIXED:
         list->setListStyle((list->getListStyle()&~FILELISTMASK)|_ICONLIST_BROWSESELECT);
         break;
     default:
-        list->showOnlyDirectories(FALSE);
+        list->showOnlyDirectories(false);
         list->setListStyle((list->getListStyle()&~FILELISTMASK)|_ICONLIST_BROWSESELECT);
         break;
     }
@@ -1307,7 +1307,7 @@ void FileSelector::showReadOnly(FXbool show)
 }
 
 
-// Return TRUE if readonly is shown
+// Return true if readonly is shown
 FXbool FileSelector::shownReadOnly() const
 {
     return readonly->shown();
@@ -1329,14 +1329,14 @@ FXbool FileSelector::getReadOnly() const
 }
 
 
-// Return TRUE if hidden files are displayed
+// Return true if hidden files are displayed
 FXbool FileSelector::shownHiddenFiles() const
 {
 	return list->shownHiddenFiles();
 }
 
 
-// Return TRUE if thumbnails are displayed
+// Return true if thumbnails are displayed
 FXbool FileSelector::shownThumbnails() const
 {
 	return list->shownThumbnails();
@@ -1375,7 +1375,7 @@ FileSelector::~FileSelector()
 	getApp()->reg().write();
 	
 	FXAccelTable *table=getShell()->getAccelTable();
-	if(table)
+	if (table)
 	{
     	table->removeAccel(MKUINT(KEY_BackSpace,0));
     	table->removeAccel(MKUINT(KEY_h,CONTROLMASK));
@@ -1435,10 +1435,10 @@ long FileSelector::onCmdPopupMenu(FXObject* o,FXSelector s,void* p)
 	new FXMenuCheck(&menu,_("Re&verse order"),list,FileList::ID_SORT_REVERSE);
 
 	menu.create();
-	allowPopupScroll=TRUE;  // Allow keyboard scrolling
+	allowPopupScroll=true;  // Allow keyboard scrolling
 	menu.popup(NULL,x,y);
 	getApp()->runModalWhileShown(&menu);
-	allowPopupScroll=FALSE;
+	allowPopupScroll=false;
 	return 1;
 }
 
@@ -1610,7 +1610,7 @@ void FileDialog::showReadOnly(FXbool show)
 }
 
 
-// Return TRUE if readonly is shown
+// Return true if readonly is shown
 FXbool FileDialog::shownReadOnly() const
 {
     return list->shownReadOnly();
@@ -1632,14 +1632,14 @@ FXbool FileDialog::getReadOnly() const
 }
 
 
-// Return TRUE if thumbnails are displayed
+// Return true if thumbnails are displayed
 FXbool FileDialog::shownThumbnails() const
 {
 	return list->shownThumbnails();
 }
 
 
-// Return TRUE if hidden files are displayed
+// Return true if hidden files are displayed
 FXbool FileDialog::shownHiddenFiles() const
 {
 	return list->shownHiddenFiles();
@@ -1681,10 +1681,10 @@ FXString FileDialog::getOpenFilename(FXWindow* owner,const FXString& caption,con
     opendialog.setPatternList(patterns);
     opendialog.setCurrentPattern(initial);
     opendialog.setFilename(path);
-    if(opendialog.execute())
+    if (opendialog.execute())
     {
         filename=opendialog.getFilename();
-        if(::isFile(filename))
+        if (::isFile(filename))
             return filename;
     }
     return FXString::null;
@@ -1699,7 +1699,7 @@ FXString FileDialog::getSaveFilename(FXWindow* owner,const FXString& caption,con
     savedialog.setPatternList(patterns);
     savedialog.setCurrentPattern(initial);
     savedialog.setFilename(path);
-    if(savedialog.execute())
+    if (savedialog.execute())
         return savedialog.getFilename();
     return FXString::null;
 }
@@ -1713,7 +1713,7 @@ FXString* FileDialog::getOpenFilenames(FXWindow* owner,const FXString& caption,c
     opendialog.setPatternList(patterns);
     opendialog.setCurrentPattern(initial);
     opendialog.setFilename(path);
-    if(opendialog.execute())
+    if (opendialog.execute())
         return opendialog.getFilenames();
     return NULL;
 }
@@ -1726,10 +1726,10 @@ FXString FileDialog::getOpenDirectory(FXWindow* owner,const FXString& caption,co
     FXString dirname;
     dirdialog.setSelectMode(SELECT_FILE_DIRECTORY);
     dirdialog.setFilename(path);
-    if(dirdialog.execute())
+    if (dirdialog.execute())
     {
         dirname=dirdialog.getFilename();
-        if(::isDirectory(dirname))
+        if (::isDirectory(dirname))
             return dirname;
     }
     return FXString::null;
