@@ -150,11 +150,13 @@ protected:
     FileList()
 	{}
     virtual IconItem *createItem(const FXString& text,FXIcon *big,FXIcon* mini,void* ptr);
-    void updateItems(FXbool);
+    FXbool updateItems(FXbool);
     void listItems(FXbool);
+
 private:
     FileList(const FileList&);
     FileList &operator=(const FileList&);
+
 public:
 	long onCmdRefresh(FXObject*,FXSelector,void*);
     long onCmdRefreshTimer(FXObject*,FXSelector,void*);
@@ -216,7 +218,7 @@ public:
 	long onUpdRefreshTimer(FXObject* sender,FXSelector,void*);
 public:
     static int compare(const IconItem* pa,const IconItem* pb,
-                       bool igncase,  bool asc, bool mixdir, int jmp);
+                       FXbool igncase,  FXbool asc, FXbool mixdir, FXuint jmp);
 	static int ascending(const IconItem* pa,const IconItem* pb);
 	static int descending(const IconItem* pa,const IconItem* pb);
 	static int ascendingCase(const IconItem* pa,const IconItem* pb);
@@ -305,13 +307,13 @@ public:
 public:
 
     // Construct a file list
-    FileList(FXWindow* focuswin, FXComposite *p,FXObject* tgt=NULL,FXSelector sel=0,FXbool showthumbs=FALSE,FXuint opts=0,int x=0,int y=0,int w=0,int h=0);
+    FileList(FXWindow* focuswin, FXComposite *p,FXObject* tgt=NULL,FXSelector sel=0,FXbool showthumbs=false,FXuint opts=0,int x=0,int y=0,int w=0,int h=0);
 
     // Create server-side resources
     virtual void create();
 
-	// Scan the current directory and update the items if needed, or if force is TRUE
-	void scan(FXbool force=TRUE);
+	// Scan the current directory and update the items if needed, or if force is true
+	void scan(FXbool force=true);
 
     // Set current file
     void setCurrentFile(const FXString& file);
@@ -320,7 +322,7 @@ public:
     FXString getCurrentFile() const;
 
     // Set current directory
-	void setDirectory(const FXString& path,const FXbool histupdate=TRUE,FXString prevpath= "");
+	void setDirectory(const FXString& path,const FXbool histupdate=true,FXString prevpath= "");
 
 	// Return current directory
     FXString getDirectory() const
@@ -337,16 +339,16 @@ public:
         return pattern;
     }
 
-    // Return TRUE if item is a directory
+    // Return true if item is a directory
     FXbool isItemDirectory(int index) const;
 
-    // Return TRUE if item is a file
+    // Return true if item is a file
     FXbool isItemFile(int index) const;
 
-    // Return TRUE if item is executable
+    // Return true if item is executable
     FXbool isItemExecutable(int index) const;
 
-    // Return TRUE if item is a symbolic link
+    // Return true if item is a symbolic link
     FXbool isItemLink(int index) const;
 
 	// Get number of selected items
@@ -418,19 +420,19 @@ public:
     // Change wildcard matching mode
     void setMatchMode(FXuint mode);
 
-    // Return TRUE if showing hidden files
+    // Return true if showing hidden files
     FXbool shownHiddenFiles() const;
 
     // Show or hide hidden files
     void showHiddenFiles(FXbool showing);
 
-    // Return TRUE if displaying thumbnails
+    // Return true if displaying thumbnails
     FXbool shownThumbnails() const;
 
     // Display or not thumbnails
     void showThumbnails(FXbool display);
 
-    // Return TRUE if showing directories only
+    // Return true if showing directories only
     FXbool showOnlyDirectories() const;
 
     // Show directories only
