@@ -1,5 +1,8 @@
 #ifndef FILEPANEL_H
 #define FILEPANEL_H
+
+#include <map>
+
 #include "Properties.h"
 #include "FileList.h"
 #include "PathLinker.h"
@@ -15,6 +18,12 @@ enum
 	CUT_CLIPBOARD,
 };
 
+
+
+// Typedef for the map between program string identifiers and integer indexes
+typedef std::map<FXString, int> progsmap;
+
+
 class FilePanel : public FXVerticalFrame
 {
     FXDECLARE(FilePanel)
@@ -27,6 +36,7 @@ protected:
 	FXPacker* 		statusbar;
     FXLabel*		statuslabel;
     FXLabel*		filterlabel;
+	FXHorizontalSeparator* panelsep;
 	FXLabel* 		activeicon;
     FXString 		name;
 	FXbool			ctrlkey;
@@ -49,6 +59,7 @@ protected:
 	HistInputDialog* filterdialog;
 	BrowseInputDialog* operationdialogsingle;
 	BrowseInputDialog* operationdialogmultiple;
+	BrowseInputDialog* comparedialog;
 	FXbool			paste;
 	FXbool 			ctrl;			    // Flag to select the right click control menu
 	FXbool			shiftf10;           // Flag indicating that Shift-F10 was pressed 
@@ -56,12 +67,13 @@ protected:
 	FXbool			isactive;
 	FXbool			stopListRefresh;
 	FXColor			attenclr;
+	progsmap		progs;				// Map between program string identifiers and integer indexes
 	
 public:
 
 FilePanel(FXWindow *owner, const char*,FXComposite*, DirPanel*, FXuint name_size=200, FXuint size_size=60, FXuint type_size=100, FXuint ext_size=100, 
-	      FXuint modd_size=150, FXuint user_size=50, FXuint grou_size=50, FXuint attr_size=100, FXuint deldate_size=150, FXuint origpath_size=200, FXbool showthumbs=FALSE,
-          FXColor listbackcolor=FXRGB(255,255,255), FXColor listforecolor=FXRGB(0,0,0), FXColor attentioncolor=FXRGB(255,0,0), FXbool smoothscroll=TRUE,
+	      FXuint modd_size=150, FXuint user_size=50, FXuint grou_size=50, FXuint attr_size=100, FXuint deldate_size=150, FXuint origpath_size=200, FXbool showthumbs=false,
+          FXColor listbackcolor=FXRGB(255,255,255), FXColor listforecolor=FXRGB(0,0,0), FXColor attentioncolor=FXRGB(255,0,0), FXbool smoothscroll=true,
  		  FXuint opts=0,int x=0,int y=0,int w=0,int h=0);
     FilePanel()
     {}
@@ -69,7 +81,7 @@ FilePanel(FXWindow *owner, const char*,FXComposite*, DirPanel*, FXuint name_size
     ~FilePanel();
 
     void setActive();
-    void setInactive(FXbool=TRUE);
+    void setInactive(FXbool=true);
 
     void Next(FilePanel*);
 	void updateLocation();
@@ -85,6 +97,7 @@ FilePanel(FXWindow *owner, const char*,FXComposite*, DirPanel*, FXuint name_size
         ID_DIRECTORY_UP,
         ID_VIEW,
         ID_EDIT,
+		ID_COMPARE,
         ID_PROPERTIES,
         ID_FILE_COPY,
 		ID_FILE_CUT,
@@ -111,6 +124,8 @@ FilePanel(FXWindow *owner, const char*,FXComposite*, DirPanel*, FXuint name_size
 		ID_GO_TRASH,
         ID_COPY_CLIPBOARD,
         ID_CUT_CLIPBOARD,
+        ID_ADDCOPY_CLIPBOARD,
+        ID_ADDCUT_CLIPBOARD,
         ID_PASTE_CLIPBOARD,
         ID_OPEN,
         ID_OPEN_WITH,
@@ -151,6 +166,7 @@ public:
     long onCmdGoHome(FXObject*,FXSelector,void*);
 	long onCmdGoTrash(FXObject*,FXSelector,void*);
     long onCmdEdit(FXObject*,FXSelector,void*);
+    long onCmdCompare(FXObject*,FXSelector,void*);
     long onCmdProperties(FXObject*,FXSelector,void*);
     long onCmdFileMan(FXObject*,FXSelector,void*);
     long onCmdFileTrash(FXObject*,FXSelector,void*);
@@ -183,6 +199,7 @@ public:
 	long onUpdOpen(FXObject*,FXSelector,void*);
 	long onUpdAddToArch(FXObject*,FXSelector,void*);
 	long onUpdSelMult(FXObject*,FXSelector,void*);
+	long onUpdCompare(FXObject*,FXSelector,void*);
 	long onUpdFileDelete(FXObject*,FXSelector,void*);
 	long onUpdFileTrash(FXObject*,FXSelector,void*);
 	long onUpdFileRestore(FXObject*,FXSelector,void*);
@@ -252,7 +269,7 @@ public:
 	}
 	
 	// Set current directory
-	void setDirectory(FXString pathname, FXbool notify=FALSE)
+	void setDirectory(FXString pathname, FXbool notify=false)
 	{
 		list->setDirectory(pathname,notify);
 	}
@@ -523,5 +540,18 @@ public:
 	{
 		return list->forwardhist->getItemAtPos(pos);
 	}
+	
+	// Show panel separator
+	void showPanelSeparator(void)
+	{
+		panelsep->setSeparatorStyle(SEPARATOR_GROOVE);
+	}
+	
+	// Hide panel separator
+	void hidePanelSeparator(void)
+	{
+		panelsep->setSeparatorStyle(SEPARATOR_NONE);
+	}
+	
 };
 #endif
