@@ -58,7 +58,7 @@ public:
         ID_BROWSE_PATH=DialogBox::ID_LAST,
         ID_LAST
     };
-    HistInputDialog(FXWindow*,FXString,FXString,FXString,FXString label="",FXIcon *ic=NULL, FXuint browse=HIST_INPUT_FILE, FXbool option=FALSE, FXString=FXString::null);
+    HistInputDialog(FXWindow*,FXString,FXString,FXString,FXString label="",FXIcon *ic=NULL, FXuint browse=HIST_INPUT_FILE, FXbool option=false, FXString=FXString::null);
     virtual void create();
     long onCmdKeyPress(FXObject*,FXSelector,void*);
 	long onCmdBrowsePath(FXObject*,FXSelector,void*);
@@ -71,7 +71,7 @@ public:
 		input->setText(text);
 	}
     void CursorEnd();
-    void SelectAll();
+    void selectAll();
     void appendItem(char *str)
     {
         input->appendItem(str);
