@@ -45,7 +45,7 @@ extern FXbool relative_resize;
 FXIMPLEMENT(IconItem,FXObject,NULL,0)
 
 
-// Check if integer is odd (return TRUE) or even (return FALSE)
+// Check if integer is odd (return true) or even (return false)
 inline FXbool IconItem::isOdd(int i) const
 {
 	return (FXbool)(i & 0x1);
@@ -628,7 +628,7 @@ FXDEFMAP(IconList) IconListMap[]=
     FXMAPFUNC(SEL_COMMAND,IconList::ID_SHOW_BIG_ICONS,IconList::onCmdShowBigIcons),
     FXMAPFUNC(SEL_COMMAND,IconList::ID_ARRANGE_BY_ROWS,IconList::onCmdArrangeByRows),
     FXMAPFUNC(SEL_COMMAND,IconList::ID_ARRANGE_BY_COLUMNS,IconList::onCmdArrangeByColumns),
-    FXMAPFUNC(SEL_COMMAND,IconList::ID_SELECT_ALL,IconList::onCmdSelectAll),
+    FXMAPFUNC(SEL_COMMAND,IconList::ID_SELECT_ALL,IconList::onCmdselectAll),
     FXMAPFUNC(SEL_COMMAND,IconList::ID_DESELECT_ALL,IconList::onCmdDeselectAll),
     FXMAPFUNC(SEL_COMMAND,IconList::ID_SELECT_INVERSE,IconList::onCmdSelectInverse),
     FXMAPFUNC(SEL_COMMAND,FXWindow::ID_SETVALUE,IconList::onCmdSetValue),
@@ -654,7 +654,7 @@ IconList::IconList(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint opts,int x
     flags|=FLAG_ENABLED;
 
 	// Headers look slightly different depending on the control theme 
-	FXbool use_clearlooks=getApp()->reg().readUnsignedEntry("SETTINGS","use_clearlooks",TRUE);
+	FXbool use_clearlooks=getApp()->reg().readUnsignedEntry("SETTINGS","use_clearlooks",true);
 	if (use_clearlooks)
     	header=new FXHeader(this,this,IconList::ID_HEADER_CHANGE,HEADER_TRACKING|HEADER_BUTTON|HEADER_RESIZE|FRAME_RAISED);
 	else
@@ -697,12 +697,12 @@ IconList::IconList(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint opts,int x
     currenty=0;
     grabx=0;
     graby=0;
-    state=FALSE;
+    state=false;
 	numsortheader=0;
 	count=0;
-	ignorecase=TRUE;
-	initheaderpct=TRUE;
-	allowTooltip=TRUE;
+	ignorecase=true;
+	initheaderpct=true;
+	allowTooltip=true;
 }
 
 
@@ -727,13 +727,13 @@ long IconList::onConfigure(FXObject*,FXSelector,void*)
 		if (initheaderpct && getNumHeaders()==9)  // Search list, is it really necessary???
 		{
 			headerpct[8]=(double)getHeaderSize(8)/(double)width;
-			initheaderpct=FALSE;
+			initheaderpct=false;
 		}
 		if (initheaderpct && getNumHeaders()==10)
 		{
 			headerpct[8]=(double)getHeaderSize(8)/(double)width;
 			headerpct[9]=(double)getHeaderSize(9)/(double)width;
-			initheaderpct=FALSE;
+			initheaderpct=false;
 		}
 		int newhsize;
 		for (int hi=0; hi<getNumHeaders(); hi++)
@@ -789,7 +789,7 @@ bool IconList::canFocus() const
 void IconList::setFocus()
 {
     FXScrollArea::setFocus();
-    setDefault(TRUE);
+    setDefault(true);
 }
 
 
@@ -846,7 +846,7 @@ void IconList::recompute()
     }
 
     // Automatically size item spacing
-    //if (autosize)
+    // if (autosize)
     if (options&_ICONLIST_AUTOSIZE)
     	itemSpace=FXMAX(itemWidth,1);
     else
@@ -1306,7 +1306,7 @@ FXbool IconList::isItemEnabled(int index) const
 // True if item (partially) visible
 FXbool IconList::isItemVisible(int index) const
 {
-    register FXbool vis=FALSE;
+    register FXbool vis=false;
     register int x,y,hh;
     if (index<0 || items.no()<=index)
     {
@@ -1327,14 +1327,14 @@ FXbool IconList::isItemVisible(int index) const
             y=pos_y+itemHeight*(index%nrows);
         }
         if (0<x+itemSpace && x<viewport_w && 0<y+itemHeight && y<viewport_h)
-        	vis=TRUE;
+        	vis=true;
     }
     else
     {
         hh=header->getDefaultHeight();
         y=pos_y+hh+index*itemHeight;
         if (hh<y+itemHeight && y<viewport_h)
-        	vis=TRUE;
+        	vis=true;
     }
     return vis;
 }
@@ -1417,9 +1417,9 @@ int IconList::getItemAt(int x,int y)
 	x-=pos_x;
 	
 	// Update the allowTooltip variable
-	allowTooltip=TRUE;
+	allowTooltip=true;
 	if (options&_ICONLIST_STANDARD)
-		allowTooltip=FALSE;
+		allowTooltip=false;
 
 	if (!(options&_ICONLIST_STANDARD) && (single_click==SINGLE_CLICK_DIR_FILE) )
 	{
@@ -1428,23 +1428,23 @@ int IconList::getItemAt(int x,int y)
 			setDefaultCursor(getApp()->getDefaultCursor(DEF_HAND_CURSOR));
 	}
 		
-	if(options&(_ICONLIST_BIG_ICONS|_ICONLIST_MINI_ICONS))
+	if (options&(_ICONLIST_BIG_ICONS|_ICONLIST_MINI_ICONS))
 	{		
 		c=x/itemSpace;
 		r=y/itemHeight;
 		
-		if(c<0 || c>=ncols || r<0 || r>=nrows)
+		if (c<0 || c>=ncols || r<0 || r>=nrows)
 			return -1;
 
 		index=(options&_ICONLIST_COLUMNS) ? ncols*r+c : nrows*c+r;
 
-		if(index<0 || index>=items.no())
+		if (index<0 || index>=items.no())
 			return -1;
 
 		ix=itemSpace*c;
 		iy=itemHeight*r;
 
-		if(items[index]->hitItem(this,x-ix,y-iy)==0)
+		if (items[index]->hitItem(this,x-ix,y-iy)==0)
 			return -1;
 	}
 	else
@@ -1452,7 +1452,7 @@ int IconList::getItemAt(int x,int y)
 		// Update the allowTooltip variable
 		if (x==0 || x>header->getItemSize(0))
 		{
-			allowTooltip=FALSE;		
+			allowTooltip=false;		
 			
 			// Don't change cursor while the wait cursor is displayed
 			if (::setWaitCursor(getApp(),QUERY_CURSOR)==0)
@@ -1464,7 +1464,7 @@ int IconList::getItemAt(int x,int y)
 		index=y/itemHeight;
 		
 		
-		if(index<0 || index>=items.no())
+		if (index<0 || index>=items.no())
 			return -1;
 	}
 	return index;
@@ -1686,11 +1686,11 @@ FXbool IconList::enableItem(int index)
     }
     if (!items[index]->isEnabled())
     {
-        items[index]->setEnabled(TRUE);
+        items[index]->setEnabled(true);
         updateItem(index);
-        return TRUE;
+        return true;
     }
-    return FALSE;
+    return false;
 }
 
 
@@ -1703,11 +1703,11 @@ FXbool IconList::disableItem(int index)
     }
     if (items[index]->isEnabled())
     {
-        items[index]->setEnabled(FALSE);
+        items[index]->setEnabled(false);
         updateItem(index);
-        return TRUE;
+        return true;
     }
-    return FALSE;
+    return false;
 }
 
 
@@ -1727,7 +1727,7 @@ FXbool IconList::selectItem(int index,FXbool notify)
             killSelection(notify);
         case _ICONLIST_EXTENDEDSELECT:
         case _ICONLIST_MULTIPLESELECT:
-            items[index]->setSelected(TRUE);
+            items[index]->setSelected(true);
             updateItem(index);
             if (notify && target)
             {
@@ -1735,9 +1735,9 @@ FXbool IconList::selectItem(int index,FXbool notify)
             }
             break;
         }
-        return TRUE;
+        return true;
     }
-    return FALSE;
+    return false;
 }
 
 
@@ -1755,7 +1755,7 @@ FXbool IconList::deselectItem(int index,FXbool notify)
         case _ICONLIST_EXTENDEDSELECT:
         case _ICONLIST_MULTIPLESELECT:
         case _ICONLIST_SINGLESELECT:
-            items[index]->setSelected(FALSE);
+            items[index]->setSelected(false);
             updateItem(index);
             if (notify && target)
             {
@@ -1763,9 +1763,9 @@ FXbool IconList::deselectItem(int index,FXbool notify)
             }
             break;
         }
-        return TRUE;
+        return true;
     }
-    return FALSE;
+    return false;
 }
 
 
@@ -1782,7 +1782,7 @@ FXbool IconList::toggleItem(int index,FXbool notify)
         if (!items[index]->isSelected())
         {
             killSelection(notify);
-            items[index]->setSelected(TRUE);
+            items[index]->setSelected(true);
             updateItem(index);
             if (notify && target)
             {
@@ -1794,7 +1794,7 @@ FXbool IconList::toggleItem(int index,FXbool notify)
         if (!items[index]->isSelected())
         {
             killSelection(notify);
-            items[index]->setSelected(TRUE);
+            items[index]->setSelected(true);
             updateItem(index);
             if (notify && target)
             {
@@ -1803,7 +1803,7 @@ FXbool IconList::toggleItem(int index,FXbool notify)
         }
         else
         {
-            items[index]->setSelected(FALSE);
+            items[index]->setSelected(false);
             updateItem(index);
             if (notify && target)
             {
@@ -1815,7 +1815,7 @@ FXbool IconList::toggleItem(int index,FXbool notify)
     case _ICONLIST_MULTIPLESELECT:
         if (!items[index]->isSelected())
         {
-            items[index]->setSelected(TRUE);
+            items[index]->setSelected(true);
             updateItem(index);
             if (notify && target)
             {
@@ -1824,7 +1824,7 @@ FXbool IconList::toggleItem(int index,FXbool notify)
         }
         else
         {
-            items[index]->setSelected(FALSE);
+            items[index]->setSelected(false);
             updateItem(index);
             if (notify && target)
             {
@@ -1833,7 +1833,7 @@ FXbool IconList::toggleItem(int index,FXbool notify)
         }
         break;
     }
-    return TRUE;
+    return true;
 }
 
 
@@ -1841,7 +1841,7 @@ FXbool IconList::toggleItem(int index,FXbool notify)
 FXbool IconList::selectInRectangle(int x,int y,int w,int h,FXbool notify)
 {
     register int r,c,index;
-    register FXbool changed=FALSE;
+    register FXbool changed=false;
     if (options&(_ICONLIST_BIG_ICONS|_ICONLIST_MINI_ICONS))
     {
         for (r=0; r<nrows; r++)
@@ -1876,7 +1876,7 @@ FXbool IconList::selectInRectangle(int x,int y,int w,int h,FXbool notify)
 // Extend selection
 FXbool IconList::extendSelection(int index,FXbool notify)
 {
-    register FXbool changes=FALSE;
+    register FXbool changes=false;
     int i1,i2,i3,i;
     if (0<=index && 0<=anchor && 0<=extent)
     {
@@ -1918,9 +1918,9 @@ FXbool IconList::extendSelection(int index,FXbool notify)
             {
                 if (!items[i]->isSelected())
                 {
-                    items[i]->setSelected(TRUE);
+                    items[i]->setSelected(true);
                     updateItem(i);
-                    changes=TRUE;
+                    changes=true;
                     if (notify && target)
                     {
                         target->tryHandle(this,FXSEL(SEL_SELECTED,message),(void*)(FXival)i);
@@ -1934,9 +1934,9 @@ FXbool IconList::extendSelection(int index,FXbool notify)
             {
                 if (items[i]->isSelected())
                 {
-                    items[i]->setSelected(FALSE);
+                    items[i]->setSelected(false);
                     updateItem(i);
-                    changes=TRUE;
+                    changes=true;
                     if (notify && target)
                     {
                         target->tryHandle(this,FXSEL(SEL_DESELECTED,message),(void*)(FXival)i);
@@ -1955,9 +1955,9 @@ FXbool IconList::extendSelection(int index,FXbool notify)
             {
                 if (!items[i]->isSelected())
                 {
-                    items[i]->setSelected(TRUE);
+                    items[i]->setSelected(true);
                     updateItem(i);
-                    changes=TRUE;
+                    changes=true;
                     if (notify && target)
                     {
                         target->tryHandle(this,FXSEL(SEL_SELECTED,message),(void*)(FXival)i);
@@ -1971,9 +1971,9 @@ FXbool IconList::extendSelection(int index,FXbool notify)
             {
                 if (items[i]->isSelected())
                 {
-                    items[i]->setSelected(FALSE);
+                    items[i]->setSelected(false);
                     updateItem(i);
-                    changes=TRUE;
+                    changes=true;
                     if (notify && target)
                     {
                         target->tryHandle(this,FXSEL(SEL_DESELECTED,message),(void*)(FXival)i);
@@ -1990,15 +1990,15 @@ FXbool IconList::extendSelection(int index,FXbool notify)
 // Kill selection
 FXbool IconList::killSelection(FXbool notify)
 {
-    register FXbool changes=FALSE;
+    register FXbool changes=false;
     register int i;
     for (i=0; i<items.no(); i++)
     {
         if (items[i]->isSelected())
         {
-            items[i]->setSelected(FALSE);
+            items[i]->setSelected(false);
             updateItem(i);
-            changes=TRUE;
+            changes=true;
             if (notify && target)
             {
                 target->tryHandle(this,FXSEL(SEL_DESELECTED,message),(void*)(FXival)i);
@@ -2189,7 +2189,7 @@ long IconList::onQueryTip(FXObject* sender,FXSelector sel,void* ptr)
 			sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&string);
 			return 1;
 		}
-		else if(!allowTooltip)
+		else if (!allowTooltip)
 		{
 			// Don't change cursor while the wait cursor is displayed
 			if (::setWaitCursor(getApp(),QUERY_CURSOR)==0)
@@ -2221,7 +2221,7 @@ long IconList::onFocusIn(FXObject* sender,FXSelector sel,void* ptr)
     if (0<=current)
     {
         FXASSERT(current<items.no());
-        items[current]->setFocus(TRUE);
+        items[current]->setFocus(true);
         updateItem(current);
     }
     return 1;
@@ -2235,7 +2235,7 @@ long IconList::onFocusOut(FXObject* sender,FXSelector sel,void* ptr)
     if (0<=current)
     {
         FXASSERT(current<items.no());
-        items[current]->setFocus(FALSE);
+        items[current]->setFocus(false);
         updateItem(current);
     }
     return 1;
@@ -2486,11 +2486,11 @@ long IconList::onUpdShowMiniIcons(FXObject* sender,FXSelector,void*)
 
 
 // Select all items
-long IconList::onCmdSelectAll(FXObject*,FXSelector,void*)
+long IconList::onCmdselectAll(FXObject*,FXSelector,void*)
 {
-    for (int i=0; i<items.no(); i++) selectItem(i,TRUE);
+    for (int i=0; i<items.no(); i++) selectItem(i,true);
 	if (!(options&_ICONLIST_SEARCH) && !(options&_ICONLIST_STANDARD))
-		deselectItem(0,TRUE);
+		deselectItem(0,true);
     return 1;
 }
 
@@ -2498,7 +2498,7 @@ long IconList::onCmdSelectAll(FXObject*,FXSelector,void*)
 // Deselect all items
 long IconList::onCmdDeselectAll(FXObject*,FXSelector,void*)
 {
-    for (int i=0; i<items.no(); i++) deselectItem(i,TRUE);
+    for (int i=0; i<items.no(); i++) deselectItem(i,true);
     return 1;
 }
 
@@ -2506,9 +2506,9 @@ long IconList::onCmdDeselectAll(FXObject*,FXSelector,void*)
 // Select inverse of current selection
 long IconList::onCmdSelectInverse(FXObject*,FXSelector,void*)
 {
-    for (int i=0; i<items.no(); i++) toggleItem(i,TRUE);
+    for (int i=0; i<items.no(); i++) toggleItem(i,true);
 	if (!(options&_ICONLIST_SEARCH) && !(options&_ICONLIST_STANDARD))
-		deselectItem(0,TRUE);
+		deselectItem(0,true);
    return 1;
 }
 
@@ -2589,8 +2589,9 @@ int IconList::descendingCase(const IconItem* a,const IconItem* b)
 void IconList::sortItems()
 {
     register IconItem *v,*c=0;
-    register FXbool exch=FALSE;
+    register FXbool exch=false;
     register int i,j,h;
+
     if (sortfunc)
     {
         if (0<=current)
@@ -2607,7 +2608,7 @@ void IconList::sortItems()
                 while (j>h && sortfunc(items[j-h-1],v)>0)
                 {
                     items[j-1]=items[j-h-1];
-                    exch=TRUE;
+                    exch=true;
                     j-=h;
                 }
                 items[j-1]=v;
@@ -2647,7 +2648,7 @@ void IconList::setCurrentItem(int index,FXbool notify)
             // No visible change if it doen't have the focus
             if (hasFocus())
             {
-                items[current]->setFocus(FALSE);
+                items[current]->setFocus(false);
                 updateItem(current);
             }
         }
@@ -2661,7 +2662,7 @@ void IconList::setCurrentItem(int index,FXbool notify)
             // No visible change if it doen't have the focus
             if (hasFocus())
             {
-                items[current]->setFocus(TRUE);
+                items[current]->setFocus(true);
                 updateItem(current);
             }
         }
@@ -2786,7 +2787,7 @@ hop:
         lookup=FXString::null;
         if (0<=index && index<items.no())
         {
-            setCurrentItem(index,TRUE);
+            setCurrentItem(index,true);
             makeItemVisible(index);
             if (items[index]->isEnabled())
             {
@@ -2796,16 +2797,16 @@ hop:
                     {
                         if (0<=anchor)
                         {
-                            selectItem(anchor,TRUE);
-                            extendSelection(index,TRUE);
+                            selectItem(anchor,true);
+                            extendSelection(index,true);
                         }
                         else
-                            selectItem(index,TRUE);
+                            selectItem(index,true);
                     }
                     else if (!(event->state&CONTROLMASK))
                     {
-                        killSelection(TRUE);
-                        selectItem(index,TRUE);
+                        killSelection(true);
+                        selectItem(index,true);
                         setAnchorItem(index);
                     }
                 }
@@ -2821,6 +2822,7 @@ hop:
     case KEY_space:
     case KEY_KP_Space:
         lookup=FXString::null;
+
         if (0<=current && items[current]->isEnabled())
         {
             switch (options&SELECT_MASK)
@@ -2830,28 +2832,29 @@ hop:
                 {
                     if (0<=anchor)
                     {
-                        selectItem(anchor,TRUE);
-                        extendSelection(current,TRUE);
+                        selectItem(anchor,true);
+                        extendSelection(current,true);
                     }
                     else
-                        selectItem(current,TRUE);
+                        selectItem(current,true);
                 }
                 else if (event->state&CONTROLMASK)
-                    toggleItem(current,TRUE);
+                    toggleItem(current,true);
                 else
                 {
-                    killSelection(TRUE);
-                    selectItem(current,TRUE);
+                    killSelection(true);
+                    selectItem(current,true);
                 }
                 break;
             case _ICONLIST_MULTIPLESELECT:
             case _ICONLIST_SINGLESELECT:
-                toggleItem(current,TRUE);
+                toggleItem(current,true);
                 break;
             }
             setAnchorItem(current);
         }
-        handle(this,FXSEL(SEL_CLICKED,0),(void*)(FXival)current);
+		// Commented out to select the current item with space
+        //handle(this,FXSEL(SEL_CLICKED,0),(void*)(FXival)current);
         if (0<=current && items[current]->isEnabled())
             handle(this,FXSEL(SEL_COMMAND,0),(void*)(FXival)current);
         return 1;
@@ -2880,14 +2883,14 @@ hop:
 		
         if (0<=index)
         {
-            setCurrentItem(index,TRUE);
+            setCurrentItem(index,true);
             makeItemVisible(index);
             if (items[index]->isEnabled())
             {
                 if ((options&SELECT_MASK)==_ICONLIST_EXTENDEDSELECT)
                 {
-                    killSelection(TRUE);
-                    selectItem(index,TRUE);
+                    killSelection(true);
+                    selectItem(index,true);
                 }
                 setAnchorItem(index);
             }
@@ -2950,7 +2953,7 @@ long IconList::onAutoScroll(FXObject* sender,FXSelector sel,void* ptr)
         currenty=event->win_y-pos_y;
         FXMINMAX(nlx,nrx,anchorx,currentx);
         FXMINMAX(nty,nby,anchory,currenty);
-        lassoChanged(pos_x+olx,pos_y+oty,orx-olx+1,oby-oty+1,pos_x+nlx,pos_y+nty,nrx-nlx+1,nby-nty+1,TRUE);
+        lassoChanged(pos_x+olx,pos_y+oty,orx-olx+1,oby-oty+1,pos_x+nlx,pos_y+nty,nrx-nlx+1,nby-nty+1,true);
 
         // Force repaint on this window
         repaint();
@@ -2998,7 +3001,7 @@ long IconList::onMotion(FXObject*,FXSelector,void* ptr)
     // Lasso selection mode
     if (flags&FLAG_LASSO)
     {
-        if (startAutoScroll(event,FALSE))
+        if (startAutoScroll(event,false))
         	return 1;
 
         // Hide lasso
@@ -3011,7 +3014,7 @@ long IconList::onMotion(FXObject*,FXSelector,void* ptr)
         currenty=event->win_y-pos_y;
         FXMINMAX(nlx,nrx,anchorx,currentx);
         FXMINMAX(nty,nby,anchory,currenty);
-        lassoChanged(pos_x+olx,pos_y+oty,orx-olx+1,oby-oty+1,pos_x+nlx,pos_y+nty,nrx-nlx+1,nby-nty+1,TRUE);
+        lassoChanged(pos_x+olx,pos_y+oty,orx-olx+1,oby-oty+1,pos_x+nlx,pos_y+nty,nrx-nlx+1,nby-nty+1,true);
 
         // Force repaint on this window
         repaint();
@@ -3024,7 +3027,7 @@ long IconList::onMotion(FXObject*,FXSelector,void* ptr)
     // Drag and drop mode
     if (flags&FLAG_DODRAG)
     {
-        if (startAutoScroll(event,TRUE))
+        if (startAutoScroll(event,true))
         	return 1;
         handle(this,FXSEL(SEL_DRAGGED,0),ptr);
         return 1;
@@ -3083,7 +3086,7 @@ long IconList::onLeftBtnPress(FXObject*,FXSelector,void* ptr)
                 // Kill selection
                 if (!(event->state&(SHIFTMASK|CONTROLMASK)))
                 {
-                    killSelection(TRUE);
+                    killSelection(true);
                 }
 
                 anchorx=currentx=event->win_x-pos_x;
@@ -3098,7 +3101,7 @@ long IconList::onLeftBtnPress(FXObject*,FXSelector,void* ptr)
         code=hitItem(index,event->win_x,event->win_y);
 
         // Change current item
-        setCurrentItem(index,TRUE);
+        setCurrentItem(index,true);
 
         // Change item selection
         state=items[index]->isSelected();
@@ -3110,28 +3113,28 @@ long IconList::onLeftBtnPress(FXObject*,FXSelector,void* ptr)
                 if (0<=anchor)
                 {
                     if (items[anchor]->isEnabled())
-                    	selectItem(anchor,TRUE);
-                    extendSelection(index,TRUE);
+                    	selectItem(anchor,true);
+                    extendSelection(index,true);
                 }
                 else
                 {
                     if (items[index]->isEnabled())
-                    	selectItem(index,TRUE);
+                    	selectItem(index,true);
                     setAnchorItem(index);
                 }
             }
             else if (event->state&CONTROLMASK)
             {
                 if (items[index]->isEnabled() && !state)
-                	selectItem(index,TRUE);
+                	selectItem(index,true);
                 setAnchorItem(index);
             }
             else
             {
                 if (items[index]->isEnabled() && !state)
                 {
-                    killSelection(TRUE);
-                    selectItem(index,TRUE);
+                    killSelection(true);
+                    selectItem(index,true);
                 }
                 setAnchorItem(index);
             }
@@ -3139,7 +3142,7 @@ long IconList::onLeftBtnPress(FXObject*,FXSelector,void* ptr)
         case _ICONLIST_MULTIPLESELECT:
         case _ICONLIST_SINGLESELECT:
             if (items[index]->isEnabled() && !state)
-            	selectItem(index,TRUE);
+            	selectItem(index,true);
             break;
         }
 
@@ -3197,14 +3200,14 @@ long IconList::onLeftBtnRelease(FXObject*,FXSelector,void* ptr)
                 {
                     if (event->state&CONTROLMASK)
                     {
-                        if (state) deselectItem(current,TRUE);
+                        if (state) deselectItem(current,true);
                     }
                     else if (!(event->state&SHIFTMASK))
                     {
                         if (state)
                         {
-                            killSelection(TRUE);
-                            selectItem(current,TRUE);
+                            killSelection(true);
+                            selectItem(current,true);
                         }
                     }
                 }
@@ -3214,7 +3217,7 @@ long IconList::onLeftBtnRelease(FXObject*,FXSelector,void* ptr)
                 if (0<=current && items[current]->isEnabled())
                 {
                     if (state)
-                    	deselectItem(current,TRUE);
+                    	deselectItem(current,true);
                 }
                 break;
             }
@@ -3441,7 +3444,7 @@ int IconList::insertItem(int index,IconItem* item,FXbool notify)
     {
         if (hasFocus())
         {
-            items[current]->setFocus(TRUE);
+            items[current]->setFocus(true);
         }
         if ((options&SELECT_MASK)==_ICONLIST_BROWSESELECT && items[current]->isEnabled())
         {
@@ -3639,7 +3642,7 @@ IconItem* IconList::extractItem(int index,FXbool notify)
     {
         if (hasFocus())
         {
-            items[current]->setFocus(TRUE);
+            items[current]->setFocus(true);
         }
         if ((options&SELECT_MASK)==_ICONLIST_BROWSESELECT && items[current]->isEnabled())
         {
@@ -3702,7 +3705,7 @@ void IconList::removeItem(int index,FXbool notify)
     {
         if (hasFocus())
         {
-            items[current]->setFocus(TRUE);
+            items[current]->setFocus(true);
         }
         if ((options&SELECT_MASK)==_ICONLIST_BROWSESELECT && items[current]->isEnabled())
         {
@@ -3896,7 +3899,7 @@ IconList::~IconList()
 {
     getApp()->removeTimeout(this,ID_TIPTIMER);
     getApp()->removeTimeout(this,ID_LOOKUPTIMER);
-    clearItems(FALSE);
+    clearItems(false);
     header=(FXHeader*)-1L;
     font=(FXFont*)-1L;
 }
