@@ -78,7 +78,7 @@ public:
     }
 
     // Change item's big icon, deleting the old icon if it was owned
-    virtual void setBigIcon(FXIcon* icn,FXbool owned=FALSE);
+    virtual void setBigIcon(FXIcon* icn,FXbool owned=false);
 
     // Return item's big icon
     FXIcon* getBigIcon() const
@@ -87,7 +87,7 @@ public:
     }
 
     // Change item's mini icon, deleting the old icon if it was owned
-    virtual void setMiniIcon(FXIcon* icn,FXbool owned=FALSE);
+    virtual void setMiniIcon(FXIcon* icn,FXbool owned=false);
 
     // Return item's mini icon
     FXIcon* getMiniIcon() const
@@ -266,7 +266,7 @@ public:
     long onQueryTip(FXObject*,FXSelector,void*);
     long onQueryHelp(FXObject*,FXSelector,void*);
     long onTipTimer(FXObject*,FXSelector,void*);
-    long onCmdSelectAll(FXObject*,FXSelector,void*);
+    long onCmdselectAll(FXObject*,FXSelector,void*);
     long onCmdDeselectAll(FXObject*,FXSelector,void*);
     long onCmdSelectInverse(FXObject*,FXSelector,void*);
     long onCmdArrangeByRows(FXObject*,FXSelector,void*);
@@ -427,46 +427,46 @@ public:
     IconItem *getItem(int index) const;
 
     // Replace the item with a [possibly subclassed] item
-    int setItem(int index,IconItem* item,FXbool notify=FALSE);
+    int setItem(int index,IconItem* item,FXbool notify=false);
 
     // Replace items text, icons, and user-data pointer
-    int setItem(int index,const FXString& text,FXIcon *big=NULL,FXIcon* mini=NULL,void* ptr=NULL,FXbool notify=FALSE);
+    int setItem(int index,const FXString& text,FXIcon *big=NULL,FXIcon* mini=NULL,void* ptr=NULL,FXbool notify=false);
 
     // Fill list by appending items from array of strings
-    int fillItems(const char** strings,FXIcon *big=NULL,FXIcon* mini=NULL,void* ptr=NULL,FXbool notify=FALSE);
+    int fillItems(const char** strings,FXIcon *big=NULL,FXIcon* mini=NULL,void* ptr=NULL,FXbool notify=false);
 
     // Fill list by appending items from newline separated strings
-    int fillItems(const FXString& strings,FXIcon *big=NULL,FXIcon* mini=NULL,void* ptr=NULL,FXbool notify=FALSE);
+    int fillItems(const FXString& strings,FXIcon *big=NULL,FXIcon* mini=NULL,void* ptr=NULL,FXbool notify=false);
 
     // Insert a new [possibly subclassed] item at the give index
-    int insertItem(int index,IconItem* item,FXbool notify=FALSE);
+    int insertItem(int index,IconItem* item,FXbool notify=false);
 
     // Insert item at index with given text, icons, and user-data pointer
-    int insertItem(int index,const FXString& text,FXIcon *big=NULL,FXIcon* mini=NULL,void* ptr=NULL,FXbool notify=FALSE);
+    int insertItem(int index,const FXString& text,FXIcon *big=NULL,FXIcon* mini=NULL,void* ptr=NULL,FXbool notify=false);
 
     // Append a [possibly subclassed] item to the end of the list
-    int appendItem(IconItem* item,FXbool notify=FALSE);
+    int appendItem(IconItem* item,FXbool notify=false);
 
     // Append new item with given text and optional icons, and user-data pointer
-    int appendItem(const FXString& text,FXIcon *big=NULL,FXIcon* mini=NULL,void* ptr=NULL,FXbool notify=FALSE);
+    int appendItem(const FXString& text,FXIcon *big=NULL,FXIcon* mini=NULL,void* ptr=NULL,FXbool notify=false);
 
     // Prepend a [possibly subclassed] item to the end of the list
-    int prependItem(IconItem* item,FXbool notify=FALSE);
+    int prependItem(IconItem* item,FXbool notify=false);
 
     // Prepend new item with given text and optional icons, and user-data pointer
-    int prependItem(const FXString& text,FXIcon *big=NULL,FXIcon* mini=NULL,void* ptr=NULL,FXbool notify=FALSE);
+    int prependItem(const FXString& text,FXIcon *big=NULL,FXIcon* mini=NULL,void* ptr=NULL,FXbool notify=false);
 
     // Move item from oldindex to newindex
-    int moveItem(int newindex,int oldindex,FXbool notify=FALSE);
+    int moveItem(int newindex,int oldindex,FXbool notify=false);
 
     // Extract item from list
-    IconItem* extractItem(int index,FXbool notify=FALSE);
+    IconItem* extractItem(int index,FXbool notify=false);
 
     // Remove item from list
-    void removeItem(int index,FXbool notify=FALSE);
+    void removeItem(int index,FXbool notify=false);
 
     // Remove all items from list
-    void clearItems(FXbool notify=FALSE);
+    void clearItems(FXbool notify=false);
 
     // Return item width
     int getItemWidth() const
@@ -512,13 +512,13 @@ public:
     FXString getItemText(int index) const;
 
     // Change item big icon
-    void setItemBigIcon(int index,FXIcon* icon,FXbool owned=FALSE);
+    void setItemBigIcon(int index,FXIcon* icon,FXbool owned=false);
 
     // Return big icon of item at index
     FXIcon* getItemBigIcon(int index) const;
 
     // Change item mini icon
-    void setItemMiniIcon(int index,FXIcon* icon,FXbool owned=FALSE);
+    void setItemMiniIcon(int index,FXIcon* icon,FXbool owned=false);
 
     // Return mini icon of item at index
     FXIcon* getItemMiniIcon(int index) const;
@@ -529,7 +529,7 @@ public:
     // Return item user-data pointer
     void* getItemData(int index) const;
 
-	// Return TRUE if item is selected
+	// Return true if item is selected
 	FXbool isItemSelected(int index) const
 	{
 		if ((FXuint)index >= (FXuint)items.no())
@@ -537,13 +537,13 @@ public:
 		return items[index]->isSelected();
 	}
 
-    // Return TRUE if item at index is current
+    // Return true if item at index is current
     FXbool isItemCurrent(int index) const;
 
-    // Return TRUE if item at index is visible
+    // Return true if item at index is visible
     FXbool isItemVisible(int index) const;
 
-    // Return TRUE if item at index is enabled
+    // Return true if item at index is enabled
     FXbool isItemEnabled(int index) const;
 
     // Return item hit code: 0 outside, 1 icon, 2 text
@@ -559,25 +559,25 @@ public:
     virtual FXbool disableItem(int index);
 
     // Select item at index
-    virtual FXbool selectItem(int index,FXbool notify=FALSE);
+    virtual FXbool selectItem(int index,FXbool notify=false);
 
     // Deselect item at index
-    virtual FXbool deselectItem(int index,FXbool notify=FALSE);
+    virtual FXbool deselectItem(int index,FXbool notify=false);
 
     // Toggle item at index
-    virtual FXbool toggleItem(int index,FXbool notify=FALSE);
+    virtual FXbool toggleItem(int index,FXbool notify=false);
 
     // Select items in rectangle
-    virtual FXbool selectInRectangle(int x,int y,int w,int h,FXbool notify=FALSE);
+    virtual FXbool selectInRectangle(int x,int y,int w,int h,FXbool notify=false);
 
     // Extend selection from anchor index to index
-    virtual FXbool extendSelection(int index,FXbool notify=FALSE);
+    virtual FXbool extendSelection(int index,FXbool notify=false);
 
     // Deselect all items
-    virtual FXbool killSelection(FXbool notify=FALSE);
+    virtual FXbool killSelection(FXbool notify=false);
 
     // Change current item index
-    virtual void setCurrentItem(int index,FXbool notify=FALSE);
+    virtual void setCurrentItem(int index,FXbool notify=false);
 
     // Return current item index, or -1 if none
     int getCurrentItem() const
