@@ -18,7 +18,7 @@ private:
         ;
     }
 public:
-    InputDialog(FXWindow*,FXString,FXString,FXString,FXString label="",FXIcon *icon=NULL, FXbool option=FALSE, FXString=FXString::null);
+    InputDialog(FXWindow*,FXString,FXString,FXString,FXString label="",FXIcon *icon=NULL, FXbool option=false, FXString=FXString::null);
     virtual void create();
     long onCmdKeyPress(FXObject*,FXSelector,void*);
     FXString getText()
@@ -29,7 +29,7 @@ public:
 	{
 		input->setText(text);
 	}
-    void SelectAll()
+    void selectAll()
     {
         input->setSelection(0,(input->getText()).length());
     };
