@@ -140,7 +140,7 @@ KeybindingsBox::KeybindingsBox(FXWindow *win, FXStringDict* glbbindings, FXStrin
 	xfwBindingsDict_prev=new FXStringDict();
 
 	// Changed flag
-	changed=FALSE;
+	changed=false;
 }
 
 
@@ -154,7 +154,7 @@ void KeybindingsBox::create()
 	
 	// Fullfill the four lists
 	glbBindingsList->clearItems();
-    for(i=glbBindingsDict->first(); i<glbBindingsDict->size(); i=glbBindingsDict->next(i))
+    for (i=glbBindingsDict->first(); i<glbBindingsDict->size(); i=glbBindingsDict->next(i))
 	{
 		data=glbBindingsDict->data(i);
 		action= data.before('\t');
@@ -165,7 +165,7 @@ void KeybindingsBox::create()
 	glbBindingsList->sortItems();
 
 	xfeBindingsList->clearItems();
-    for(i=xfeBindingsDict->first(); i<xfeBindingsDict->size(); i=xfeBindingsDict->next(i))
+    for (i=xfeBindingsDict->first(); i<xfeBindingsDict->size(); i=xfeBindingsDict->next(i))
 	{
 		data=xfeBindingsDict->data(i);
 		action= data.before('\t');
@@ -176,7 +176,7 @@ void KeybindingsBox::create()
 	xfeBindingsList->sortItems();
 
 	xfiBindingsList->clearItems();
-    for(i=xfiBindingsDict->first(); i<xfiBindingsDict->size(); i=xfiBindingsDict->next(i))
+    for (i=xfiBindingsDict->first(); i<xfiBindingsDict->size(); i=xfiBindingsDict->next(i))
 	{
 		data=xfiBindingsDict->data(i);
 		action= data.before('\t');
@@ -187,7 +187,7 @@ void KeybindingsBox::create()
 	xfiBindingsList->sortItems();
 
 	xfwBindingsList->clearItems();
-    for(i=xfwBindingsDict->first(); i<xfwBindingsDict->size(); i=xfwBindingsDict->next(i))
+    for (i=xfwBindingsDict->first(); i<xfwBindingsDict->size(); i=xfwBindingsDict->next(i))
 	{
 		data=xfwBindingsDict->data(i);
 		action= data.before('\t');
@@ -260,10 +260,10 @@ long KeybindingsBox::onCmdAccept(FXObject* o,FXSelector s,void* p)
 		getApp()->reg().write();
 		
 		// Reinit the changed flag
-    	changed=FALSE;
+    	changed=false;
 
 		// Ask the user if he wants to restart Xfe
-		if(BOX_CLICKED_CANCEL!=MessageBox::question(this,BOX_OK_CANCEL,_("Restart"),_("Key bindings will be changed after restart.\nRestart X File Explorer now?")))
+		if (BOX_CLICKED_CANCEL!=MessageBox::question(this,BOX_OK_CANCEL,_("Restart"),_("Key bindings will be changed after restart.\nRestart X File Explorer now?")))
 			mainWindow->handle(this,FXSEL(SEL_COMMAND,XFileExplorer::ID_RESTART),NULL);
 	}
     DialogBox::onCmdAccept(o,s,p);
@@ -302,7 +302,7 @@ long KeybindingsBox::onCmdCancel(FXObject* o,FXSelector s,void* p)
 	}
 	
 	// Reinit the changed flag
-    changed=FALSE;
+    changed=false;
 	
 	DialogBox::onCmdCancel(o,s,p);
 	return 0;
@@ -368,7 +368,7 @@ long KeybindingsBox::onCmdGlbSortByActionName(FXObject*,FXSelector,void*)
 	glbBindingsList->setSortHeader(0);
 	glbBindingsList->clearItems();
     FXString str, data, action, keybinding;
-	for(int i=glbBindingsDict->first(); i<glbBindingsDict->size(); i=glbBindingsDict->next(i))
+	for (int i=glbBindingsDict->first(); i<glbBindingsDict->size(); i=glbBindingsDict->next(i))
 	{	
 		data=glbBindingsDict->data(i);
 		action= data.before('\t');
@@ -389,7 +389,7 @@ long KeybindingsBox::onCmdGlbSortByRegistryKey(FXObject*,FXSelector,void*)
 	glbBindingsList->setSortHeader(1);
 	glbBindingsList->clearItems();
     FXString str, data, action, keybinding;
-    for(int i=glbBindingsDict->first(); i<glbBindingsDict->size(); i=glbBindingsDict->next(i))
+    for (int i=glbBindingsDict->first(); i<glbBindingsDict->size(); i=glbBindingsDict->next(i))
 	{
 		data=glbBindingsDict->data(i);
 		action= data.before('\t');
@@ -409,7 +409,7 @@ long KeybindingsBox::onCmdGlbSortByKeyBinding(FXObject*,FXSelector,void*)
 	glbBindingsList->setSortHeader(2);
 	glbBindingsList->clearItems();
     FXString str, data, action, keybinding;
-    for(int i=glbBindingsDict->first(); i<glbBindingsDict->size(); i=glbBindingsDict->next(i))
+    for (int i=glbBindingsDict->first(); i<glbBindingsDict->size(); i=glbBindingsDict->next(i))
 	{
 		data=glbBindingsDict->data(i);
 		action= data.before('\t');
@@ -430,7 +430,7 @@ long KeybindingsBox::onCmdXfeSortByActionName(FXObject*,FXSelector,void*)
 	xfeBindingsList->setSortHeader(0);
 	xfeBindingsList->clearItems();
     FXString str, data, action, keybinding;
-	for(int i=xfeBindingsDict->first(); i<xfeBindingsDict->size(); i=xfeBindingsDict->next(i))
+	for (int i=xfeBindingsDict->first(); i<xfeBindingsDict->size(); i=xfeBindingsDict->next(i))
 	{	
 		data=xfeBindingsDict->data(i);
 		action= data.before('\t');
@@ -450,7 +450,7 @@ long KeybindingsBox::onCmdXfeSortByRegistryKey(FXObject*,FXSelector,void*)
 	xfeBindingsList->setSortHeader(1);
 	xfeBindingsList->clearItems();
     FXString str, data, action, keybinding;
-    for(int i=xfeBindingsDict->first(); i<xfeBindingsDict->size(); i=xfeBindingsDict->next(i))
+    for (int i=xfeBindingsDict->first(); i<xfeBindingsDict->size(); i=xfeBindingsDict->next(i))
 	{
 		data=xfeBindingsDict->data(i);
 		action= data.before('\t');
@@ -470,7 +470,7 @@ long KeybindingsBox::onCmdXfeSortByKeyBinding(FXObject*,FXSelector,void*)
 	xfeBindingsList->setSortHeader(2);
 	xfeBindingsList->clearItems();
     FXString str, data, action, keybinding;
-    for(int i=xfeBindingsDict->first(); i<xfeBindingsDict->size(); i=xfeBindingsDict->next(i))
+    for (int i=xfeBindingsDict->first(); i<xfeBindingsDict->size(); i=xfeBindingsDict->next(i))
 	{
 		data=xfeBindingsDict->data(i);
 		action= data.before('\t');
@@ -490,7 +490,7 @@ long KeybindingsBox::onCmdXfiSortByActionName(FXObject*,FXSelector,void*)
 	xfiBindingsList->setSortHeader(0);
 	xfiBindingsList->clearItems();
     FXString str, data, action, keybinding;
-	for(int i=xfiBindingsDict->first(); i<xfiBindingsDict->size(); i=xfiBindingsDict->next(i))
+	for (int i=xfiBindingsDict->first(); i<xfiBindingsDict->size(); i=xfiBindingsDict->next(i))
 	{
 		data=xfiBindingsDict->data(i);
 		action= data.before('\t');
@@ -510,7 +510,7 @@ long KeybindingsBox::onCmdXfiSortByRegistryKey(FXObject*,FXSelector,void*)
 	xfiBindingsList->setSortHeader(1);
 	xfiBindingsList->clearItems();
     FXString str, data, action, keybinding;
-    for(int i=xfiBindingsDict->first(); i<xfiBindingsDict->size(); i=xfiBindingsDict->next(i))
+    for (int i=xfiBindingsDict->first(); i<xfiBindingsDict->size(); i=xfiBindingsDict->next(i))
 	{
 		data=xfiBindingsDict->data(i);
 		action= data.before('\t');
@@ -530,7 +530,7 @@ long KeybindingsBox::onCmdXfiSortByKeyBinding(FXObject*,FXSelector,void*)
 	xfiBindingsList->setSortHeader(2);
 	xfiBindingsList->clearItems();
     FXString str, data, action, keybinding;
-    for(int i=xfiBindingsDict->first(); i<xfiBindingsDict->size(); i=xfiBindingsDict->next(i))
+    for (int i=xfiBindingsDict->first(); i<xfiBindingsDict->size(); i=xfiBindingsDict->next(i))
 	{
 		data=xfiBindingsDict->data(i);
 		action= data.before('\t');
@@ -551,7 +551,7 @@ long KeybindingsBox::onCmdXfwSortByActionName(FXObject*,FXSelector,void*)
 	xfwBindingsList->setSortHeader(0);
 	xfwBindingsList->clearItems();
     FXString str, data, action, keybinding;
-	for(int i=xfwBindingsDict->first(); i<xfwBindingsDict->size(); i=xfwBindingsDict->next(i))
+	for (int i=xfwBindingsDict->first(); i<xfwBindingsDict->size(); i=xfwBindingsDict->next(i))
 	{
 		data=xfwBindingsDict->data(i);
 		action= data.before('\t');
@@ -571,7 +571,7 @@ long KeybindingsBox::onCmdXfwSortByRegistryKey(FXObject*,FXSelector,void*)
 	xfwBindingsList->setSortHeader(1);
 	xfwBindingsList->clearItems();
     FXString str, data, action, keybinding;
-    for(int i=xfwBindingsDict->first(); i<xfwBindingsDict->size(); i=xfwBindingsDict->next(i))
+    for (int i=xfwBindingsDict->first(); i<xfwBindingsDict->size(); i=xfwBindingsDict->next(i))
 	{
 		data=xfwBindingsDict->data(i);
 		action= data.before('\t');
@@ -591,7 +591,7 @@ long KeybindingsBox::onCmdXfwSortByKeyBinding(FXObject*,FXSelector,void*)
 	xfwBindingsList->setSortHeader(2);
 	xfwBindingsList->clearItems();
     FXString str, data, action, keybinding;
-    for(int i=xfwBindingsDict->first(); i<xfwBindingsDict->size(); i=xfwBindingsDict->next(i))
+    for (int i=xfwBindingsDict->first(); i<xfwBindingsDict->size(); i=xfwBindingsDict->next(i))
 	{
 		data=xfwBindingsDict->data(i);
 		action= data.before('\t');
@@ -681,9 +681,9 @@ long KeybindingsBox::onCmdXfwHeaderClicked(FXObject*,FXSelector,void* ptr)
 long KeybindingsBox::onUpdGlbHeader(FXObject*,FXSelector,void*)
 {	
 	// Update header arrow
-  	glbBindingsList->getHeader()->setArrowDir(0,(glbBindingsList->getSortFunc()==ascendingActionName) ? FALSE : (glbBindingsList->getSortFunc()==descendingActionName)? TRUE : MAYBE);
-  	glbBindingsList->getHeader()->setArrowDir(1,(glbBindingsList->getSortFunc()==ascendingRegistryKey) ? FALSE : (glbBindingsList->getSortFunc()==descendingRegistryKey)? TRUE : MAYBE);
-  	glbBindingsList->getHeader()->setArrowDir(2,(glbBindingsList->getSortFunc()==ascendingKeybinding) ? FALSE : (glbBindingsList->getSortFunc()==descendingKeybinding)? TRUE : MAYBE);
+  	glbBindingsList->getHeader()->setArrowDir(0,(glbBindingsList->getSortFunc()==ascendingActionName) ? false : (glbBindingsList->getSortFunc()==descendingActionName)? true : MAYBE);
+  	glbBindingsList->getHeader()->setArrowDir(1,(glbBindingsList->getSortFunc()==ascendingRegistryKey) ? false : (glbBindingsList->getSortFunc()==descendingRegistryKey)? true : MAYBE);
+  	glbBindingsList->getHeader()->setArrowDir(2,(glbBindingsList->getSortFunc()==ascendingKeybinding) ? false : (glbBindingsList->getSortFunc()==descendingKeybinding)? true : MAYBE);
 
 	// Set minimum header size
 	if (glbBindingsList->getHeaderSize(0)<MIN_HEADER_SIZE)
@@ -701,9 +701,9 @@ long KeybindingsBox::onUpdGlbHeader(FXObject*,FXSelector,void*)
 long KeybindingsBox::onUpdXfeHeader(FXObject*,FXSelector,void*)
 {	
 	// Update header arrow
-  	xfeBindingsList->getHeader()->setArrowDir(0,(xfeBindingsList->getSortFunc()==ascendingActionName) ? FALSE : (xfeBindingsList->getSortFunc()==descendingActionName)? TRUE : MAYBE);
-  	xfeBindingsList->getHeader()->setArrowDir(1,(xfeBindingsList->getSortFunc()==ascendingRegistryKey) ? FALSE : (xfeBindingsList->getSortFunc()==descendingRegistryKey)? TRUE : MAYBE);
-  	xfeBindingsList->getHeader()->setArrowDir(2,(xfeBindingsList->getSortFunc()==ascendingKeybinding) ? FALSE : (xfeBindingsList->getSortFunc()==descendingKeybinding)? TRUE : MAYBE);
+  	xfeBindingsList->getHeader()->setArrowDir(0,(xfeBindingsList->getSortFunc()==ascendingActionName) ? false : (xfeBindingsList->getSortFunc()==descendingActionName)? true : MAYBE);
+  	xfeBindingsList->getHeader()->setArrowDir(1,(xfeBindingsList->getSortFunc()==ascendingRegistryKey) ? false : (xfeBindingsList->getSortFunc()==descendingRegistryKey)? true : MAYBE);
+  	xfeBindingsList->getHeader()->setArrowDir(2,(xfeBindingsList->getSortFunc()==ascendingKeybinding) ? false : (xfeBindingsList->getSortFunc()==descendingKeybinding)? true : MAYBE);
 
 	// Set minimum header size
 	if (xfeBindingsList->getHeaderSize(0)<MIN_HEADER_SIZE)
@@ -721,9 +721,9 @@ long KeybindingsBox::onUpdXfeHeader(FXObject*,FXSelector,void*)
 long KeybindingsBox::onUpdXfiHeader(FXObject*,FXSelector,void*)
 {	
 	// Update header arrow
-  	xfiBindingsList->getHeader()->setArrowDir(0,(xfiBindingsList->getSortFunc()==ascendingActionName) ? FALSE : (xfiBindingsList->getSortFunc()==descendingActionName)? TRUE : MAYBE);
-  	xfiBindingsList->getHeader()->setArrowDir(1,(xfiBindingsList->getSortFunc()==ascendingRegistryKey) ? FALSE : (xfiBindingsList->getSortFunc()==descendingRegistryKey)? TRUE : MAYBE);
-  	xfiBindingsList->getHeader()->setArrowDir(2,(xfiBindingsList->getSortFunc()==ascendingKeybinding) ? FALSE : (xfiBindingsList->getSortFunc()==descendingKeybinding)? TRUE : MAYBE);
+  	xfiBindingsList->getHeader()->setArrowDir(0,(xfiBindingsList->getSortFunc()==ascendingActionName) ? false : (xfiBindingsList->getSortFunc()==descendingActionName)? true : MAYBE);
+  	xfiBindingsList->getHeader()->setArrowDir(1,(xfiBindingsList->getSortFunc()==ascendingRegistryKey) ? false : (xfiBindingsList->getSortFunc()==descendingRegistryKey)? true : MAYBE);
+  	xfiBindingsList->getHeader()->setArrowDir(2,(xfiBindingsList->getSortFunc()==ascendingKeybinding) ? false : (xfiBindingsList->getSortFunc()==descendingKeybinding)? true : MAYBE);
 
 	// Set minimum header size
 	if (xfiBindingsList->getHeaderSize(0)<MIN_HEADER_SIZE)
@@ -741,9 +741,9 @@ long KeybindingsBox::onUpdXfiHeader(FXObject*,FXSelector,void*)
 long KeybindingsBox::onUpdXfwHeader(FXObject*,FXSelector,void*)
 {	
 	// Update header arrow
-  	xfwBindingsList->getHeader()->setArrowDir(0,(xfwBindingsList->getSortFunc()==ascendingActionName) ? FALSE : (xfwBindingsList->getSortFunc()==descendingActionName)? TRUE : MAYBE);
-  	xfwBindingsList->getHeader()->setArrowDir(1,(xfwBindingsList->getSortFunc()==ascendingRegistryKey) ? FALSE : (xfwBindingsList->getSortFunc()==descendingRegistryKey)? TRUE : MAYBE);
-  	xfwBindingsList->getHeader()->setArrowDir(2,(xfwBindingsList->getSortFunc()==ascendingKeybinding) ? FALSE : (xfwBindingsList->getSortFunc()==descendingKeybinding)? TRUE : MAYBE);
+  	xfwBindingsList->getHeader()->setArrowDir(0,(xfwBindingsList->getSortFunc()==ascendingActionName) ? false : (xfwBindingsList->getSortFunc()==descendingActionName)? true : MAYBE);
+  	xfwBindingsList->getHeader()->setArrowDir(1,(xfwBindingsList->getSortFunc()==ascendingRegistryKey) ? false : (xfwBindingsList->getSortFunc()==descendingRegistryKey)? true : MAYBE);
+  	xfwBindingsList->getHeader()->setArrowDir(2,(xfwBindingsList->getSortFunc()==ascendingKeybinding) ? false : (xfwBindingsList->getSortFunc()==descendingKeybinding)? true : MAYBE);
 
 	// Set minimum header size
 	if (xfwBindingsList->getHeaderSize(0)<MIN_HEADER_SIZE)
@@ -787,7 +787,7 @@ long KeybindingsBox::onCmdDefineGlbKeybindings(FXObject*,FXSelector,void*)
 	KeybindingsDialog* kbdialog=new KeybindingsDialog(this,key,message,_("Modify Key Binding"),keybindingsicon);
 
 	// Accept was pressed
-    if(kbdialog->execute(PLACEMENT_CURSOR))
+    if (kbdialog->execute(PLACEMENT_CURSOR))
     {		
 		// Convert the entered string into a valid key binding string
 		FXString newkey=kbdialog->getKey();
@@ -798,14 +798,14 @@ long KeybindingsBox::onCmdDefineGlbKeybindings(FXObject*,FXSelector,void*)
 		if (newkey!="")
 		{
 			FXString dictdata, dictkey;
-			FXbool exist_in_glb=FALSE, exist_in_xfe=FALSE, exist_in_xfi=FALSE, exist_in_xfw=FALSE;
-			for(int i=glbBindingsDict->first(); i<glbBindingsDict->size(); i=glbBindingsDict->next(i))
+			FXbool exist_in_glb=false, exist_in_xfe=false, exist_in_xfi=false, exist_in_xfw=false;
+			for (int i=glbBindingsDict->first(); i<glbBindingsDict->size(); i=glbBindingsDict->next(i))
 			{
 				dictdata=glbBindingsDict->data(i);
 				dictkey=dictdata.after('\t');
 				if (dictkey==newkey)
 				{
-					exist_in_glb=TRUE;
+					exist_in_glb=true;
 					break;
 				}
 			}
@@ -817,13 +817,13 @@ long KeybindingsBox::onCmdDefineGlbKeybindings(FXObject*,FXSelector,void*)
 				delete kbdialog;
 				return 0;
 			}
-			for(int i=xfeBindingsDict->first(); i<xfeBindingsDict->size(); i=xfeBindingsDict->next(i))
+			for (int i=xfeBindingsDict->first(); i<xfeBindingsDict->size(); i=xfeBindingsDict->next(i))
 			{
 				dictdata=xfeBindingsDict->data(i);
 				dictkey=dictdata.after('\t');
 				if (dictkey==newkey)
 				{
-					exist_in_xfe=TRUE;
+					exist_in_xfe=true;
 					break;
 				}
 			}
@@ -835,13 +835,13 @@ long KeybindingsBox::onCmdDefineGlbKeybindings(FXObject*,FXSelector,void*)
 				delete kbdialog;
 				return 0;
 			}
-			for(int i=xfiBindingsDict->first(); i<xfiBindingsDict->size(); i=xfiBindingsDict->next(i))
+			for (int i=xfiBindingsDict->first(); i<xfiBindingsDict->size(); i=xfiBindingsDict->next(i))
 			{
 				dictdata=xfiBindingsDict->data(i);
 				dictkey=dictdata.after('\t');
 				if (dictkey==newkey)
 				{
-					exist_in_xfi=TRUE;
+					exist_in_xfi=true;
 					break;
 				}
 			}
@@ -853,13 +853,13 @@ long KeybindingsBox::onCmdDefineGlbKeybindings(FXObject*,FXSelector,void*)
 				delete kbdialog;
 				return 0;
 			}
-			for(int i=xfwBindingsDict->first(); i<xfwBindingsDict->size(); i=xfwBindingsDict->next(i))
+			for (int i=xfwBindingsDict->first(); i<xfwBindingsDict->size(); i=xfwBindingsDict->next(i))
 			{
 				dictdata=xfwBindingsDict->data(i);
 				dictkey=dictdata.after('\t');
 				if (dictkey==newkey)
 				{
-					exist_in_xfw=TRUE;
+					exist_in_xfw=true;
 					break;
 				}
 			}
@@ -881,7 +881,7 @@ long KeybindingsBox::onCmdDefineGlbKeybindings(FXObject*,FXSelector,void*)
 		FXString str=action+TAB+newkey;
 		glbBindingsDict->replace(regkey.text(),str.text());
 		
-		changed=TRUE;
+		changed=true;
 	}	
 
 	// Cancel was pressed
@@ -927,7 +927,7 @@ long KeybindingsBox::onCmdDefineXfeKeybindings(FXObject*,FXSelector,void*)
 	KeybindingsDialog* kbdialog=new KeybindingsDialog(this,key,message,_("Modify Key Binding"),keybindingsicon);
 
 	// Accept was pressed
-    if(kbdialog->execute(PLACEMENT_CURSOR))
+    if (kbdialog->execute(PLACEMENT_CURSOR))
     {		
 		// Convert the entered string into a valid key binding string
 		FXString newkey=kbdialog->getKey();
@@ -938,14 +938,14 @@ long KeybindingsBox::onCmdDefineXfeKeybindings(FXObject*,FXSelector,void*)
 		if (newkey!="")
 		{
 			FXString dictdata, dictkey;
-			FXbool exist_in_glb=FALSE, exist_in_xfe=FALSE;
-			for(int i=glbBindingsDict->first(); i<glbBindingsDict->size(); i=glbBindingsDict->next(i))
+			FXbool exist_in_glb=false, exist_in_xfe=false;
+			for (int i=glbBindingsDict->first(); i<glbBindingsDict->size(); i=glbBindingsDict->next(i))
 			{
 				dictdata=glbBindingsDict->data(i);
 				dictkey=dictdata.after('\t');
 				if (dictkey==newkey)
 				{
-					exist_in_glb=TRUE;
+					exist_in_glb=true;
 					break;
 				}
 			}
@@ -957,13 +957,13 @@ long KeybindingsBox::onCmdDefineXfeKeybindings(FXObject*,FXSelector,void*)
 				delete kbdialog;
 				return 0;
 			}
-			for(int i=xfeBindingsDict->first(); i<xfeBindingsDict->size(); i=xfeBindingsDict->next(i))
+			for (int i=xfeBindingsDict->first(); i<xfeBindingsDict->size(); i=xfeBindingsDict->next(i))
 			{
 				dictdata=xfeBindingsDict->data(i);
 				dictkey=dictdata.after('\t');
 				if (dictkey==newkey)
 				{
-					exist_in_xfe=TRUE;
+					exist_in_xfe=true;
 					break;
 				}
 			}
@@ -985,7 +985,7 @@ long KeybindingsBox::onCmdDefineXfeKeybindings(FXObject*,FXSelector,void*)
 		FXString str=action+TAB+newkey;
 		xfeBindingsDict->replace(regkey.text(),str.text());
 		
-		changed=TRUE;
+		changed=true;
 	}	
 
 	// Cancel was pressed
@@ -1031,7 +1031,7 @@ long KeybindingsBox::onCmdDefineXfiKeybindings(FXObject*,FXSelector,void*)
 	KeybindingsDialog* kbdialog=new KeybindingsDialog(this,key,message,_("Modify Key Binding"),keybindingsicon);
 
 	// Accept was pressed
-    if(kbdialog->execute(PLACEMENT_CURSOR))
+    if (kbdialog->execute(PLACEMENT_CURSOR))
     {		
 		// Convert the entered string into a valid key binding string
 		FXString newkey=kbdialog->getKey();
@@ -1042,14 +1042,14 @@ long KeybindingsBox::onCmdDefineXfiKeybindings(FXObject*,FXSelector,void*)
 		if (newkey!="")
 		{
 			FXString dictdata, dictkey;
-			FXbool exist_in_glb=FALSE, exist_in_xfi=FALSE;
-			for(int i=glbBindingsDict->first(); i<glbBindingsDict->size(); i=glbBindingsDict->next(i))
+			FXbool exist_in_glb=false, exist_in_xfi=false;
+			for (int i=glbBindingsDict->first(); i<glbBindingsDict->size(); i=glbBindingsDict->next(i))
 			{
 				dictdata=glbBindingsDict->data(i);
 				dictkey=dictdata.after('\t');
 				if (dictkey==newkey)
 				{
-					exist_in_glb=TRUE;
+					exist_in_glb=true;
 					break;
 				}
 			}
@@ -1061,13 +1061,13 @@ long KeybindingsBox::onCmdDefineXfiKeybindings(FXObject*,FXSelector,void*)
 				delete kbdialog;
 				return 0;
 			}
-			for(int i=xfiBindingsDict->first(); i<xfiBindingsDict->size(); i=xfiBindingsDict->next(i))
+			for (int i=xfiBindingsDict->first(); i<xfiBindingsDict->size(); i=xfiBindingsDict->next(i))
 			{
 				dictdata=xfiBindingsDict->data(i);
 				dictkey=dictdata.after('\t');
 				if (dictkey==newkey)
 				{
-					exist_in_xfi=TRUE;
+					exist_in_xfi=true;
 					break;
 				}
 			}
@@ -1089,7 +1089,7 @@ long KeybindingsBox::onCmdDefineXfiKeybindings(FXObject*,FXSelector,void*)
 		FXString str=action+TAB+newkey;
 		xfiBindingsDict->replace(regkey.text(),str.text());
 		
-		changed=TRUE;
+		changed=true;
 	}	
 
 	// Cancel was pressed
@@ -1135,7 +1135,7 @@ long KeybindingsBox::onCmdDefineXfwKeybindings(FXObject*,FXSelector,void*)
 	KeybindingsDialog* kbdialog=new KeybindingsDialog(this,key,message,_("Modify Key Binding"),keybindingsicon);
 
 	// Accept was pressed
-    if(kbdialog->execute(PLACEMENT_CURSOR))
+    if (kbdialog->execute(PLACEMENT_CURSOR))
     {		
 		// Convert the entered string into a valid key binding string
 		FXString newkey=kbdialog->getKey();
@@ -1146,14 +1146,14 @@ long KeybindingsBox::onCmdDefineXfwKeybindings(FXObject*,FXSelector,void*)
 		if (newkey!="")
 		{
 			FXString dictdata, dictkey;
-			FXbool exist_in_glb=FALSE, exist_in_xfw=FALSE;
-			for(int i=glbBindingsDict->first(); i<glbBindingsDict->size(); i=glbBindingsDict->next(i))
+			FXbool exist_in_glb=false, exist_in_xfw=false;
+			for (int i=glbBindingsDict->first(); i<glbBindingsDict->size(); i=glbBindingsDict->next(i))
 			{
 				dictdata=glbBindingsDict->data(i);
 				dictkey=dictdata.after('\t');
 				if (dictkey==newkey)
 				{
-					exist_in_glb=TRUE;
+					exist_in_glb=true;
 					break;
 				}
 			}
@@ -1165,13 +1165,13 @@ long KeybindingsBox::onCmdDefineXfwKeybindings(FXObject*,FXSelector,void*)
 				delete kbdialog;
 				return 0;
 			}
-			for(int i=xfwBindingsDict->first(); i<xfwBindingsDict->size(); i=xfwBindingsDict->next(i))
+			for (int i=xfwBindingsDict->first(); i<xfwBindingsDict->size(); i=xfwBindingsDict->next(i))
 			{
 				dictdata=xfwBindingsDict->data(i);
 				dictkey=dictdata.after('\t');
 				if (dictkey==newkey)
 				{
-					exist_in_xfw=TRUE;
+					exist_in_xfw=true;
 					break;
 				}
 			}
@@ -1193,7 +1193,7 @@ long KeybindingsBox::onCmdDefineXfwKeybindings(FXObject*,FXSelector,void*)
 		FXString str=action+TAB+newkey;
 		xfwBindingsDict->replace(regkey.text(),str.text());
 		
-		changed=TRUE;
+		changed=true;
 	}	
 
 	// Cancel was pressed
