@@ -60,16 +60,17 @@ void MessageBox::initialize(const FXString& text,FXIcon* ic, FXuint whichbuttons
     FXHorizontalFrame* info=new FXHorizontalFrame(content,LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,10,10,10,10);
 
     // Message text
-    msg=new FXLabel(info,text,ic,textoptions);
+	msg=new FXLabel(info,FXString::null,ic,textoptions);
+	setText(text);
 
     new FXHorizontalSeparator(content,SEPARATOR_GROOVE|LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FILL_X);
     FXHorizontalFrame* buttons=new FXHorizontalFrame(content,LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FILL_X|PACK_UNIFORM_WIDTH,0,0,0,0,10,10,10,10);
-    if(whichbuttons==BOX_OK)
+    if (whichbuttons==BOX_OK)
     {
         initial=new FXButton(buttons,_("&OK"),NULL,this,ID_CLICKED_OK,BUTTON_INITIAL|BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_CENTER_X,0,0,0,0,HORZ_PAD,HORZ_PAD,VERT_PAD,VERT_PAD);
         initial->setFocus();
     }
-    else if(whichbuttons==BOX_OK_SU)
+    else if (whichbuttons==BOX_OK_SU)
     {
         initial=new FXButton(buttons,_("&OK"),NULL,this,ID_CLICKED_OK,BUTTON_INITIAL|BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_CENTER_X,0,0,0,0,HORZ_PAD,HORZ_PAD,VERT_PAD,VERT_PAD);
 		
@@ -85,39 +86,39 @@ void MessageBox::initialize(const FXString& text,FXIcon* ic, FXuint whichbuttons
 		}
 		initial->setFocus();
     }
-    else if(whichbuttons==BOX_OK_CANCEL)
+    else if (whichbuttons==BOX_OK_CANCEL)
     {
         initial=new FXButton(buttons,_("&Cancel"),NULL,this,ID_CLICKED_CANCEL,BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_CENTER_X,0,0,0,0,HORZ_PAD,HORZ_PAD,VERT_PAD,VERT_PAD);
         new FXButton(buttons,_("&OK"),NULL,this,ID_CLICKED_OK,BUTTON_INITIAL|BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_CENTER_X,0,0,0,0,HORZ_PAD,HORZ_PAD,VERT_PAD,VERT_PAD);
         initial->setFocus();
     }
-    else if(whichbuttons==BOX_YES_NO)
+    else if (whichbuttons==BOX_YES_NO)
     {
         initial=new FXButton(buttons,_("&No"),NULL,this,ID_CLICKED_NO,BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_CENTER_X,0,0,0,0,HORZ_PAD,HORZ_PAD,VERT_PAD,VERT_PAD);
 		new FXButton(buttons,_("&Yes"),NULL,this,ID_CLICKED_YES,BUTTON_INITIAL|BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_CENTER_X,0,0,0,0,HORZ_PAD,HORZ_PAD,VERT_PAD,VERT_PAD);
         initial->setFocus();
     }
-    else if(whichbuttons==BOX_YES_NO_CANCEL)
+    else if (whichbuttons==BOX_YES_NO_CANCEL)
     {
         initial=new FXButton(buttons,_("&Cancel"),NULL,this,ID_CLICKED_CANCEL,BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_CENTER_X,0,0,0,0,HORZ_PAD,HORZ_PAD,VERT_PAD,VERT_PAD);
         new FXButton(buttons,_("&Yes"),NULL,this,ID_CLICKED_YES,BUTTON_INITIAL|BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_CENTER_X,0,0,0,0,HORZ_PAD,HORZ_PAD,VERT_PAD,VERT_PAD);
         new FXButton(buttons,_("&No"),NULL,this,ID_CLICKED_NO,BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_CENTER_X,0,0,0,0,HORZ_PAD,HORZ_PAD,VERT_PAD,VERT_PAD);
         initial->setFocus();
     }
-    else if(whichbuttons==BOX_QUIT_CANCEL)
+    else if (whichbuttons==BOX_QUIT_CANCEL)
     {
         initial=new FXButton(buttons,_("&Cancel"),NULL,this,ID_CLICKED_CANCEL,BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_CENTER_X,0,0,0,0,HORZ_PAD,HORZ_PAD,VERT_PAD,VERT_PAD);
         new FXButton(buttons,_("&Quit"),NULL,this,ID_CLICKED_QUIT,BUTTON_INITIAL|BUTTON_DEFAULT|BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_CENTER_X,0,0,0,0,HORZ_PAD,HORZ_PAD,VERT_PAD,VERT_PAD);
         initial->setFocus();
     }
-    else if(whichbuttons==BOX_QUIT_SAVE_CANCEL)
+    else if (whichbuttons==BOX_QUIT_SAVE_CANCEL)
     {
         initial=new FXButton(buttons,_("&Cancel"),NULL,this,ID_CLICKED_CANCEL,BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_CENTER_X,0,0,0,0,HORZ_PAD,HORZ_PAD,VERT_PAD,VERT_PAD);
         new FXButton(buttons,_("&Quit"),NULL,this,ID_CLICKED_QUIT,BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_CENTER_X,0,0,0,0,HORZ_PAD,HORZ_PAD,VERT_PAD,VERT_PAD);
         new FXButton(buttons,_("&Save"),NULL,this,ID_CLICKED_SAVE,BUTTON_INITIAL|BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_CENTER_X,0,0,0,0,HORZ_PAD,HORZ_PAD,VERT_PAD,VERT_PAD);
         initial->setFocus();
     }
-    else if(whichbuttons==BOX_YES_NO_ALL_CANCEL)
+    else if (whichbuttons==BOX_YES_NO_ALL_CANCEL)
     {
         initial=new FXButton(buttons,_("&Cancel"),NULL,this,ID_CLICKED_CANCEL,BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_CENTER_X,0,0,0,0,HORZ_PAD,HORZ_PAD,VERT_PAD,VERT_PAD);
         new FXButton(buttons,_("&Yes"),NULL,this,ID_CLICKED_YES,BUTTON_INITIAL|BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_CENTER_X,0,0,0,0,HORZ_PAD,HORZ_PAD,VERT_PAD,VERT_PAD);
@@ -282,3 +283,11 @@ FXuint MessageBox::information(FXApp* app,FXuint opts,const char* caption,const
     va_end(arguments);
     return box.execute();
 }
+
+
+// Set message text
+void MessageBox::setText(FXString text)
+{
+	// Set message text with a maximum of MAX_MESSAGE_LENGTH characters per line
+	msg->setText(::multiLines(text,MAX_MESSAGE_LENGTH));
+}
