@@ -93,10 +93,7 @@ public:
 	}
 	
 	// Set message text
-	void setText(FXString text)
-	{
-		msg->setText(text);
-	}
+	void setText(FXString);
 
 };
 
