@@ -37,6 +37,9 @@ public:
     };
 public:
     OverwriteBox(FXWindow *win,const FXString& name,const FXString& text,FXuint opts=DECOR_TITLE|DECOR_BORDER,int x=0,int y=0);
+	OverwriteBox(FXWindow *win,const FXString& name,const FXString& text, FXString& srcsize, FXString& srcmtime, FXString& tgtsize, 
+	             FXString& tgtmtime,FXuint opts=DECOR_TITLE|DECOR_BORDER,int x=0,int y=0);
+
 };
 
 #endif
