@@ -31,7 +31,7 @@ PathLinker::PathLinker(FXComposite* a, FileList* flist, DirList* dlist, FXuint o
 	
 	// Add some path links
     int id = ID_START_LINK;
-    for(int i = 0; i < MAX_LINKS; i++)
+    for (int i = 0; i < MAX_LINKS; i++)
     {
         std::stringstream ss;
         ss << i;
@@ -115,7 +115,7 @@ void PathLinker::setPath(FXString text)
 	//int frameWidth = filelist->getWidth();
 
 	// Hide all of the link buttons
-    for(int i = 0; i < MAX_LINKS; i++)
+    for (int i = 0; i < MAX_LINKS; i++)
     {
         linkButtons[i]->hide();
         linkButtons[i]->setFont(normalFont);
@@ -128,7 +128,7 @@ void PathLinker::setPath(FXString text)
     FXString displayText = visitedPath;
     
     /* Doesn't work properly!
-    if(textWidth > frameWidth)
+    if (textWidth > frameWidth)
     {    	
         // The magic '4' is to compensate for the '/...' that is introduced at the front
         // of the the path. This calculation doesn't seem to work quite right as it
@@ -159,19 +159,22 @@ void PathLinker::setPath(FXString text)
     }
     nbActiveButtons = ind+1;
     setText(ind, displayText.mid(previousPos, displayText.length()));
-    
-    // If actual path is included in the visited path
-    if (visited >= 0)
-    {
-    	linkButtons[index]->setFont(highlightFont);
-    	linkButtons[index]->setState(STATE_DOWN);
-    	currentButton=index;
-	}
-    else
-    {
-    	linkButtons[ind]->setFont(highlightFont);
-    	linkButtons[ind]->setState(STATE_DOWN);
-    	currentButton=ind;
+
+	if (ind < MAX_LINKS) // Avoid crashing when the number of path links is too high
+	{
+		// If actual path is included in the visited path
+		if (visited >= 0)
+		{
+			linkButtons[index]->setFont(highlightFont);
+			linkButtons[index]->setState(STATE_DOWN);
+			currentButton=index;
+		}
+		else
+		{
+			linkButtons[ind]->setFont(highlightFont);
+			linkButtons[ind]->setState(STATE_DOWN);
+			currentButton=ind;
+		}
 	}
 }
 
@@ -186,7 +189,7 @@ void PathLinker::updatePath(FXString text, FXuint index)
 	//int frameWidth = filelist->getWidth();
 
 	// Hide all of the link buttons
-    for(int i = 0; i < MAX_LINKS; i++)
+    for (int i = 0; i < MAX_LINKS; i++)
     {
         linkButtons[i]->hide();
         linkButtons[i]->setFont(normalFont);
@@ -200,7 +203,7 @@ void PathLinker::updatePath(FXString text, FXuint index)
     FXString displayText = visitedPath;
     
     /* Doesn(t work properly!
-    if(textWidth > frameWidth)
+    if (textWidth > frameWidth)
     {    	
         // The magic '4' is to compensate for the '/...' that is introduced at the front
         // of the the path. This calculation doesn't seem to work quite right as it
@@ -231,6 +234,7 @@ void PathLinker::updatePath(FXString text, FXuint index)
         nextPos = displayText.find(PATHSEPSTRING, previousPos);
     }
     nbActiveButtons = ind+1;
+
     setText(ind, displayText.mid(previousPos, displayText.length()));
     
    	linkButtons[index]->setFont(highlightFont);
@@ -241,7 +245,7 @@ void PathLinker::updatePath(FXString text, FXuint index)
 
 void PathLinker::setText(FXuint index, FXString displayText)
 {	
-    if(index < MAX_LINKS)
+    if (index < MAX_LINKS)
     {        
 		linkButtons[index]->setText(displayText);
 		if (displayText.length())
@@ -259,7 +263,7 @@ long PathLinker::pathButtonPressed(FXObject * obj ,FXSelector sel ,void* ptr)
 	FXString filePath("");
     int endId = FXSELID(sel);
 
-	if(endId == ID_START_LINK)
+	if (endId == ID_START_LINK)
 	{
 		// Selecting root dir
 		filePath = PATHSEPSTRING;
@@ -277,7 +281,7 @@ long PathLinker::pathButtonPressed(FXObject * obj ,FXSelector sel ,void* ptr)
 	// Update the FileList and DirList directory
 	filelist->setDirectory(filePath);
 	if (dirlist)
-		dirlist->setDirectory(filePath,TRUE);
+		dirlist->setDirectory(filePath,true);
 	
 	return 1;
 }
@@ -338,7 +342,7 @@ long PathLinker::onUpdPath(FXObject * obj ,FXSelector sel ,void* ptr)
 void PathLinker::unfocus(void)
 {
 	this->setBackColor(FXRGB(128,128,128));
-    for(int i=0; i <MAX_LINKS; i++)
+    for (int i=0; i <MAX_LINKS; i++)
     {
         linkButtons[i]->setBackColor(FXRGB(128,128,128));
 		linkButtons[i]->setTextColor(FXRGB(255,255,255));
@@ -350,7 +354,7 @@ void PathLinker::unfocus(void)
 void PathLinker::focus(void)
 {
 	this->setBackColor(getApp()->getBaseColor());
-    for(int i=0; i <MAX_LINKS; i++)
+    for (int i=0; i <MAX_LINKS; i++)
     {
         linkButtons[i]->setBackColor(getApp()->getBaseColor());
 		linkButtons[i]->setTextColor(getApp()->getForeColor());
