@@ -43,8 +43,6 @@ struct Theme
     FXbool operator != (const Theme&);
 };
 
-FXColor makeHiliteColorGradient(FXColor);
-FXColor makeShadowColorGradient(FXColor);
 
 class PreferencesBox : public DialogBox
 {
@@ -56,22 +54,24 @@ private:
     FXComboBox *themesBox;
     FXList     *themesList;
     FXTextField *iconpath;
-    FXTextField *txteditor;
-    FXTextField *timeformat;
     FXTextField *txtviewer;
+    FXTextField *txteditor;
+	FXTextField *filecomparator;
+    FXTextField *timeformat;
     FXTextField *imgviewer;
     FXTextField *xterm;
     FXTextField *imgeditor;
     FXTextField *archiver;
     FXTextField *pdfviewer;
-    FXTextField *videoviewer;
-    FXTextField *audioviewer;
+    FXTextField *videoplayer;
+    FXTextField *audioplayer;
     FXTextField *normalfont;
     FXTextField *textfont;
     FXString    oldiconpath;
-    FXString    oldtxteditor;
-    FXString    oldtimeformat;
     FXString    oldtxtviewer;
+    FXString    oldtxteditor;
+    FXString    oldfilecomparator;
+    FXString    oldtimeformat;
     FXString    oldimgviewer;
     FXString    oldxterm;
     FXString    oldnormalfont;
@@ -79,8 +79,8 @@ private:
     FXString    oldimgeditor;
     FXString    oldarchiver;
     FXString    oldpdfviewer;
-    FXString    oldvideoviewer;
-    FXString    oldaudioviewer;
+    FXString    oldaudioplayer;
+    FXString    oldvideoplayer;
     FXCheckButton  *autosave;
     FXCheckButton  *savewinpos;
     FXCheckButton  *diropen;
@@ -106,6 +106,9 @@ private:
 	FXCheckButton  *show_mount;
 	FXCheckButton  *scroll;
 	FXCheckButton  *controls;
+	FXDataTarget	startdirtarget;
+	int				startdirmode;
+	int				oldstartdirmode;
 #ifdef STARTUP_NOTIFICATION
 	FXCheckButton  *usesn;
 #endif
@@ -158,13 +161,14 @@ public:
 	{
         ID_ACCEPT=DialogBox::ID_LAST,
 		ID_CANCEL,
-        ID_BROWSE_TXTEDIT,
         ID_BROWSE_TXTVIEW,
+        ID_BROWSE_TXTEDIT,
+        ID_BROWSE_FILECOMP,
 		ID_BROWSE_IMGVIEW,
 		ID_BROWSE_ARCHIVER,
 		ID_BROWSE_PDFVIEW,
-		ID_BROWSE_VIDEOVIEW,
-		ID_BROWSE_AUDIOVIEW,
+		ID_BROWSE_VIDEOPLAY,
+		ID_BROWSE_AUDIOPLAY,
         ID_BROWSE_XTERM,
         ID_COLOR,
 		ID_NORMALFONT,
@@ -185,6 +189,9 @@ public:
 		ID_SHOW_PATHLINK,
 		ID_CHANGE_KEYBINDINGS,
 		ID_RESTORE_KEYBINDINGS,
+		ID_START_HOMEDIR,
+		ID_START_CURRENTDIR,
+		ID_START_LASTDIR,
         ID_LAST
     };
 
@@ -211,5 +218,7 @@ public:
 	long onUpdControls(FXObject*,FXSelector,void*);
 	long onCmdChangeKeyBindings(FXObject*,FXSelector,void*);
 	long onCmdRestoreKeyBindings(FXObject*,FXSelector,void*);
+	long onCmdStartDir(FXObject*,FXSelector,void*);
+	long onUpdStartDir(FXObject*,FXSelector,void*);
 };
 #endif
