@@ -209,19 +209,23 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
     FXVerticalFrame *contassoc=new FXVerticalFrame(fassocgroup,LAYOUT_FILL_X|LAYOUT_FILL_Y);
     FXMatrix *matrix = new FXMatrix(contassoc,3,MATRIX_BY_COLUMNS|LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y);
     fassoctab->disable();
-    new FXLabel(matrix,_("Extension:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
-    ext = new FXLabel(matrix,"",NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
+    new FXLabel(matrix,_("Extension:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW|LAYOUT_CENTER_Y);
+    
+    // Use a read-only FXTextField instead of a FXLabel, to allow long strings
+    ext = new FXTextField(matrix,20,NULL,0,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW|LAYOUT_CENTER_Y|TEXTFIELD_READONLY|_TEXTFIELD_NOFRAME);
+	ext->setBackColor(getApp()->getBaseColor());
+
     new FXLabel(matrix,"",NULL,0);
 
-    new FXLabel(matrix,_("Description:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
-    descr = new FXTextField(matrix,30,NULL,0,FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW|LAYOUT_FILL_X);
+    new FXLabel(matrix,_("Description:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW|LAYOUT_CENTER_Y);
+    descr = new FXTextField(matrix,30,NULL,0,FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW|LAYOUT_FILL_X|LAYOUT_CENTER_Y);
     new FXLabel(matrix,"",NULL,0);
 
-    new FXLabel(matrix,_("Open:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
-    open = new FXTextField(matrix,30,NULL,0,FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW|LAYOUT_FILL_X);
-    new FXButton(matrix,_("\tSelect file..."),filedialogicon,this,ID_BROWSE_OPEN,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y,0,0,0,0,20,20);
+    new FXLabel(matrix,_("Open:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW|LAYOUT_CENTER_Y);
+    open = new FXTextField(matrix,30,NULL,0,FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW|LAYOUT_FILL_X|LAYOUT_CENTER_Y);
+    new FXButton(matrix,_("\tSelect file..."),filedialogicon,this,ID_BROWSE_OPEN,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_FILL_X|LAYOUT_CENTER_Y,0,0,0,0,10,10);
 
-    int is_ar = FALSE;
+    int is_ar = false;
 
     FXString viewlbl=_("View:");
     FXString editlbl=_("Edit:");
@@ -233,37 +237,37 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 	    || extension=="7z" || extension=="Z" || extension=="lzh" || extension=="rar"
 	    || extension=="ace" || extension=="arj")
 	{
-		is_ar = TRUE; // archive
+		is_ar = true; // archive
 		viewlbl = _("Extract:");
 	}
 #if defined(linux)
-	else if(extension=="rpm")
+	else if (extension=="rpm")
 		editlbl = _("Install/Upgrade:");
 #endif	
-    new FXLabel(matrix,viewlbl,NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
-    view = new FXTextField(matrix,30,NULL,0,FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW|LAYOUT_FILL_X);
-    new FXButton(matrix,_("\tSelect file..."),filedialogicon,this,ID_BROWSE_VIEW,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y,0,0,0,0,20,20);
+    new FXLabel(matrix,viewlbl,NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW|LAYOUT_CENTER_Y);
+    view = new FXTextField(matrix,30,NULL,0,FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW|LAYOUT_FILL_X|LAYOUT_CENTER_Y);
+    new FXButton(matrix,_("\tSelect file..."),filedialogicon,this,ID_BROWSE_VIEW,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_FILL_X|LAYOUT_CENTER_Y,0,0,0,0,10,10);
 
-    if(!is_ar)
+    if (!is_ar)
     {
-        new FXLabel(matrix,editlbl,NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
-        edit = new FXTextField(matrix,30,NULL,0,FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW|LAYOUT_FILL_X);
-        new FXButton(matrix,_("\tSelect file..."),filedialogicon,this,ID_BROWSE_EDIT,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y,0,0,0,0,20,20);
+        new FXLabel(matrix,editlbl,NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW|LAYOUT_CENTER_Y);
+        edit = new FXTextField(matrix,30,NULL,0,FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW|LAYOUT_FILL_X|LAYOUT_CENTER_Y);
+        new FXButton(matrix,_("\tSelect file..."),filedialogicon,this,ID_BROWSE_EDIT,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_FILL_X|LAYOUT_CENTER_Y,0,0,0,0,10,10);
     }
     else
         edit = NULL;
 
-    new FXLabel(matrix,_("Big Icon:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
-    bigic = new FXTextField(matrix,30,NULL,0,FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW|LAYOUT_FILL_X);
-    new FXButton(matrix,_("\tSelect file..."),filedialogicon,this,ID_BIG_ICON,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y,0,0,0,0,20,20);
+    new FXLabel(matrix,_("Big Icon:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW|LAYOUT_CENTER_Y);
+    bigic = new FXTextField(matrix,30,NULL,0,FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW|LAYOUT_FILL_X|LAYOUT_CENTER_Y);
+    bigicbtn=new FXButton(matrix,_("\tSelect file..."),filedialogicon,this,ID_BIG_ICON,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_FILL_X|LAYOUT_CENTER_Y,0,0,0,0,10,10);
 
-    new FXLabel(matrix,_("Mini Icon:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
-    miniic = new FXTextField(matrix,30,NULL,0,FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW|LAYOUT_FILL_X);
-    new FXButton(matrix,_("\tSelect file..."),filedialogicon,this,ID_MINI_ICON,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y,0,0,0,0,20,20);
+    new FXLabel(matrix,_("Mini Icon:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW|LAYOUT_CENTER_Y);
+    miniic = new FXTextField(matrix,30,NULL,0,FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW|LAYOUT_FILL_X|LAYOUT_CENTER_Y);
+    miniicbtn=new FXButton(matrix,_("\tSelect file..."),filedialogicon,this,ID_MINI_ICON,FRAME_RAISED|FRAME_THICK|LAYOUT_FILL_X|LAYOUT_RIGHT|LAYOUT_CENTER_Y,0,0,0,0,10,10);
 
-    // Label
+    // File name
     new FXLabel(generalframe,_("Name"),NULL,JUSTIFY_LEFT);
-    input = new FXTextField(generalframe,20,NULL,0,FRAME_THICK|FRAME_SUNKEN|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
+    input = new FXTextField(generalframe,60,NULL,0,FRAME_THICK|FRAME_SUNKEN|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
 
     // Complete file path name
 	pathname=path+PATHSEPSTRING+file;
@@ -275,14 +279,14 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 	paths = NULL;
 	
 	// Initialize mount point flag
-	isMountpoint=FALSE;
+	isMountpoint=false;
 
 	// Warn if non UTF-8 file name
 	if (!isUtf8(pathname.text(),pathname.length()))
 		new FXLabel(generalframe,_("=> Warning: file name is not UTF-8 encoded!"),NULL,LAYOUT_LEFT|LAYOUT_CENTER_Y|LAYOUT_FILL_ROW);
 
 	// Get file/link stat info
-    if(lstatrep(pathname.text(),&linfo)!=0)
+    if (lstatrep(pathname.text(),&linfo)!=0)
         return ;
 
 	// Obtain user name
@@ -298,13 +302,13 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 	// Test if link or broken link
 	// When valid link, get the referred file path
     isLink=S_ISLNK(linfo.st_mode);
-	isBrokenLink=FALSE;
-	if(isLink)
+	isBrokenLink=false;
+	if (isLink)
 	{
 		// Broken link
 		struct stat info;
 		if (statrep(pathname.text(),&info)!=0)
-			isBrokenLink=TRUE;
+			isBrokenLink=true;
 
 		// Get the path name of the linked file
 		referredpath=::readLink(pathname);
@@ -313,7 +317,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
     orig_mode=linfo.st_mode;
     
     // Initialize exec flag
-    executable=FALSE;
+    executable=false;
 
 	// Read time format
 	FXString timeformat=getApp()->reg().readStringEntry("SETTINGS","time_format",DEFAULT_TIME_FORMAT);
@@ -332,7 +336,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 
     // Is it a directory?
 	isDirectory=S_ISDIR(linfo.st_mode);
-    if(isDirectory)
+    if (isDirectory)
     {		
 		// Directory path
 		FXString dirpath=FXPath::absolute(parentdir,file);
@@ -340,15 +344,15 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 #if defined(linux)
 		FILE *mtab=setmntent(MTAB_PATH,"r");
         struct mntent *mnt;
-        if(mtab)
+        if (mtab)
         {
             while((mnt=getmntent(mtab)))
             {
-                if(!streq(mnt->mnt_type,MNTTYPE_IGNORE) && !streq(mnt->mnt_type,MNTTYPE_SWAP))
+                if (!streq(mnt->mnt_type,MNTTYPE_IGNORE) && !streq(mnt->mnt_type,MNTTYPE_SWAP))
                 {
-                    if(streq(mnt->mnt_dir,dirpath.text()))
+                    if (streq(mnt->mnt_dir,dirpath.text()))
                     {
-                        isMountpoint=TRUE;
+                        isMountpoint=true;
                         snprintf(buf,sizeof(buf)-1,_("Filesystem (%s)"),mnt->mnt_fsname);
                         type=buf;
 						strlcpy(mnttype,mnt->mnt_type,strlen(mnt->mnt_type)+1);
@@ -359,16 +363,16 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
         }
 #endif
 		// If it is a mount point
-		if(isMountpoint)
+		if (isMountpoint)
 		{
 			// Caution : use the -P option to be POSIX compatible!
 			snprintf(buf,sizeof(buf)-1,"df -P -B 1 '%s'",pathname.text());
 			p=popen(buf,"r");
-			FXbool success=TRUE;
+			FXbool success=true;
 			if (fgets(buf,sizeof(buf),p) == NULL)
-				success=FALSE;
+				success=false;
 			if (fgets(buf,sizeof(buf),p) == NULL)
-				success=FALSE;
+				success=false;
 			if (success)
 			{
 				strtok(buf," ");
@@ -396,13 +400,13 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 			type=_("Folder");
     }
 	
-    else if(S_ISCHR(linfo.st_mode))
+    else if (S_ISCHR(linfo.st_mode))
         type=_("Character Device");
-    else if(S_ISBLK(linfo.st_mode))
+    else if (S_ISBLK(linfo.st_mode))
         type=_("Block Device");
-    else if(S_ISFIFO(linfo.st_mode))
+    else if (S_ISFIFO(linfo.st_mode))
         type=_("Named Pipe");
-    else if(S_ISSOCK(linfo.st_mode))
+    else if (S_ISSOCK(linfo.st_mode))
         type=_("Socket");
     
 	// Regular file or link
@@ -415,16 +419,16 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 			fileassoc=getApp()->reg().readStringEntry("FILETYPES",extension.text(),"");
 
 		// If we have an association
-        if(!fileassoc.empty())
+        if (!fileassoc.empty())
         {
            	FXString c;
             type=fileassoc.section(';',1);    
-			if(type=="")
+			if (type=="")
 			{
 				if (linfo.st_mode&(S_IXUSR|S_IXGRP|S_IXOTH))
 				{
                 	type=_("Executable");
-                	executable=TRUE;
+                	executable=true;
 				}
                 else
                 	type=_("Document");
@@ -434,20 +438,31 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
             descr->setText(fileassoc.section(';',1));
             open->setText(c.section(',',0));
             view->setText(c.section(',',1));
-            if(edit)
+            if (edit)
                 edit->setText(c.section(',',2));
             bigic->setText(fileassoc.section(';',2));
             miniic->setText(fileassoc.section(';',3));
             if (!isLink)
 				fassoctab->enable();
+ 
+ 			// Load big and mini icons
+			FXString iconpath=getApp()->reg().readStringEntry("SETTINGS","iconpath",DEFAULTICONPATH);
+
+ 			FXIcon* bigicon = loadiconfile(getApp(),iconpath,bigic->getText());
+ 			if (bigicon)		
+				bigicbtn->setIcon(bigicon);
+
+ 			FXIcon* miniicon = loadiconfile(getApp(),iconpath,miniic->getText());
+			if (miniicon)
+				miniicbtn->setIcon(miniicon);
         }
         else
         {
             ext->setText(extension);
-			if(linfo.st_mode&(S_IXUSR|S_IXGRP|S_IXOTH))
+			if (linfo.st_mode&(S_IXUSR|S_IXGRP|S_IXOTH))
 			{
                 type=_("Executable");
-                executable=TRUE;
+                executable=true;
 			}
             else
             {
@@ -482,24 +497,24 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 					fileassoc=getApp()->reg().readStringEntry("FILETYPES",extension.text(),"");
 
 				// If we have an association
-				if(!fileassoc.empty())
+				if (!fileassoc.empty())
 					type=fileassoc.section(';',1);
 				
 				// No association
 				else
 				{
-					if(S_ISCHR(info.st_mode))
+					if (S_ISCHR(info.st_mode))
 						type=_("Character Device");
-					else if(S_ISBLK(info.st_mode))
+					else if (S_ISBLK(info.st_mode))
 						type=_("Block Device");
-					else if(S_ISFIFO(info.st_mode))
+					else if (S_ISFIFO(info.st_mode))
 						type=_("Named Pipe");
-					else if(S_ISSOCK(info.st_mode))
+					else if (S_ISSOCK(info.st_mode))
 						type=_("Socket");
-					else if(info.st_mode&(S_IXUSR|S_IXGRP|S_IXOTH))
+					else if (info.st_mode&(S_IXUSR|S_IXGRP|S_IXOTH))
 					{
 						type=_("Executable");
-						executable=TRUE;
+						executable=true;
 					}
 					else
 						type=_("Document");
@@ -511,41 +526,41 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 
 	// Parent directory name not editable
 	if (file=="..")
-		input->setEditable(FALSE);
+		input->setEditable(false);
 
 	// Root directory name not editable
     if (file=="" && path==ROOTDIR)
 	{
 		input->setText(ROOTDIR);
-		input->setEditable(FALSE);
+		input->setEditable(false);
 	}
 	else		
 		input->setText(file);
-    
+
 	input->setFocus();
-
+ 
     // Set permissions
-    perm->ur->setCheck((linfo.st_mode & S_IRUSR) ? TRUE : FALSE);
-    perm->uw->setCheck((linfo.st_mode & S_IWUSR) ? TRUE : FALSE);
-    perm->ux->setCheck((linfo.st_mode & S_IXUSR) ? TRUE : FALSE);
+    perm->ur->setCheck((linfo.st_mode & S_IRUSR) ? true : false);
+    perm->uw->setCheck((linfo.st_mode & S_IWUSR) ? true : false);
+    perm->ux->setCheck((linfo.st_mode & S_IXUSR) ? true : false);
 
-    perm->gr->setCheck((linfo.st_mode & S_IRGRP) ? TRUE : FALSE);
-    perm->gw->setCheck((linfo.st_mode & S_IWGRP) ? TRUE : FALSE);
-    perm->gx->setCheck((linfo.st_mode & S_IXGRP) ? TRUE : FALSE);
+    perm->gr->setCheck((linfo.st_mode & S_IRGRP) ? true : false);
+    perm->gw->setCheck((linfo.st_mode & S_IWGRP) ? true : false);
+    perm->gx->setCheck((linfo.st_mode & S_IXGRP) ? true : false);
 
-    perm->or_->setCheck((linfo.st_mode & S_IROTH) ? TRUE : FALSE);
-    perm->ow->setCheck((linfo.st_mode & S_IWOTH) ? TRUE : FALSE);
-    perm->ox->setCheck((linfo.st_mode & S_IXOTH) ? TRUE : FALSE);
+    perm->or_->setCheck((linfo.st_mode & S_IROTH) ? true : false);
+    perm->ow->setCheck((linfo.st_mode & S_IWOTH) ? true : false);
+    perm->ox->setCheck((linfo.st_mode & S_IXOTH) ? true : false);
 
-    perm->suid->setCheck((linfo.st_mode & S_ISUID) ? TRUE : FALSE);
-    perm->sgid->setCheck((linfo.st_mode & S_ISGID) ? TRUE : FALSE);
-    perm->svtx->setCheck((linfo.st_mode & S_ISVTX) ? TRUE : FALSE);
+    perm->suid->setCheck((linfo.st_mode & S_ISUID) ? true : false);
+    perm->sgid->setCheck((linfo.st_mode & S_ISGID) ? true : false);
+    perm->svtx->setCheck((linfo.st_mode & S_ISVTX) ? true : false);
 
     perm->set->setCheck();
 	perm->all->setCheck();
 
 	FXLabel *mtType=NULL, *mtUsed=NULL, *mtFree=NULL, *fileType=NULL, *fileChanged=NULL, *fileAccessed=NULL, *fileModified=NULL;
-	FXbool isInTrash=FALSE;
+	FXbool isInTrash=false;
 	
 	fileSize=NULL;
 	
@@ -562,7 +577,9 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
   		mtFree=new FXLabel(mtmatrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN|JUSTIFY_LEFT);
   		new FXLabel(mtmatrix,_("File system:"),NULL,LAYOUT_LEFT);
   		mtType=new FXLabel(mtmatrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN|JUSTIFY_LEFT);
-  		new FXLabel(mtmatrix,_("Location:"),NULL,LAYOUT_LEFT);
+  		new FXLabel(mtmatrix,_("Location:"),NULL,LAYOUT_LEFT);		
+  		
+  		//location=new FXText(mtmatrix,NULL,LAYOUT_FILL_X|LAYOUT_FILL_Y); // Use an FXText to allow long text strings
   		location=new FXLabel(mtmatrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN|JUSTIFY_LEFT);
 	}
 	else
@@ -577,12 +594,13 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 		filesSizeDetails=new FXLabel(attrmatrix,FXString::null,NULL,LAYOUT_LEFT|JUSTIFY_LEFT);
   		new FXLabel(attrmatrix,_("Location:"),NULL,LAYOUT_LEFT);
   		location=new FXLabel(attrmatrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN|JUSTIFY_LEFT);
+ 
 		if (isLink & !isBrokenLink)
 		{
 			new FXLabel(attrmatrix,_("Link to:"),NULL,LAYOUT_LEFT);
 			linkto=new FXLabel(attrmatrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
 		}
-		else if(isBrokenLink)
+		else if (isBrokenLink)
 		{
 			new FXLabel(attrmatrix,_("Broken link to:"),NULL,LAYOUT_LEFT);
 			linkto=new FXLabel(attrmatrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
@@ -591,7 +609,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 		// If the file is in the trash can
 		if (parentdir.left(trashfileslocation.length())==trashfileslocation)
 		{
-			isInTrash=TRUE;			
+			isInTrash=true;			
 
    			new FXLabel(attrmatrix,_("Original location:"),NULL,LAYOUT_LEFT);
  			origlocation=new FXLabel(attrmatrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
@@ -611,19 +629,19 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 		sngroup=new FXGroupBox(generalframe,_("Startup Notification"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X);
 		snbutton=new FXCheckButton(sngroup,_("Disable startup notification for this executable"),this,ID_SNDISABLE);
 
-		sndisable_prev=FALSE;
+		sndisable_prev=false;
 		FXString snexcepts=getApp()->reg().readStringEntry("OPTIONS","startup_notification_exceptions","");
-		if(snexcepts != "")
+		if (snexcepts != "")
 		{
 			FXString entry;
-			for(int i=0; ; i++)
+			for (int i=0; ; i++)
 			{
 				entry=snexcepts.section(':',i);
-				if(streq(entry.text(),""))
+				if (streq(entry.text(),""))
 					break;
-				if(streq(entry.text(),filename.text()))
+				if (streq(entry.text(),filename.text()))
 				{
-					sndisable_prev=TRUE;
+					sndisable_prev=true;
 					break;
 				}
 			}
@@ -644,7 +662,20 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 	fileType->setText(type.text());
 
 	// Parent directory
-	location->setText(parentdir);
+	FXString text = parentdir;
+
+	// Insert line breaks if text has one line and more than allowed number of characters
+	if (text.find('\n') < 0 && text.length() > MAX_MESSAGE_LENGTH)
+	{
+		// Insert \n in the message every MAX_MESSAGE_LENGTH chars
+		int nb = text.length()/MAX_MESSAGE_LENGTH;
+		for (int n=1; n<=nb; n++)
+		{
+			text.insert(n*MAX_MESSAGE_LENGTH,'\n');
+		}
+	}
+
+	location->setText(text);
 	
 	// Referred file for valid or broken link
 	if (isLink)
@@ -654,7 +685,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 	if (isDirectory)
 	{
 		// if mount point
-		if(isMountpoint)
+		if (isMountpoint)
 		{
 			hsize=::hSize(used);
         	snprintf(size,sizeof(size)-1,"%s (%s)",hsize.text(),pctr);        
@@ -708,15 +739,15 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 		char line[1024];
 		FXString origpath="", delstr="";
 		FXlong deldate=0;
-		FXbool success=TRUE;
+		FXbool success=true;
 		FXString trashinfopathname=trashinfolocation+PATHSEPSTRING+trashbasename+".trashinfo";
 		if ((fp=fopen(trashinfopathname.text(),"r"))!=NULL)
 		{
 			// Read the first three lines and get the strings
 			if (fgets(line,sizeof(line),fp)==NULL)
-				success=FALSE;
+				success=false;
 			if (fgets(line,sizeof(line),fp)==NULL)
-				success=FALSE;
+				success=false;
 			if (success)
 			{
 				origpath=line;
@@ -724,7 +755,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 				origpath=origpath.before('\n');
 			}						
 			if (fgets(line,sizeof(line),fp)==NULL)
-				success=FALSE;
+				success=false;
 			if (success)
 			{
 				delstr=line;
@@ -769,7 +800,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 	miniic_prev=miniic->getText();
 
 	// Flag used to avoid computing recursive size more than once
-	recsize=TRUE;
+	recsize=true;
 }
 
 
@@ -781,7 +812,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString *file,int n,FXString *path):
     FXString type, extension, fileassoc;
     char buf[MAXPATHLEN+1];
 	int i, isDirectory, nbseldirs=0, nbselfiles=0, dotdot=0;
-	FXbool firstfile=TRUE;
+	FXbool firstfile=true;
 
     // Buttons
     FXHorizontalFrame *buttons=new FXHorizontalFrame(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X,0,0,0,0,10,10,5,5);
@@ -822,7 +853,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString *file,int n,FXString *path):
     // Get file/link info of the first file of the list
 	// This is used as a guess for the username, group and permissions of the whole list
 	FXString pathname=path[0]+PATHSEPSTRING+file[0];
-    if(lstatrep(pathname.text(),&linfo)!=0)
+    if (lstatrep(pathname.text(),&linfo)!=0)
         return ;
 	
 	// Obtain user name
@@ -833,21 +864,21 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString *file,int n,FXString *path):
 
     orig_mode=linfo.st_mode;
 
-    perm->ur->setCheck((linfo.st_mode & S_IRUSR) ? TRUE : FALSE);
-    perm->uw->setCheck((linfo.st_mode & S_IWUSR) ? TRUE : FALSE);
-    perm->ux->setCheck((linfo.st_mode & S_IXUSR) ? TRUE : FALSE);
+    perm->ur->setCheck((linfo.st_mode & S_IRUSR) ? true : false);
+    perm->uw->setCheck((linfo.st_mode & S_IWUSR) ? true : false);
+    perm->ux->setCheck((linfo.st_mode & S_IXUSR) ? true : false);
 
-    perm->gr->setCheck((linfo.st_mode & S_IRGRP) ? TRUE : FALSE);
-    perm->gw->setCheck((linfo.st_mode & S_IWGRP) ? TRUE : FALSE);
-    perm->gx->setCheck((linfo.st_mode & S_IXGRP) ? TRUE : FALSE);
+    perm->gr->setCheck((linfo.st_mode & S_IRGRP) ? true : false);
+    perm->gw->setCheck((linfo.st_mode & S_IWGRP) ? true : false);
+    perm->gx->setCheck((linfo.st_mode & S_IXGRP) ? true : false);
 
-    perm->or_->setCheck((linfo.st_mode & S_IROTH) ? TRUE : FALSE);
-    perm->ow->setCheck((linfo.st_mode & S_IWOTH) ? TRUE : FALSE);
-    perm->ox->setCheck((linfo.st_mode & S_IXOTH) ? TRUE : FALSE);
+    perm->or_->setCheck((linfo.st_mode & S_IROTH) ? true : false);
+    perm->ow->setCheck((linfo.st_mode & S_IWOTH) ? true : false);
+    perm->ox->setCheck((linfo.st_mode & S_IXOTH) ? true : false);
 
-    perm->suid->setCheck((linfo.st_mode & S_ISUID) ? TRUE : FALSE);
-    perm->sgid->setCheck((linfo.st_mode & S_ISGID) ? TRUE : FALSE);
-    perm->svtx->setCheck((linfo.st_mode & S_ISVTX) ? TRUE : FALSE);
+    perm->suid->setCheck((linfo.st_mode & S_ISUID) ? true : false);
+    perm->sgid->setCheck((linfo.st_mode & S_ISGID) ? true : false);
+    perm->svtx->setCheck((linfo.st_mode & S_ISVTX) ? true : false);
 
     perm->add->setCheck();
 	perm->all->setCheck();
@@ -864,10 +895,10 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString *file,int n,FXString *path):
     num = n;
 
 	// Total size and files type
-	for(i=0;i<num;i++)
+	for (i=0;i<num;i++)
 	{
 		FXString pathname=paths[i]+PATHSEPSTRING+files[i];
-		if(lstatrep(pathname.text(),&linfo)!=0)
+		if (lstatrep(pathname.text(),&linfo)!=0)
 			continue ;
 
 		// Special case of the ".." directory
@@ -879,7 +910,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString *file,int n,FXString *path):
 
 		// Is it a directory?
 		isDirectory=S_ISDIR(linfo.st_mode);
-		if(isDirectory)
+		if (isDirectory)
 			nbseldirs++;
 
 		else // Regular file
@@ -896,11 +927,11 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString *file,int n,FXString *path):
 			if (firstfile)
 			{
 				// If we have an association
-        		if(!fileassoc.empty())
+        		if (!fileassoc.empty())
  					type=fileassoc.section(';',1);
 				else
 					type=_("Document");
-				firstfile=FALSE;
+				firstfile=false;
 			}
 			else
 			{
@@ -936,7 +967,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString *file,int n,FXString *path):
 	filesType->setText(type);
 
 	// Flag used to avoid computing recursive size more than once
-	recsize=TRUE;
+	recsize=true;
 }
 
 
@@ -977,18 +1008,18 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
 			// Add to list if not already present
 			if (sndisable)
 			{
-				FXbool notinlist=TRUE;
-				if(snexcepts != "")
+				FXbool notinlist=true;
+				if (snexcepts != "")
 				{
 					FXString entry;
-					for(int i=0; ; i++)
+					for (int i=0; ; i++)
 					{
 						entry=snexcepts.section(':',i);
-						if(streq(entry.text(),""))
+						if (streq(entry.text(),""))
 							break;
-						if(streq(entry.text(),filename.text()))
+						if (streq(entry.text(),filename.text()))
 						{
-							notinlist=FALSE;
+							notinlist=false;
 							break;
 						}
 					}
@@ -1001,19 +1032,19 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
 			// Remove from list if already present
 			else
 			{
-				FXbool inlist=FALSE;
+				FXbool inlist=false;
 				int pos=0;
-				if(snexcepts != "")
+				if (snexcepts != "")
 				{
 					FXString entry;
-					for(int i=0; ; i++)
+					for (int i=0; ; i++)
 					{
 						entry=snexcepts.section(':',i);
-						if(streq(entry.text(),""))
+						if (streq(entry.text(),""))
 							break;
-						if(streq(entry.text(),filename.text()))
+						if (streq(entry.text(),filename.text()))
 						{
-							inlist=TRUE;
+							inlist=true;
 							break;
 						}
 						pos += entry.length()+1;
@@ -1049,12 +1080,12 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
 	{
 		op = open->getText();
 		v = view->getText();
-		if(!v.empty())
+		if (!v.empty())
 			v = "," + v;
-		if(edit)
+		if (edit)
 		{
 			e = edit->getText();
-			if(!e.empty())
+			if (!e.empty())
 				e = "," + e;
 		}
 
@@ -1067,7 +1098,7 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
 		if (ext->getText()!="")
 		{
 			oldfileassoc=getApp()->reg().readStringEntry("FILETYPES",ext->getText().text(),"");
-			if(oldfileassoc == "" || fileassoc.section('=',1) != oldfileassoc)
+			if (oldfileassoc == "" || fileassoc.section('=',1) != oldfileassoc)
 			{
 				FXString command=fileassoc.section('=',1);
 				getApp()->reg().writeStringEntry("FILETYPES",ext->getText().text(),command.text());
@@ -1105,7 +1136,7 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
 	}
 
     // Rename file if necessary
-	if(source != target)
+	if (source != target)
 	{
 		// Source path is not writable	
 		if (!::isWritable(sourcepath))
@@ -1155,13 +1186,13 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
         gid_t gid = 32768;
         struct passwd* pwde;
         while( (pwde = getpwent()) )
-            if(perm->user->getText() == pwde->pw_name)
+            if (perm->user->getText() == pwde->pw_name)
                 uid = pwde->pw_uid;
         endpwent();
 
         struct group* grpe;
         while( (grpe = getgrent()) )
-            if(perm->grp->getText() == grpe->gr_name)
+            if (perm->grp->getText() == grpe->gr_name)
                 gid = grpe->gr_gid;
         endgrent();
 
@@ -1177,7 +1208,7 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
 		if (f->isCancelled())
 		{
 			f->hideProgressDialog();
-			MessageBox::error(this,BOX_OK,_("Error"),_("Change owner cancelled!"));
+			MessageBox::error(this,BOX_OK,_("Warning"),_("Change owner cancelled!"));
 			delete f;
 			getApp()->endWaitCursor();
 			return 1;
@@ -1185,7 +1216,7 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
 		getApp()->endWaitCursor();
 		
 		// Handle chown errors
-        if(rc)
+        if (rc)
 		{
 			f->hideProgressDialog();
 			if (errcode)
@@ -1210,7 +1241,7 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
         struct stat linfo;
         mode_t m;
 		
-        if(lstatrep(targetpath.text(),&linfo)!=0)
+        if (lstatrep(targetpath.text(),&linfo)!=0)
             return 1;
 
         f = new File(this,_("File permissions"),CHMOD);
@@ -1244,7 +1275,7 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
 		if (f->isCancelled())
 		{
 			f->hideProgressDialog();
-			MessageBox::error(this,BOX_OK,_("Error"),_("Change file permissions cancelled!"));
+			MessageBox::error(this,BOX_OK,_("Warning"),_("Change file permissions cancelled!"));
 			delete f;
 			getApp()->endWaitCursor();
 			return 1;
@@ -1295,20 +1326,20 @@ long PropertiesBox::onCmdAcceptMult(FXObject* o,FXSelector s,void* p)
 	{
 		struct stat linfo;
 		FXString pathname=FXPath::absolute(paths[i],files[i]);
-		if(lstatrep(pathname.text(),&linfo)!=0)
+		if (lstatrep(pathname.text(),&linfo)!=0)
 			continue ;
 
 		uid_t uid = 32768;
 		gid_t gid = 32768;
 		struct passwd* pwde;
 		while( (pwde = getpwent()) )
-			if(perm->user->getText() == pwde->pw_name)
+			if (perm->user->getText() == pwde->pw_name)
 				uid = pwde->pw_uid;
 		endpwent();
 
 		struct group* grpe;
 		while( (grpe = getgrent()) )
-			if(perm->grp->getText() == grpe->gr_name)
+			if (perm->grp->getText() == grpe->gr_name)
 				gid = grpe->gr_gid;
 		endgrent();
 
@@ -1321,14 +1352,14 @@ long PropertiesBox::onCmdAcceptMult(FXObject* o,FXSelector s,void* p)
 		if (f->isCancelled())
 		{
 			f->hideProgressDialog();
-			MessageBox::error(this,BOX_OK,_("Error"),_("Change owner cancelled!"));
+			MessageBox::error(this,BOX_OK,_("Warning"),_("Change owner cancelled!"));
 			delete f;
 			getApp()->endWaitCursor();
 			return 0;
 		}
 		
 		// Handle chown errors
-		if(rc)
+		if (rc)
 		{
 			f->hideProgressDialog();
 			if (errcode)
@@ -1358,13 +1389,13 @@ long PropertiesBox::onCmdAcceptMult(FXObject* o,FXSelector s,void* p)
 		// Wait cursor
 		getApp()->beginWaitCursor();
 
-        for(i=0; i<num; i++)
+        for (i=0; i<num; i++)
         {
             struct stat linfo;
             mode_t m;
 			
 			FXString pathname=FXPath::absolute(paths[i],files[i]);
-            if(lstatrep(pathname.text(),&linfo)!=0)
+            if (lstatrep(pathname.text(),&linfo)!=0)
                 continue ;
 
             switch(perm->cmd)
@@ -1394,14 +1425,14 @@ long PropertiesBox::onCmdAcceptMult(FXObject* o,FXSelector s,void* p)
 				if (f->isCancelled())
 				{
 					f->hideProgressDialog();
-					MessageBox::error(this,BOX_OK,_("Error"),_("Change file(s) permissions cancelled!"));
+					MessageBox::error(this,BOX_OK,_("Warning"),_("Change file(s) permissions cancelled!"));
 					delete f;
 					getApp()->endWaitCursor();
 					return 1;
 				}
         		
 				// Handle chmod errors
-				if(rc)
+				if (rc)
 				{
 					f->hideProgressDialog();
 					if (errcode)
@@ -1493,7 +1524,7 @@ long PropertiesBox::onCmdCheck(FXObject* o,FXSelector s,void* p)
 			break;
 	}
 	FXCheckButton* ch = (FXCheckButton*)o;    
-	if(!ch->getCheck())
+	if (!ch->getCheck())
        mode &= ~xmode;
     else
         mode |= xmode;
@@ -1513,7 +1544,7 @@ long PropertiesBox::onCmdBrowse(FXObject* o,FXSelector s,void* p)
 	browseProgram.setFilename(ROOTDIR);
 	browseProgram.setPatternList(patterns);
 	browseProgram.setSelectMode(SELECT_FILE_EXISTING);
-	if(browseProgram.execute())
+	if (browseProgram.execute())
     {
         FXString path=browseProgram.getFilename();
         switch(FXSELID(s))
@@ -1525,7 +1556,7 @@ long PropertiesBox::onCmdBrowse(FXObject* o,FXSelector s,void* p)
             	view->setText(FXPath::name(path));
             	break;
         	case ID_BROWSE_EDIT:
-            	if(edit)
+            	if (edit)
                 	edit->setText(FXPath::name(path));
             	break;
         }
@@ -1537,7 +1568,7 @@ long PropertiesBox::onCmdBrowse(FXObject* o,FXSelector s,void* p)
 long PropertiesBox::onCmdBrowseIcon(FXObject* o,FXSelector s,void* p)
 {
     FXString icon;
-    if(FXSELID(s)==ID_BIG_ICON)
+    if (FXSELID(s)==ID_BIG_ICON)
         icon = bigic->getText();
     else
         icon= miniic->getText();
@@ -1553,15 +1584,30 @@ long PropertiesBox::onCmdBrowseIcon(FXObject* o,FXSelector s,void* p)
     browseIcon.setFilename(iconpath+PATHSEPSTRING+icon);
     browseIcon.setPatternList(patterns);
 	browseIcon.setSelectMode(SELECT_FILE_EXISTING);
-    if(browseIcon.execute())
+    if (browseIcon.execute())
     {
-        FXString path=browseIcon.getFilename();
-        if(!::exists(path))
+        FXString path;
+        
+        path=browseIcon.getFilename();
+        if (!::exists(path))
             return 0;
-        if(FXSELID(s)==ID_BIG_ICON)
+        if (FXSELID(s)==ID_BIG_ICON)
+        {
+ 			// Load big icon
             bigic->setText(path);
+
+ 			FXIcon* bigicon = loadiconfile(getApp(),path,bigic->getText());
+			if (bigicon)
+				bigicbtn->setIcon(bigicon);
+		}
         else
+        {
+ 			// Load mini icon
             miniic->setText(path);
+
+		 	FXIcon* miniicon = loadiconfile(getApp(),path,miniic->getText());
+			miniicbtn->setIcon(miniicon);
+		}
     }
     return 1;
 }
@@ -1625,7 +1671,7 @@ long PropertiesBox::onUpdSizeAndPerm(FXObject* o,FXSelector s,void* p)
 				else
 					pathname=FXPath::absolute(paths[i],files[i]);
 								
-				if(lstatrep(pathname.text(),&info)!=0)
+				if (lstatrep(pathname.text(),&info)!=0)
 				{
 					continue ;
 				}
@@ -1638,7 +1684,7 @@ long PropertiesBox::onUpdSizeAndPerm(FXObject* o,FXSelector s,void* p)
 
 				// Is it a directory?
 				isDirectory=S_ISDIR(info.st_mode);
-				if(isDirectory)
+				if (isDirectory)
 				{						
 					strlcpy(buf,pathname.text(),pathname.length()+1);
 					FXuint nbfiles=0, nbsubfolders=0;
@@ -1675,10 +1721,10 @@ long PropertiesBox::onUpdSizeAndPerm(FXObject* o,FXSelector s,void* p)
 
 		getApp()->endWaitCursor();
 	}
-	recsize=FALSE;
+	recsize=false;
 
 	// Update permissions
-    if(perm->rec->getCheck())
+    if (perm->rec->getCheck())
 	{
         perm->dironly->enable();
         perm->fileonly->enable();
@@ -1691,7 +1737,7 @@ long PropertiesBox::onUpdSizeAndPerm(FXObject* o,FXSelector s,void* p)
         perm->fileonly->disable();
 	}
 
-    if(perm->own->getCheck())
+    if (perm->own->getCheck())
 	{
         perm->set->disable();
         perm->clear->disable();
@@ -1756,7 +1802,7 @@ long PropertiesBox::onCmdKeyPress(FXObject* sender,FXSelector sel,void* ptr)
 // Update the startup notification button depending on the file exec status
 long PropertiesBox::onUpdSnDisable(FXObject*,FXSelector,void*)
 {
-	FXbool usesn=getApp()->reg().readUnsignedEntry("OPTIONS","use_startup_notification",TRUE);
+	FXbool usesn=getApp()->reg().readUnsignedEntry("OPTIONS","use_startup_notification",true);
 	if (usesn && executable)
 	{
 		sngroup->enable();
