@@ -56,7 +56,7 @@ private:
 	FXLabel*	origlocation;
 	FXLabel*	linkto;
 	FXLabel*	deletiondate;
-    FXLabel*	ext;
+    FXTextField*	ext;
     FXString*	files;
     FXString*	paths;
 	FXLabel*	name_encoding;
@@ -97,7 +97,9 @@ private:
     FXTextField*	edit;
     FXTextField*	descr;
     FXTextField*	bigic;
+    FXButton*		bigicbtn;
     FXTextField*	miniic;
+    FXButton*		miniicbtn;
 	FXbool			isDirectory;
 	FXbool			isMountpoint;
 	FXbool			recsize;
