@@ -21,8 +21,10 @@
 #include "SearchWindow.h"
 
 
-// List refresh counter limit
-#define REFRESH_COUNT 100
+// List refresh counter limits
+#define REFRESH_COUNT_LIMIT 10000
+#define REFRESH_COUNT_SLOW 100
+#define REFRESH_COUNT_FAST 1000
 
 
 // Map
@@ -97,12 +99,12 @@ SearchWindow::SearchWindow(FXApp* app,const FXString& name,FXuint opts,int x,int
 	FXbool moreopts=getApp()->reg().readUnsignedEntry("SEARCH PANEL","moreoptions",0);
 	if (moreopts)
 	{
-		moreoptions->setCheck(TRUE);
+		moreoptions->setCheck(true);
 		moregroup->show();
 	}
 	else
 	{
-		moreoptions->setCheck(FALSE);
+		moreoptions->setCheck(false);
 		moregroup->hide();
 	}
 
@@ -194,8 +196,22 @@ SearchWindow::SearchWindow(FXApp* app,const FXString& name,FXuint opts,int x,int
 	new FXLabel(matrix4,_("Follow symbolic links:"),NULL,JUSTIFY_LEFT);
 	linkbtn = new FXCheckButton(matrix4,_("\tSearch while following symbolic links"),NULL,0,JUSTIFY_LEFT|LAYOUT_CENTER_Y);
 	
+	// Non recursive
+	new FXLabel(matrix4,"",NULL,JUSTIFY_LEFT);
+	new FXLabel(matrix4,_("Non recursive:"),NULL,JUSTIFY_LEFT);
+	norecbtn = new FXCheckButton(matrix4,_("\tDon't search folders recursively"),NULL,0,JUSTIFY_LEFT|LAYOUT_CENTER_Y);
+
+	// Don't search in other file systems
+	new FXLabel(matrix4,"",NULL,JUSTIFY_LEFT);
+	new FXLabel(matrix4,_("Ignore other file systems:"),NULL,JUSTIFY_LEFT);
+	nofsbtn = new FXCheckButton(matrix4,_("\tDon't search in other file systems"),NULL,0,JUSTIFY_LEFT|LAYOUT_CENTER_Y);
+
+	// Search results
+	FXHorizontalFrame *frame2=new FXHorizontalFrame(frame1,LAYOUT_SIDE_TOP|FRAME_NONE|LAYOUT_FILL_X, 0,0,0,0, 0,0,0,0);
+	searchresults=new FXLabel(frame2,"",NULL,LAYOUT_CENTER_Y|LAYOUT_FILL_X);
+
 	// Buttons
-    FXHorizontalFrame *buttons=new FXHorizontalFrame(frame1,PACK_UNIFORM_WIDTH|LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X,0,0,0,0,10,10,5,5);
+    FXHorizontalFrame *buttons=new FXHorizontalFrame(frame2,PACK_UNIFORM_WIDTH,0,0,0,0,10,10,5,5);
     
 	// Start
     startbutton = new FXButton(buttons,_("&Start\tStart the search (F3)"),NULL,this,ID_START,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT,0,0,0,0,20,20);
@@ -203,8 +219,6 @@ SearchWindow::SearchWindow(FXApp* app,const FXString& name,FXuint opts,int x,int
 	// Stop
     stopbutton = new FXButton(buttons,_("&Stop\tStop the search (Esc)"),NULL,this,ID_STOP,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT,0,0,0,0,20,20);
     
-	// Search results
-	searchresults=new FXLabel(frame1,_("Search results"),NULL,LAYOUT_TOP|LAYOUT_FILL_X);
 
 	// Search Panel
 	FXColor listbackcolor=getApp()->reg().readColorEntry("SETTINGS","listbackcolor",FXRGB(255,255,255));
@@ -354,13 +368,17 @@ SearchWindow::SearchWindow(FXApp* app,const FXString& name,FXuint opts,int x,int
 	hotkey=_parseAccel(key);
 	getAccelTable()->addAccel(hotkey,searchpanel,FXSEL(SEL_COMMAND,SearchPanel::ID_OPEN));
 
+	key=getApp()->reg().readStringEntry("KEYBINDINGS","view","Shift-F4");
+	hotkey=_parseAccel(key);	
+	getAccelTable()->addAccel(hotkey,searchpanel,FXSEL(SEL_COMMAND,SearchPanel::ID_VIEW));
+
  	key=getApp()->reg().readStringEntry("KEYBINDINGS","edit","F4");
 	hotkey=_parseAccel(key);	
 	getAccelTable()->addAccel(hotkey,searchpanel,FXSEL(SEL_COMMAND,SearchPanel::ID_EDIT));
 
-	key=getApp()->reg().readStringEntry("KEYBINDINGS","view","Shift-F4");
+ 	key=getApp()->reg().readStringEntry("KEYBINDINGS","compare","F8");
 	hotkey=_parseAccel(key);	
-	getAccelTable()->addAccel(hotkey,searchpanel,FXSEL(SEL_COMMAND,SearchPanel::ID_VIEW));
+	getAccelTable()->addAccel(hotkey,searchpanel,FXSEL(SEL_COMMAND,SearchPanel::ID_COMPARE));
 
 	key=getApp()->reg().readStringEntry("KEYBINDINGS","close","Ctrl-W");
 	hotkey=_parseAccel(key);	
@@ -372,7 +390,7 @@ SearchWindow::SearchWindow(FXApp* app,const FXString& name,FXuint opts,int x,int
     // Set text font for the warning window
 	FXString fontspec;
 	fontspec=getApp()->reg().readStringEntry("SETTINGS","textfont","Helvetica,100,normal,regular");
-	if(!fontspec.empty())
+	if (!fontspec.empty())
 	{
     	FXFont* font=new FXFont(getApp(),fontspec);
         font->create();
@@ -383,7 +401,7 @@ SearchWindow::SearchWindow(FXApp* app,const FXString& name,FXuint opts,int x,int
 	application=app;
 	count=0;
 	pid=-1;
-	running=FALSE;
+	running=false;
 }
 
 
@@ -432,16 +450,18 @@ long SearchWindow::onCmdMoreOptions(FXObject* o,FXSelector sel,void*)
 		maxsize->setValue(0);
 		mindays->setValue(0);
 		maxdays->setValue(0);
-		userbtn->setCheck(FALSE);
-		grpbtn->setCheck(FALSE);
-		typebtn->setCheck(FALSE);
-		permbtn->setCheck(FALSE);
-		emptybtn->setCheck(FALSE);
-		linkbtn->setCheck(FALSE);
+		userbtn->setCheck(false);
+		grpbtn->setCheck(false);
+		typebtn->setCheck(false);
+		permbtn->setCheck(false);
+		emptybtn->setCheck(false);
+		linkbtn->setCheck(false);
 		perm->setText("0644");
 		type->setCurrentItem(0);
 		user->setText(uid);
 		grp->setText(gid);
+		norecbtn->setCheck(false);
+		nofsbtn->setCheck(false);
 	}
 	else
 		moregroup->hide();
@@ -466,19 +486,21 @@ long SearchWindow::onCmdClose(FXObject*,FXSelector,void*)
 	maxsize->setValue(0);
 	mindays->setValue(0);
 	maxdays->setValue(0);
-	userbtn->setCheck(FALSE);
-	grpbtn->setCheck(FALSE);
-	typebtn->setCheck(FALSE);
-	permbtn->setCheck(FALSE);
-	emptybtn->setCheck(FALSE);
-	linkbtn->setCheck(FALSE);
+	userbtn->setCheck(false);
+	grpbtn->setCheck(false);
+	typebtn->setCheck(false);
+	permbtn->setCheck(false);
+	emptybtn->setCheck(false);
+	linkbtn->setCheck(false);
 	perm->setText("0644");
 	type->setCurrentItem(0);
 	user->setText(uid);
 	grp->setText(gid);
+	norecbtn->setCheck(false);
+	nofsbtn->setCheck(false);
 
-	running=FALSE;
-	searchresults->setText(_("Search results"));
+	running=false;
+	searchresults->setText("");
 
     if (pid != -1)
 		kill((-1*pid), SIGTERM); // Kills the process group
@@ -492,8 +514,6 @@ long SearchWindow::onCmdClose(FXObject*,FXSelector,void*)
 // Start the file search
 long SearchWindow::onCmdStart(FXObject*,FXSelector,void*)
 {
-	searchresults->setText(_("Search results"));
-
 	// Set the search pattern from user input
 	// Add '*' before and after the string if not present
 	FXString searchpattern;
@@ -546,6 +566,14 @@ long SearchWindow::onCmdStart(FXObject*,FXSelector,void*)
 	if (grpbtn->getCheck())
 		searchcommand += " -group " + grp->getText();
 
+	// Non recursive
+	if (norecbtn->getCheck())
+		searchcommand += " -maxdepth 1 ";
+
+	// Don't search other file systems
+	if (nofsbtn->getCheck())
+		searchcommand += " -mount ";
+
 	// File type
 	if (typebtn->getCheck())
 	{
@@ -599,13 +627,14 @@ long SearchWindow::onCmdStart(FXObject*,FXSelector,void*)
 	// Don't use standard cursor wait function
 	::setWaitCursor(getApp(),BEGIN_CURSOR);
 		
-	searchresults->setText(_("Search started - Please wait..."));
-	running=TRUE;
+	searchresults->setText(_(">>>> Search started - Please wait... <<<<"));
+	running=true;
 
 	// Execute command
 	count=0;
 	strprev="";
 	warnwindow->setText("");
+
 	execCmd(searchcommand.text());
 	
     return 1;
@@ -677,7 +706,7 @@ long SearchWindow::onReadData(FXObject*, FXSelector, void*)
 	if (running)
 	{
 		// Stop refreshing the file list
-		searchpanel->setAllowRefresh(FALSE);
+		searchpanel->setAllowRefresh(false);
 
 		nread = read(out[0], buf, 4095);
 		if (nread > 0)
@@ -688,10 +717,10 @@ long SearchWindow::onReadData(FXObject*, FXSelector, void*)
 			strbuf=strprev + buf;
 
 			// Loop over lines in strbuf
-			for(beg=0; beg<strbuf.length(); beg=end+1)
+			for (beg=0; beg<strbuf.length(); beg=end+1)
 			{
 				// If line not complete, the fragment will be used in the next line						
-				if((end=strbuf.find("\n",beg))<0)
+				if ((end=strbuf.find("\n",beg))<0)
 				{
 					end=strbuf.length();
 					strprev=strbuf.mid(beg,end-beg);
@@ -711,14 +740,15 @@ long SearchWindow::onReadData(FXObject*, FXSelector, void*)
 						if (searchpanel->appendItem(pathname))						
 							count++;
 						
-						// Refresh file list
-						if (count%REFRESH_COUNT == 0)
+						// Refresh file list (two speeds depending on the number of items)
+						FXuint cnt = (count < REFRESH_COUNT_LIMIT ? count%REFRESH_COUNT_SLOW : count%REFRESH_COUNT_FAST);
+						if (cnt == 0)
 						{
 							searchpanel->setCurrentItem(count-1);
 							searchpanel->setStatusText(FXStringVal(count)+_(" items"));				
 							getApp()->forceRefresh();
 							getApp()->repaint();
-						}						
+						}													
 					}
 					else
 					{
@@ -739,8 +769,8 @@ long SearchWindow::onReadData(FXObject*, FXSelector, void*)
 		{
 			waitpid(pid, &status, 0);		
 			application->removeInput(out[0], INPUT_READ);
-			searchresults->setText(_("Search results"));
-			running=FALSE;
+			searchresults->setText(_(">>>> Search results <<<<"));
+			running=false;
 
 			// Don't use standard cursor wait function
 			::setWaitCursor(getApp(),END_CURSOR);
@@ -750,7 +780,7 @@ long SearchWindow::onReadData(FXObject*, FXSelector, void*)
 			getApp()->repaint();
 
 			// Force file list refresh
-			searchpanel->setAllowRefresh(TRUE);
+			searchpanel->setAllowRefresh(true);
 			searchpanel->onCmdRefresh(0,0,0);
 		}
 	
@@ -773,14 +803,14 @@ long SearchWindow::onCmdStop(FXObject*,FXSelector,void*)
 	if (running)
 	{
 		::setWaitCursor(getApp(),END_CURSOR);
-		running=FALSE;
-		searchresults->setText(_("Search stopped..."));
+		running=false;
+		searchresults->setText(_(">>>> Search stopped... <<<<"));
 
 		if (pid != -1)
 			kill((-1*pid), SIGTERM); // Kills the process group
 
 		application->removeInput(out[0], INPUT_READ);
-		searchpanel->setAllowRefresh(TRUE);
+		searchpanel->setAllowRefresh(true);
 	}
 	
     return 1;
@@ -820,6 +850,8 @@ long SearchWindow::onUpdStop(FXObject*,FXSelector,void*)
 		type->disable();
 		user->disable();
 		grp->disable();
+		norecbtn->disable();
+		nofsbtn->disable();
 	}
 	else
 	{
@@ -851,6 +883,8 @@ long SearchWindow::onUpdStop(FXObject*,FXSelector,void*)
 		type->enable();
 		user->enable();
 		grp->enable();
+		norecbtn->enable();
+		nofsbtn->enable();
 	}
 
     return 1;
@@ -875,6 +909,10 @@ void SearchWindow::show(FXuint placement)
 	// Clear all file list items
 	searchpanel->clearItems();
 
+	// Set focus on the find search field and select all chars
+	findfile->setFocus();
+	findfile->selectAll();
+	
     // Pop the window
     FXTopWindow::show(placement);
 }
@@ -903,7 +941,7 @@ long SearchWindow::onKeyPress(FXObject* sender,FXSelector sel,void* ptr)
 	}
 
 	// Shift-F10 was pressed : open popup menu
-	else if(event->state&SHIFTMASK && event->code==KEY_F10)
+	else if (event->state&SHIFTMASK && event->code==KEY_F10)
     {
 		searchpanel->handle(sender,FXSEL(SEL_COMMAND,SearchPanel::ID_POPUP_MENU),ptr);
         return 1;
@@ -912,7 +950,7 @@ long SearchWindow::onKeyPress(FXObject* sender,FXSelector sel,void* ptr)
 	// Any other key was pressed : handle the pressed key in the usual way
     else
 	{
-		if(FXTopWindow::onKeyPress(sender,sel,ptr))
+		if (FXTopWindow::onKeyPress(sender,sel,ptr))
         	return 1;
 	}
 		
@@ -944,7 +982,7 @@ long SearchWindow::onCmdBrowsePath(FXObject* o,FXSelector s,void* p)
 	
 	// Browse files in mixed mode
 	browse.setSelectMode(SELECT_FILE_DIRECTORY);
-	if(browse.execute())
+	if (browse.execute())
 	{
 	  FXString path=browse.getFilename();
 	  wheredir->setText(path);
@@ -1007,16 +1045,18 @@ long SearchWindow::onCmdResetOptions(FXObject* o,FXSelector sel,void*)
 	maxsize->setValue(0);
 	mindays->setValue(0);
 	maxdays->setValue(0);
-	userbtn->setCheck(FALSE);
-	grpbtn->setCheck(FALSE);
-	typebtn->setCheck(FALSE);
-	permbtn->setCheck(FALSE);
-	emptybtn->setCheck(FALSE);
-	linkbtn->setCheck(FALSE);
+	userbtn->setCheck(false);
+	grpbtn->setCheck(false);
+	typebtn->setCheck(false);
+	permbtn->setCheck(false);
+	emptybtn->setCheck(false);
+	linkbtn->setCheck(false);
 	perm->setText("0644");
 	type->setCurrentItem(0);
 	user->setText(uid);
 	grp->setText(gid);
+	norecbtn->setCheck(false);
+	nofsbtn->setCheck(false);
 
 	return 1;
 }
