@@ -34,7 +34,7 @@ FXDEFMAP(TextLabel) TextLabelMap[]=
     FXMAPFUNC(SEL_FOCUSOUT,0,TextLabel::onFocusOut),
     FXMAPFUNC(SEL_FOCUS_SELF,0,TextLabel::onFocusSelf),
     FXMAPFUNC(SEL_UPDATE,TextLabel::ID_COPY_SEL,TextLabel::onUpdHaveSelection),
-    FXMAPFUNC(SEL_UPDATE,TextLabel::ID_SELECT_ALL,TextLabel::onUpdSelectAll),
+    FXMAPFUNC(SEL_UPDATE,TextLabel::ID_SELECT_ALL,TextLabel::onUpdselectAll),
     FXMAPFUNC(SEL_COMMAND,TextLabel::ID_CURSOR_HOME,TextLabel::onCmdCursorHome),
     FXMAPFUNC(SEL_COMMAND,TextLabel::ID_CURSOR_END,TextLabel::onCmdCursorEnd),
     FXMAPFUNC(SEL_COMMAND,TextLabel::ID_CURSOR_RIGHT,TextLabel::onCmdCursorRight),
@@ -45,7 +45,7 @@ FXDEFMAP(TextLabel) TextLabelMap[]=
     FXMAPFUNC(SEL_COMMAND,TextLabel::ID_CURSOR_WORD_END,TextLabel::onCmdCursorWordEnd),
     FXMAPFUNC(SEL_COMMAND,TextLabel::ID_MARK,TextLabel::onCmdMark),
     FXMAPFUNC(SEL_COMMAND,TextLabel::ID_EXTEND,TextLabel::onCmdExtend),
-    FXMAPFUNC(SEL_COMMAND,TextLabel::ID_SELECT_ALL,TextLabel::onCmdSelectAll),
+    FXMAPFUNC(SEL_COMMAND,TextLabel::ID_SELECT_ALL,TextLabel::onCmdselectAll),
     FXMAPFUNC(SEL_COMMAND,TextLabel::ID_DESELECT_ALL,TextLabel::onCmdDeselectAll),
     FXMAPFUNC(SEL_COMMAND,TextLabel::ID_COPY_SEL,TextLabel::onCmdCopySel),
 };
@@ -372,7 +372,7 @@ bool TextLabel::canFocus() const
 void TextLabel::setFocus()
 {
     FXFrame::setFocus();
-    setDefault(TRUE);
+    setDefault(true);
     flags&=~FLAG_UPDATE;
     if (getApp()->hasInputMethod())
         createComposeContext();
@@ -612,7 +612,7 @@ long TextLabel::onUpdHaveSelection(FXObject* sender,FXSelector,void* ptr)
 
 
 // Update somebody who works on the selection
-long TextLabel::onUpdSelectAll(FXObject* sender,FXSelector,void* ptr)
+long TextLabel::onUpdselectAll(FXObject* sender,FXSelector,void* ptr)
 {
     sender->handle(this,contents.empty()?FXSEL(SEL_COMMAND,ID_DISABLE):FXSEL(SEL_COMMAND,ID_ENABLE),ptr);
     return 1;
@@ -817,7 +817,7 @@ int TextLabel::coord(int i) const
 }
 
 
-// Return TRUE if position is visible
+// Return true if position is visible
 FXbool TextLabel::isPosVisible(int pos) const
 {
     if (0<=pos && pos<=contents.length())
@@ -825,11 +825,11 @@ FXbool TextLabel::isPosVisible(int pos) const
         register int x=coord(contents.validate(pos));
         return border+padleft<=x && x<=width-border-padright;
     }
-    return FALSE;
+    return false;
 }
 
 
-// Return TRUE if position pos is selected
+// Return true if position pos is selected
 FXbool TextLabel::isPosSelected(int pos) const
 {
     return hasSelection() && FXMIN(anchor,cursor)<=pos && pos<=FXMAX(anchor,cursor);
@@ -1171,7 +1171,7 @@ long TextLabel::onCmdExtend(FXObject*,FXSelector,void*)
 
 
 // Select All
-long TextLabel::onCmdSelectAll(FXObject*,FXSelector,void*)
+long TextLabel::onCmdselectAll(FXObject*,FXSelector,void*)
 {
     selectAll();
     makePositionVisible(cursor);
@@ -1344,9 +1344,9 @@ FXbool TextLabel::killSelection()
     {
         releaseSelection();
         update(border,border,width-(border<<1),height-(border<<1));
-        return TRUE;
+        return true;
     }
-    return FALSE;
+    return false;
 }
 
 
@@ -1356,7 +1356,7 @@ FXbool TextLabel::selectAll()
     setAnchorPos(0);
     setCursorPos(contents.length());
     extendSelection(cursor);
-    return TRUE;
+    return true;
 }
 
 
@@ -1366,7 +1366,7 @@ FXbool TextLabel::setSelection(int pos,int len)
     setAnchorPos(pos);
     setCursorPos(pos+len);
     extendSelection(cursor);
-    return TRUE;
+    return true;
 }
 
 
@@ -1375,7 +1375,7 @@ FXbool TextLabel::extendSelection(int pos)
 {
 	// Don't select text if ncols=0
 	if (columns==0)
-		return TRUE;
+		return true;
 		
 	FXDragType types[4];
 
@@ -1399,7 +1399,7 @@ FXbool TextLabel::extendSelection(int pos)
     }
 
     update(border,border,width-(border<<1),height-(border<<1));
-    return TRUE;
+    return true;
 }
 
 
