@@ -56,7 +56,7 @@ FXTextInsert::FXTextInsert(FXText* txt,int p,int ni,const char* ins):FXTextComma
 // Undo an insert removes the inserted text
 void FXTextInsert::undo()
 {
-    text->removeText(pos,nins,TRUE);
+    text->removeText(pos,nins,true);
     text->setCursorPos(pos);
     text->makePositionVisible(pos);
 }
@@ -65,7 +65,7 @@ void FXTextInsert::undo()
 // Redo an insert inserts the same old text again
 void FXTextInsert::redo()
 {
-    text->insertText(pos,buffer,nins,TRUE);
+    text->insertText(pos,buffer,nins,true);
     text->setCursorPos(pos+nins);
     text->makePositionVisible(pos+nins);
 }
@@ -84,7 +84,7 @@ FXTextDelete::FXTextDelete(FXText* txt,int p,int nd,const char* del):FXTextComma
 // Undo a delete reinserts the old text
 void FXTextDelete::undo()
 {
-    text->insertText(pos,buffer,ndel,TRUE);
+    text->insertText(pos,buffer,ndel,true);
     text->setCursorPos(pos+ndel);
     text->makePositionVisible(pos+ndel);
 }
@@ -93,7 +93,7 @@ void FXTextDelete::undo()
 // Redo a delete removes it again
 void FXTextDelete::redo()
 {
-    text->removeText(pos,ndel,TRUE);
+    text->removeText(pos,ndel,true);
     text->setCursorPos(pos);
     text->makePositionVisible(pos);
 }
@@ -113,7 +113,7 @@ FXTextReplace::FXTextReplace(FXText* txt,int p,int nd,int ni,const char* del,con
 // Undo a replace reinserts the old text
 void FXTextReplace::undo()
 {
-    text->replaceText(pos,nins,buffer,ndel,TRUE);
+    text->replaceText(pos,nins,buffer,ndel,true);
     text->setCursorPos(pos+ndel);
     text->makePositionVisible(pos+ndel);
 }
@@ -122,7 +122,7 @@ void FXTextReplace::undo()
 // Redo a replace reinserts the new text
 void FXTextReplace::redo()
 {
-    text->replaceText(pos,ndel,buffer+ndel,nins,TRUE);
+    text->replaceText(pos,ndel,buffer+ndel,nins,true);
     text->setCursorPos(pos+nins);
     text->makePositionVisible(pos+nins);
 }
@@ -212,7 +212,7 @@ Preferences::Preferences(WriteWindow *owner):DialogBox(owner,_("XFileWrite Prefe
 
     new FXLabel(matrix,_("Strip carriage returns:")+(FXString)"                ",NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
     stripcr = new FXCheckButton(matrix,FXString::null,NULL,0,LAYOUT_LEFT|LAYOUT_CENTER_Y|LAYOUT_FILL_ROW,0,0,0,0, 0,0,0,0);
-    int stripreturn=getApp()->reg().readIntEntry("OPTIONS","stripreturn",FALSE);
+    int stripreturn=getApp()->reg().readIntEntry("OPTIONS","stripreturn",false);
 	stripcr->setCheck(stripreturn);
 
     // Second tab - Colors
@@ -495,7 +495,6 @@ FXDEFMAP(WriteWindow) WriteWindowMap[]=
 	FXMAPFUNC(SEL_COMMAND,WriteWindow::ID_OPEN,WriteWindow::onCmdOpen),
 	FXMAPFUNC(SEL_COMMAND,WriteWindow::ID_OPEN_RECENT,WriteWindow::onCmdOpenRecent),
 	FXMAPFUNC(SEL_COMMAND,WriteWindow::ID_SAVE,WriteWindow::onCmdSave),
-	FXMAPFUNC(SEL_UPDATE,WriteWindow::ID_SAVE,WriteWindow::onUpdSave),
 	FXMAPFUNC(SEL_COMMAND,WriteWindow::ID_SAVEAS,WriteWindow::onCmdSaveAs),
 	FXMAPFUNC(SEL_COMMAND,WriteWindow::ID_FONT,WriteWindow::onCmdFont),
 	FXMAPFUNC(SEL_COMMAND,WriteWindow::ID_PRINT,WriteWindow::onCmdPrint),
@@ -519,6 +518,9 @@ FXDEFMAP(WriteWindow) WriteWindowMap[]=
 	FXMAPFUNC(SEL_COMMAND,WriteWindow::ID_GOTO_LINE,WriteWindow::onCmdGotoLine),
 	FXMAPFUNCS(SEL_UPDATE, WriteWindow::ID_WINDOW_1,WriteWindow::ID_WINDOW_50,WriteWindow::onUpdWindow),
 	FXMAPFUNCS(SEL_COMMAND,WriteWindow::ID_WINDOW_1,WriteWindow::ID_WINDOW_50,WriteWindow::onCmdWindow),
+	FXMAPFUNC(SEL_UPDATE,WriteWindow::ID_SAVE,WriteWindow::onUpdSave),
+	FXMAPFUNC(SEL_UPDATE,WriteWindow::ID_SAVEAS,WriteWindow::onUpdReadOnly),
+	FXMAPFUNC(SEL_UPDATE,WriteWindow::ID_REPLACE,WriteWindow::onUpdReadOnly),
 };
 
 
@@ -526,7 +528,7 @@ FXDEFMAP(WriteWindow) WriteWindowMap[]=
 FXIMPLEMENT(WriteWindow,FXMainWindow,WriteWindowMap,ARRAYNUMBER(WriteWindowMap))
 
 // Make some windows
-WriteWindow::WriteWindow(XFileWrite* a,const FXString& file):FXMainWindow(a,"XFileWrite",NULL,NULL,DECOR_ALL),mrufiles(a)
+WriteWindow::WriteWindow(XFileWrite* a,const FXString& file, const FXbool _readonly):FXMainWindow(a,"XFileWrite",NULL,NULL,DECOR_ALL),mrufiles(a)
 {
     FXHotKey hotkey;
 	FXString key;
@@ -595,6 +597,11 @@ WriteWindow::WriteWindow(XFileWrite* a,const FXString& file):FXMainWindow(a,"XFi
     editor->setTextStyle(editor->getTextStyle()&~TEXT_SHOWACTIVE);
     editor->setMarginLeft(10);
 
+	// Read only
+	readonly=_readonly;
+	if (readonly)
+		editor->setTextStyle(editor->getTextStyle()|TEXT_READONLY);
+
     // Show insert mode in status bar
     FXLabel* overstrike=new FXLabel(statusbar,FXString::null,NULL,FRAME_SUNKEN|LAYOUT_RIGHT|LAYOUT_CENTER_Y,0,0,0,0,2,2,1,1);
     overstrike->setTarget(this);
@@ -652,10 +659,10 @@ WriteWindow::WriteWindow(XFileWrite* a,const FXString& file):FXMainWindow(a,"XFi
     new FXButton(toolbar,TAB+_("Copy")+PARS(key)+TAB+_("Copy selection to clipboard.")+PARS(key),copy_clpicon,editor,FXText::ID_COPY_SEL,ICON_ABOVE_TEXT|BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
 
 	key=getApp()->reg().readStringEntry("KEYBINDINGS","cut","Ctrl-X");
-    new FXButton(toolbar,TAB+_("Cut")+PARS(key)+TAB+_("Cut selection to clipboard.")+PARS(key),cut_clpicon,editor,FXText::ID_CUT_SEL,ICON_ABOVE_TEXT|BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
+    cut = new FXButton(toolbar,TAB+_("Cut")+PARS(key)+TAB+_("Cut selection to clipboard.")+PARS(key),cut_clpicon,editor,FXText::ID_CUT_SEL,ICON_ABOVE_TEXT|BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
 
 	key=getApp()->reg().readStringEntry("KEYBINDINGS","paste","Ctrl-V");
-    new FXButton(toolbar,TAB+_("Paste")+PARS(key)+TAB+_("Paste clipboard.")+PARS(key),paste_clpicon,editor,FXText::ID_PASTE_SEL,ICON_ABOVE_TEXT|BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
+    paste = new FXButton(toolbar,TAB+_("Paste")+PARS(key)+TAB+_("Paste clipboard.")+PARS(key),paste_clpicon,editor,FXText::ID_PASTE_SEL,ICON_ABOVE_TEXT|BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
 
     // Spacer
     new FXSeparator(toolbar,SEPARATOR_GROOVE);
@@ -681,7 +688,7 @@ WriteWindow::WriteWindow(XFileWrite* a,const FXString& file):FXMainWindow(a,"XFi
 	key=getApp()->reg().readStringEntry("KEYBINDINGS","search","Ctrl-F");
     new FXButton(toolbar,TAB+_("Search")+PARS(key)+TAB+_("Search text.")+PARS(key),searchicon,this,WriteWindow::ID_SEARCH,ICON_ABOVE_TEXT|BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
 
-	key=getApp()->reg().readStringEntry("KEYBINDINGS","search_prev","Shift-Ctrl-G");
+	key=getApp()->reg().readStringEntry("KEYBINDINGS","search_prev","Ctrl-Shift-G");
     new FXButton(toolbar,TAB+_("Search selection backward")+PARS(key)+TAB+_("Search backward for selected text.")+PARS(key),searchprevicon,this,WriteWindow::ID_SEARCH_BACK_SEL,ICON_ABOVE_TEXT|BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
 
 	key=getApp()->reg().readStringEntry("KEYBINDINGS","search_next","Ctrl-G");
@@ -779,13 +786,13 @@ WriteWindow::WriteWindow(XFileWrite* a,const FXString& file):FXMainWindow(a,"XFi
 
 	key=getApp()->reg().readStringEntry("KEYBINDINGS","cut","Ctrl-X");
 	text=_("Cu&t")+TABS(key)+_("Cut selection to clipboard.")+PARS(key);
-    mc=new FXMenuCommand(editmenu,text,cut_clpicon,editor,FXText::ID_CUT_SEL);
+    cutmc=new FXMenuCommand(editmenu,text,cut_clpicon,editor,FXText::ID_CUT_SEL);
 	hotkey=_parseAccel(key);
 	getAccelTable()->addAccel(hotkey,mc,FXSEL(SEL_COMMAND,FXMenuCommand::ID_ACCEL));
 
 	key=getApp()->reg().readStringEntry("KEYBINDINGS","paste","Ctrl-V");
 	text=_("&Paste")+TABS(key)+_("Paste from clipboard.")+PARS(key);
-    mc=new FXMenuCommand(editmenu,text,paste_clpicon,editor,FXText::ID_PASTE_SEL);
+    pastemc=new FXMenuCommand(editmenu,text,paste_clpicon,editor,FXText::ID_PASTE_SEL);
 	hotkey=_parseAccel(key);
 	getAccelTable()->addAccel(hotkey,mc,FXSEL(SEL_COMMAND,FXMenuCommand::ID_ACCEL));
 
@@ -796,7 +803,7 @@ WriteWindow::WriteWindow(XFileWrite* a,const FXString& file):FXMainWindow(a,"XFi
 	hotkey=_parseAccel(key);
 	getAccelTable()->addAccel(hotkey,mc,FXSEL(SEL_COMMAND,FXMenuCommand::ID_ACCEL));
 
-	key=getApp()->reg().readStringEntry("KEYBINDINGS","upper_case","Shift-Ctrl-U");
+	key=getApp()->reg().readStringEntry("KEYBINDINGS","upper_case","Ctrl-Shift-U");
 	text=_("Upp&er-case")+TABS(key)+_("Change to upper case.")+PARS(key);
     mc=new FXMenuCommand(editmenu,text,uppercaseicon,editor,FXText::ID_UPPER_CASE);
 	hotkey=_parseAccel(key);
@@ -832,7 +839,7 @@ WriteWindow::WriteWindow(XFileWrite* a,const FXString& file):FXMainWindow(a,"XFi
 	hotkey=_parseAccel(key);
 	getAccelTable()->addAccel(hotkey,mc,FXSEL(SEL_COMMAND,FXMenuCommand::ID_ACCEL));
 
-	key=getApp()->reg().readStringEntry("KEYBINDINGS","search_prev","Shift-Ctrl-G");
+	key=getApp()->reg().readStringEntry("KEYBINDINGS","search_prev","Ctrl-Shift-G");
 	text=_("Search sel. &backward")+TABS(key)+_("Search backward for selected text.")+PARS(key);
     mc=new FXMenuCommand(searchmenu,text,searchprevicon,this,WriteWindow::ID_SEARCH_BACK_SEL);
 	hotkey=_parseAccel(key);
@@ -938,16 +945,16 @@ WriteWindow::WriteWindow(XFileWrite* a,const FXString& file):FXMainWindow(a,"XFi
 
     // Initialize file name
     filename=file;
-    filenameset=FALSE;
+    filenameset=false;
     filetime=0;
 
     // Initialize other stuff
-    stripcr=FALSE;
-    linesnum=FALSE;
+    stripcr=false;
+    linesnum=false;
     undolist.mark();
 
 	// Initialize window position and size
-	fromreg=TRUE;
+	fromreg=true;
 	ww=0;
 	hh=0;
 	xx=0;
@@ -969,7 +976,7 @@ void WriteWindow::create()
     windowmenu->create();
     helpmenu->create();
     popupmenu->create();
-    if(!urilistType)
+    if (!urilistType)
         urilistType=getApp()->registerDragType(urilistTypeName);
     show(PLACEMENT_DEFAULT);
     editor->setFocus();
@@ -1028,20 +1035,20 @@ FXbool WriteWindow::loadFile(const FXString& file)
     char *text;
 
     // Opened file?
-    if(!textfile.isOpen())
+    if (!textfile.isOpen())
     {
         MessageBox::error(this,BOX_OK,_("Error Loading File"),_("Unable to open file: %s"),file.text());
-        return FALSE;
+        return false;
     }
 
     // Get file size
     size=textfile.size();
 
     // Make buffer to load file
-    if(!FXMALLOC(&text,char,size))
+    if (!FXMALLOC(&text,char,size))
     {
         MessageBox::error(this,BOX_OK,_("Error Loading File"),_("File is too big: %s (%d bytes)"),file.text(),size);
-        return FALSE;
+        return false;
     }
 
     // Set wait cursor
@@ -1049,21 +1056,21 @@ FXbool WriteWindow::loadFile(const FXString& file)
 
     // Read the file
     n=textfile.readBlock(text,size);
-    if(n<0)
+    if (n<0)
     {
         FXFREE(&text);
         MessageBox::error(this,BOX_OK,_("Error Loading File"),_("Unable to read file: %s"),file.text());
         getApp()->endWaitCursor();
-        return FALSE;
+        return false;
     }
 
     // Strip carriage returns
-    if(stripcr)
+    if (stripcr)
     {
-        for(i=j=0; j<n; j++)
+        for (i=j=0; j<n; j++)
         {
             c=text[j];
-            if(c!='\r')
+            if (c!='\r')
                 text[i++]=c;
         }
         n=i;
@@ -1088,7 +1095,7 @@ FXbool WriteWindow::loadFile(const FXString& file)
 
     mrufiles.appendFile(file);
     filetime=FXStat::modified(file);
-    filenameset=TRUE;
+    filenameset=true;
     filename=file;
 
     // Clear undo records
@@ -1097,7 +1104,7 @@ FXbool WriteWindow::loadFile(const FXString& file)
     // Mark undo state as clean (saved)
     undolist.mark();
 
-    return TRUE;
+    return true;
 }
 
 
@@ -1111,20 +1118,20 @@ FXbool WriteWindow::saveFile(const FXString& file)
     char *text;
 
     // Opened file?
-    if(!textfile.isOpen())
+    if (!textfile.isOpen())
     {
         MessageBox::error(this,BOX_OK,_("Error Saving File"),_("Unable to open file: %s"),file.text());
-        return FALSE;
+        return false;
     }
 
     // Get size
     size=editor->getLength();
 
     // Alloc buffer
-    if(!FXMALLOC(&text,char,size+1))
+    if (!FXMALLOC(&text,char,size+1))
     {
         MessageBox::error(this,BOX_OK,_("Error Saving File"),_("File is too big: %s"),file.text());
-        return FALSE;
+        return false;
     }
 
     // Set wait cursor
@@ -1143,18 +1150,18 @@ FXbool WriteWindow::saveFile(const FXString& file)
     getApp()->endWaitCursor();
 
     // Were we able to write it all?
-    if(n!=size)
+    if (n!=size)
     {
         MessageBox::error(this,BOX_OK,_("Error Saving File"),_("File: %s truncated."),file.text());
-        return FALSE;
+        return false;
     }
 
     mrufiles.appendFile(file);
     filetime=FXStat::modified(file);
-    filenameset=TRUE;
+    filenameset=true;
     filename=file;
     undolist.mark();
-    return TRUE;
+    return true;
 }
 
 
@@ -1162,9 +1169,9 @@ FXbool WriteWindow::saveFile(const FXString& file)
 FXString WriteWindow::unique() const
 {
     FXString name=_("untitled");
-    for(int i=1; i<2147483647; i++)
+    for (int i=1; i<2147483647; i++)
     {
-        if(!findWindow(name))
+        if (!findWindow(name))
         	break;
         name.format(_("untitled%d"),i);
     }
@@ -1175,9 +1182,9 @@ FXString WriteWindow::unique() const
 // Find an as yet untitled, unedited window
 WriteWindow *WriteWindow::findUnused() const
 {
-    for(int w=0; w<getApp()->windowlist.no(); w++)
+    for (int w=0; w<getApp()->windowlist.no(); w++)
     {
-        if(!getApp()->windowlist[w]->isFilenameSet() && !getApp()->windowlist[w]->isModified())
+        if (!getApp()->windowlist[w]->isFilenameSet() && !getApp()->windowlist[w]->isModified())
             return getApp()->windowlist[w];
     }
     return NULL;
@@ -1187,9 +1194,9 @@ WriteWindow *WriteWindow::findUnused() const
 // Find window, if any, currently editing the given file
 WriteWindow *WriteWindow::findWindow(const FXString& file) const
 {
-    for(int w=0; w<getApp()->windowlist.no(); w++)
+    for (int w=0; w<getApp()->windowlist.no(); w++)
     {
-        if(getApp()->windowlist[w]->getFilename()==file)
+        if (getApp()->windowlist[w]->getFilename()==file)
             return getApp()->windowlist[w];
     }
     return NULL;
@@ -1227,7 +1234,7 @@ void WriteWindow::loadConfig()
 
     // Font
     fontspec=getApp()->reg().readStringEntry("OPTIONS","textfont","");
-    if(!fontspec.empty())
+    if (!fontspec.empty())
     {
         font=new FXFont(getApp(),fontspec);
         font->create();
@@ -1239,7 +1246,7 @@ void WriteWindow::loadConfig()
 	reg_xfe->read();
 	
     // Get value of the retain window position flag
-	save_win_pos=reg_xfe->readUnsignedEntry("SETTINGS","save_win_pos",FALSE);
+	save_win_pos=reg_xfe->readUnsignedEntry("SETTINGS","save_win_pos",false);
 
 	delete reg_xfe;
 
@@ -1251,10 +1258,10 @@ void WriteWindow::loadConfig()
 	}
 
     // Showing the status line?
-    hidestatus=getApp()->reg().readIntEntry("OPTIONS","hidestatus",FALSE);
+    hidestatus=getApp()->reg().readIntEntry("OPTIONS","hidestatus",false);
 
     // Showing the tool bar?
-    hidetoolbar=getApp()->reg().readIntEntry("OPTIONS","hidetoolbar",FALSE);
+    hidetoolbar=getApp()->reg().readIntEntry("OPTIONS","hidetoolbar",false);
 
     // Highlight match time
     hilitematchtime=getApp()->reg().readIntEntry("OPTIONS","hilitematchtime",3000);
@@ -1267,8 +1274,8 @@ void WriteWindow::loadConfig()
     tabcols=getApp()->reg().readIntEntry("OPTIONS","tabcols",8);
 
     // Various flags
-    stripcr=getApp()->reg().readIntEntry("OPTIONS","stripreturn",FALSE);
-    linesnum=getApp()->reg().readIntEntry("OPTIONS","linesnum",FALSE);
+    stripcr=getApp()->reg().readIntEntry("OPTIONS","stripreturn",false);
+    linesnum=getApp()->reg().readIntEntry("OPTIONS","linesnum",false);
 
     // Change the colors
     editor->setTextColor(textfore);
@@ -1283,15 +1290,15 @@ void WriteWindow::loadConfig()
 
 
     // Hide statusline
-    if(hidestatus)
+    if (hidestatus)
     	statusbar->hide();
 
     // Hide toolbar
-    if(hidetoolbar)
+    if (hidetoolbar)
     	toolbar->hide();
 
     // Wrap mode
-    if(wrapping)
+    if (wrapping)
         editor->setTextStyle(editor->getTextStyle()|TEXT_WORDWRAP);
     else
         editor->setTextStyle(editor->getTextStyle()&~TEXT_WORDWRAP);
@@ -1420,7 +1427,7 @@ long WriteWindow::onCmdFont(FXObject*,FXSelector,void*)
     FXFontDesc fontdesc;
     editor->getFont()->getFontDesc(fontdesc);
     fontdlg.setFontSelection(fontdesc);
-    if(fontdlg.execute())
+    if (fontdlg.execute())
     {
         FXFont *oldfont=font;
         fontdlg.getFontSelection(fontdesc);
@@ -1437,7 +1444,7 @@ long WriteWindow::onCmdFont(FXObject*,FXSelector,void*)
 // New
 long WriteWindow::onCmdNew(FXObject*,FXSelector,void*)
 {
-    WriteWindow *window=new WriteWindow(getApp(),unique());
+    WriteWindow *window=new WriteWindow(getApp(),unique(),readonly);
 
 	// Smooth scrolling
 	window->setSmoothScroll(smoothscroll);
@@ -1470,26 +1477,26 @@ long WriteWindow::onCmdOpen(FXObject*,FXSelector,void*)
     opendialog.setSelectMode(SELECTFILE_MULTIPLE);
     opendialog.setPatternList(patterns);
     opendialog.setDirectory(FXPath::directory(filename));
-    if(opendialog.execute())
+    if (opendialog.execute())
     {
         FXString* files=opendialog.getFilenames();
         FXuint i=0;
         while (files[i]!=FXString::null)
         {
             WriteWindow *window=findWindow(files[i]);
-            if(!window)
+            if (!window)
             {
                 window=findUnused();
-                if(!window)
+                if (!window)
                 {
  					// New window
-					window=new WriteWindow(getApp(),unique());
+					window=new WriteWindow(getApp(),unique(),readonly);
 					
 					// Smooth scrolling
 					window->setSmoothScroll(smoothscroll);
 
 					// Set the size and position of the new window
-					window->fromreg=FALSE;
+					window->fromreg=false;
 					window->ww=getWidth();
 					window->hh=getHeight();
 					window->xx=getX();
@@ -1516,12 +1523,12 @@ long WriteWindow::onCmdOpenRecent(FXObject*,FXSelector,void* ptr)
 {
     FXString file=(const char*)ptr;
     WriteWindow *window=findWindow(file);
-    if(!window)
+    if (!window)
     {
         window=findUnused();
-        if(!window)
+        if (!window)
         {
-            window=new WriteWindow(getApp(),unique());
+            window=new WriteWindow(getApp(),unique(),readonly);
 
 			// Smooth scrolling
 			window->setSmoothScroll(smoothscroll);
@@ -1541,14 +1548,14 @@ long WriteWindow::onEditDNDDrop(FXObject*,FXSelector,void*)
 {
     char *data;
     FXuint len;
-    if(getDNDData(FROM_DRAGNDROP,urilistType,(FXuchar*&)data,len))
+    if (getDNDData(FROM_DRAGNDROP,urilistType,(FXuchar*&)data,len))
     {
         FXString urilist(data,len);
         FXString file=FXURL::fileFromURL(urilist.before('\r'));
         FXFREE(&data);
-        if(file.empty())
+        if (file.empty())
             return 1;
-        if(!saveChanges())
+        if (!saveChanges())
             return 1;
         loadFile(file);
         return 1;
@@ -1560,7 +1567,7 @@ long WriteWindow::onEditDNDDrop(FXObject*,FXSelector,void*)
 // See if a filename is being dragged over the window
 long WriteWindow::onEditDNDMotion(FXObject*,FXSelector,void*)
 {
-    if(offeredDNDType(FROM_DRAGNDROP,urilistType))
+    if (offeredDNDType(FROM_DRAGNDROP,urilistType))
     {
         acceptDrop(DRAG_COPY);
         return 1;
@@ -1574,37 +1581,37 @@ FXbool WriteWindow::saveChanges()
 {
     FXuint answer;
     FXString file;
-    if(isModified())
+    if (isModified())
     {
         answer=MessageBox::question(this,BOX_YES_NO_CANCEL,_("Unsaved Document"),_("Save %s to file?"),FXPath::name(filename).text());
-        if(answer==BOX_CLICKED_CANCEL)
-        	return FALSE;
-        if(answer==BOX_CLICKED_YES)
+        if (answer==BOX_CLICKED_CANCEL)
+        	return false;
+        if (answer==BOX_CLICKED_YES)
         {
             file=filename;
-            if(!filenameset)
+            if (!filenameset)
             {
 				FileDialog savedialog(this,_("Save Document"));                
 				savedialog.setSelectMode(SELECTFILE_ANY);
                 savedialog.setFilename(file);
-                if(!savedialog.execute())
-                	return FALSE;
+                if (!savedialog.execute())
+                	return false;
                 file=savedialog.getFilename();
-                if(FXStat::exists(file))
-                    if(BOX_CLICKED_NO==MessageBox::question(this,BOX_YES_NO,_("Overwrite Document"),_("Overwrite existing document: %s?"),file.text()))
-                    	return FALSE;
+                if (FXStat::exists(file))
+                    if (BOX_CLICKED_NO==MessageBox::question(this,BOX_YES_NO,_("Overwrite Document"),_("Overwrite existing document: %s?"),file.text()))
+                    	return false;
            }
             saveFile(file);
         }
     }
-    return TRUE;
+    return true;
 }
 
 
 // Save
 long WriteWindow::onCmdSave(FXObject* sender,FXSelector sel,void* ptr)
 {
-    if(!filenameset)
+    if (!filenameset)
     	return onCmdSaveAs(sender,sel,ptr);
     saveFile(filename);
     return 1;
@@ -1619,6 +1626,24 @@ long WriteWindow::onUpdSave(FXObject* sender,FXSelector,void*)
 }
 
 
+
+// Disable menus and buttons when read only
+long WriteWindow::onUpdReadOnly(FXObject* sender,FXSelector,void*)
+{
+    sender->handle(this,readonly?FXSEL(SEL_COMMAND,ID_DISABLE):FXSEL(SEL_COMMAND,ID_ENABLE),NULL);
+    
+    // Disable cut and paste commands
+    // (note: it seems that the context menu commands can't be disabled)
+    paste->disable();
+    pastemc->disable();
+    cut->disable();
+    cutmc->disable();
+    
+    return 1;
+}
+
+
+
 // Save As
 long WriteWindow::onCmdSaveAs(FXObject*,FXSelector,void*)
 {
@@ -1626,12 +1651,12 @@ long WriteWindow::onCmdSaveAs(FXObject*,FXSelector,void*)
     FXString file=filename;
     savedialog.setSelectMode(SELECTFILE_ANY);
     savedialog.setFilename(file);
-    if(savedialog.execute())
+    if (savedialog.execute())
     {
         file=savedialog.getFilename();
-        if(FXStat::exists(file))
+        if (FXStat::exists(file))
         {
-            if(BOX_CLICKED_NO==MessageBox::question(this,BOX_YES_NO,_("Overwrite Document"),_("Overwrite existing document: %s?"),file.text()))
+            if (BOX_CLICKED_NO==MessageBox::question(this,BOX_YES_NO,_("Overwrite Document"),_("Overwrite existing document: %s?"),file.text()))
                 return 1;
         }
         saveFile(file);
@@ -1645,8 +1670,8 @@ long WriteWindow::onCmdSaveAs(FXObject*,FXSelector,void*)
 FXbool WriteWindow::close(FXbool notify)
 {
     // Prompt to save changes
-    if(!saveChanges())
-        return FALSE;
+    if (!saveChanges())
+        return false;
 
     // Save settings
     saveConfig();
@@ -1660,7 +1685,7 @@ FXbool WriteWindow::close(FXbool notify)
 long WriteWindow::onCmdWindow(FXObject*,FXSelector sel,void*)
 {
     int which=FXSELID(sel)-ID_WINDOW_1;
-    if(which<getApp()->windowlist.no())
+    if (which<getApp()->windowlist.no())
     {
         getApp()->windowlist[which]->raise();
         getApp()->windowlist[which]->setFocus();
@@ -1673,18 +1698,18 @@ long WriteWindow::onCmdWindow(FXObject*,FXSelector sel,void*)
 long WriteWindow::onUpdWindow(FXObject *sender,FXSelector sel,void*)
 {
     int which=FXSELID(sel)-ID_WINDOW_1;
-    if(which<getApp()->windowlist.no())
+    if (which<getApp()->windowlist.no())
     {
         WriteWindow *window=getApp()->windowlist[which];
         FXString string;
-        if(which<49)
+        if (which<49)
             string.format("&%d %s",which+1,window->getTitle().text());
         else
             string.format("5&0 %s",window->getTitle().text());
 
         sender->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_SETSTRINGVALUE),(void*)&string);
 
-        if(window==getApp()->getActiveWindow())
+        if (window==getApp()->getActiveWindow())
             sender->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_CHECK),NULL);
 
         else
@@ -1702,11 +1727,15 @@ long WriteWindow::onUpdateTitle(FXObject* sender,FXSelector sel,void* ptr)
 {
     FXMainWindow::onUpdate(sender,sel,ptr);
     FXString title=FXPath::name(getFilename());
-    if(isModified())
+    if (isModified())
         title+=_(" (changed)");
     FXString directory=FXPath::directory(getFilename());
-    if(!directory.empty())
+    if (!directory.empty())
         title+=" - " + directory;
+
+	if (readonly)
+		title += _(" (read only)");
+
     setTitle(title);
     return 1;
 }
@@ -1759,7 +1788,7 @@ long WriteWindow::onCmdWrap(FXObject*,FXSelector,void*)
 // Update toggle wrap mode
 long WriteWindow::onUpdWrap(FXObject* sender,FXSelector,void*)
 {
-    if(editor->getTextStyle()&TEXT_WORDWRAP)
+    if (editor->getTextStyle()&TEXT_WORDWRAP)
         sender->handle(this,FXSEL(SEL_COMMAND,ID_CHECK),NULL);
     else
         sender->handle(this,FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
@@ -1786,7 +1815,7 @@ long WriteWindow::onCmdLinesNum(FXObject*,FXSelector,void*)
 // Update toggle line numbers
 long WriteWindow::onUpdLinesNum(FXObject* sender,FXSelector,void*)
 {
-    if(linesnum)
+    if (linesnum)
         sender->handle(this,FXSEL(SEL_COMMAND,ID_CHECK),NULL);
     else
         sender->handle(this,FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
@@ -1797,9 +1826,18 @@ long WriteWindow::onUpdLinesNum(FXObject* sender,FXSelector,void*)
 // Update box for overstrike mode display
 long WriteWindow::onUpdOverstrike(FXObject* sender,FXSelector,void*)
 {
-    FXString mode((editor->getTextStyle()&TEXT_OVERSTRIKE)?_("OVR"):_("INS"));
-    sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&mode);
-    return 1;
+	if (readonly)
+	{
+		FXString mode(_("READ ONLY"));
+		sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&mode);	
+	}
+	else
+	{
+		FXString mode((editor->getTextStyle()&TEXT_OVERSTRIKE)?_("OVR"):_("INS"));
+		sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&mode);	
+	}
+
+	return 1;
 }
 
 
@@ -1812,18 +1850,16 @@ long WriteWindow::onUpdNumRows(FXObject* sender,FXSelector,void*)
 }
 
 
-
-
 // Text inserted; callback has [pos nins]
 long WriteWindow::onTextInserted(FXObject*,FXSelector,void* ptr)
 {
     const FXTextChange *change=(const FXTextChange*)ptr;
 
     // Log undo record
-    if(!undolist.busy())
+    if (!undolist.busy())
     {
         undolist.add(new FXTextInsert(editor,change->pos,change->nins,change->ins));
-        if(undolist.size()>MAXUNDOSIZE)
+        if (undolist.size()>MAXUNDOSIZE)
         	undolist.trimSize(KEEPUNDOSIZE);
     }
 
@@ -1838,10 +1874,10 @@ long WriteWindow::onTextDeleted(FXObject*,FXSelector,void* ptr)
     const FXTextChange *change=(const FXTextChange*)ptr;
 
     // Log undo record
-    if(!undolist.busy())
+    if (!undolist.busy())
     {
         undolist.add(new FXTextDelete(editor,change->pos,change->ndel,change->del));
-        if(undolist.size()>MAXUNDOSIZE)
+        if (undolist.size()>MAXUNDOSIZE)
         	undolist.trimSize(KEEPUNDOSIZE);
     }
 
@@ -1855,10 +1891,10 @@ long WriteWindow::onTextReplaced(FXObject*,FXSelector,void* ptr)
     const FXTextChange *change=(const FXTextChange*)ptr;
 
     // Log undo record
-    if(!undolist.busy())
+    if (!undolist.busy())
     {
         undolist.add(new FXTextReplace(editor,change->pos,change->ndel,change->nins,change->del,change->ins));
-        if(undolist.size()>MAXUNDOSIZE)
+        if (undolist.size()>MAXUNDOSIZE)
         	undolist.trimSize(KEEPUNDOSIZE);
     }
 
@@ -1870,12 +1906,12 @@ long WriteWindow::onTextReplaced(FXObject*,FXSelector,void* ptr)
 long WriteWindow::onTextRightMouse(FXObject*,FXSelector,void* ptr)
 {
     FXEvent* event=(FXEvent*)ptr;
-    if(!event->moved)
+    if (!event->moved)
     {
-        allowPopupScroll=TRUE; // Allow keyboard scrolling
+        allowPopupScroll=true; // Allow keyboard scrolling
         popupmenu->popup(NULL,event->root_x,event->root_y);
         getApp()->runModalWhileShown(popupmenu);
-        allowPopupScroll=FALSE;
+        allowPopupScroll=false;
     }
     return 1;
 }
@@ -1886,13 +1922,13 @@ long WriteWindow::onFocusIn(FXObject* sender,FXSelector sel,void* ptr)
 {
     register FXTime t;
     FXMainWindow::onFocusIn(sender,sel,ptr);
-    if(filetime!=0)
+    if (filetime!=0)
     {
         t=FXStat::modified(filename);
-        if(t && t!=filetime)
+        if (t && t!=filetime)
         {
             filetime=t;
-            if(BOX_CLICKED_OK==MessageBox::warning(this,BOX_OK_CANCEL,_("File Was Changed"),_("%s\nwas changed by another program. Reload this file from disk?"),filename.text()))
+            if (BOX_CLICKED_OK==MessageBox::warning(this,BOX_OK_CANCEL,_("File Was Changed"),_("%s\nwas changed by another program. Reload this file from disk?"),filename.text()))
             {
                 int top=editor->getTopLine();
                 int pos=editor->getCursorPos();
@@ -1911,6 +1947,8 @@ long WriteWindow::onCmdSearch(FXObject*,FXSelector,void*)
 {
     if (searchdialog==NULL)
         searchdialog=new FXSearchDialog(this,_("Search"),searchicon);
+	searchdialog->setSearchMode(SEARCH_IGNORECASE);
+
     int beg[10];
     int end[10];
     int pos;
@@ -1920,16 +1958,16 @@ long WriteWindow::onCmdSearch(FXObject*,FXSelector,void*)
     do
     {
         code=searchdialog->execute();
-        if(code==FXSearchDialog::DONE)
+        if (code==FXSearchDialog::DONE)
             return 1;
         searchstring=searchdialog->getSearchText();
         searchflags=searchdialog->getSearchMode();
         pos=editor->isPosSelected(editor->getCursorPos()) ? (searchflags&SEARCH_BACKWARD) ? editor->getSelStartPos()-1 : editor->getSelEndPos() : editor->getCursorPos();
-        if(editor->findText(searchstring,beg,end,pos,searchflags|SEARCH_WRAP,10))
+        if (editor->findText(searchstring,beg,end,pos,searchflags|SEARCH_WRAP,10))
         {
             editor->setAnchorPos(beg[0]);
-            editor->extendSelection(end[0],SELECT_CHARS,TRUE);
-            editor->setCursorPos(end[0],TRUE);
+            editor->extendSelection(end[0],SELECT_CHARS,true);
+            editor->setCursorPos(end[0],true);
             editor->makePositionVisible(beg[0]);
             editor->makePositionVisible(end[0]);
         }
@@ -1946,7 +1984,10 @@ long WriteWindow::onCmdSearch(FXObject*,FXSelector,void*)
 // Replace text; we assume that findText has called squeezegap()!
 long WriteWindow::onCmdReplace(FXObject*,FXSelector,void*)
 {
-    replacedialog=new FXReplaceDialog(this,_("Replace"),replaceicon);
+	if (replacedialog==NULL)
+		replacedialog=new FXReplaceDialog(this,_("Replace"),replaceicon);
+	replacedialog->setSearchMode(SEARCH_IGNORECASE);
+    
     int beg[10],end[10],fm,to,len,pos;
     FXuint searchflags,code;
     FXString searchstring;
@@ -1962,7 +2003,7 @@ long WriteWindow::onCmdReplace(FXObject*,FXSelector,void*)
     do
     {
         code=replacedialog->execute();
-        if(code==FXReplaceDialog::DONE)
+        if (code==FXReplaceDialog::DONE)
             goto ret;
         searchflags=replacedialog->getSearchMode();
         searchstring=replacedialog->getSearchText();
@@ -1970,40 +2011,40 @@ long WriteWindow::onCmdReplace(FXObject*,FXSelector,void*)
         replacevalue=FXString::null;
         fm=-1;
         to=-1;
-        if(code==FXReplaceDialog::REPLACE_ALL)
+        if (code==FXReplaceDialog::REPLACE_ALL)
         {
             searchflags&=~SEARCH_BACKWARD;
             pos=0;
             while(editor->findText(searchstring,beg,end,pos,searchflags,10))
             {
-                if(0<=fm)
+                if (0<=fm)
                     replacevalue.append(&buffer[pos],beg[0]-pos);
                 replacevalue.append(FXRex::substitute(buffer,length,beg,end,replacestring,10));
-                if(fm<0)
+                if (fm<0)
                     fm=beg[0];
                 to=end[0];
                 pos=end[0];
-                if(beg[0]==end[0])
+                if (beg[0]==end[0])
                     pos++;
             }
         }
         else
         {
             pos=editor->isPosSelected(editor->getCursorPos()) ? (searchflags&SEARCH_BACKWARD) ? editor->getSelStartPos()-1 : editor->getSelEndPos() : editor->getCursorPos();
-            if(editor->findText(searchstring,beg,end,pos,searchflags|SEARCH_WRAP,10))
+            if (editor->findText(searchstring,beg,end,pos,searchflags|SEARCH_WRAP,10))
             {
                 replacevalue=FXRex::substitute(buffer,length,beg,end,replacestring,10);
                 fm=beg[0];
                 to=end[0];
             }
         }
-        if(0<=fm)
+        if (0<=fm)
         {
             len=replacevalue.length();
-            editor->replaceText(fm,to-fm,replacevalue.text(),len,TRUE);
-            editor->setCursorPos(fm+len,TRUE);
+            editor->replaceText(fm,to-fm,replacevalue.text(),len,true);
+            editor->setCursorPos(fm+len,true);
             editor->makePositionVisible(editor->getCursorPos());
-            editor->setModified(TRUE);
+            editor->setModified(true);
         }
         else
         {
@@ -2029,18 +2070,18 @@ long WriteWindow::onCmdSearchSel(FXObject*,FXSelector sel,void*)
     int beg,end;
 
     // First, try UTF-8
-    if(getDNDData(FROM_SELECTION,utf8Type,string))
+    if (getDNDData(FROM_SELECTION,utf8Type,string))
         searchstring=string;
 
     // Next, try UTF-16
-    else if(getDNDData(FROM_SELECTION,utf16Type,string))
+    else if (getDNDData(FROM_SELECTION,utf16Type,string))
     {
         FXUTF16LECodec unicode;                 // FIXME maybe other endianness for unix
         searchstring=unicode.mb2utf(string);
     }
 
     // Finally, try good old 8859-1
-    else if(getDNDData(FROM_SELECTION,stringType,string))
+    else if (getDNDData(FROM_SELECTION,stringType,string))
     {
         FX88591Codec ascii;
         searchstring=ascii.mb2utf(string);
@@ -2053,26 +2094,26 @@ long WriteWindow::onCmdSearchSel(FXObject*,FXSelector sel,void*)
     }
 	
     // Search direction
-    if(FXSELID(sel)==ID_SEARCH_FORW_SEL)
+    if (FXSELID(sel)==ID_SEARCH_FORW_SEL)
     {
-        if(editor->isPosSelected(pos))
+        if (editor->isPosSelected(pos))
         	pos=editor->getSelEndPos();
         searchflags=SEARCH_EXACT|SEARCH_FORWARD;
     }
     else
     {
-        if(editor->isPosSelected(pos))
+        if (editor->isPosSelected(pos))
         	pos=editor->getSelStartPos()-1;
         searchflags=SEARCH_EXACT|SEARCH_BACKWARD;
     }
 
     // Perform search
-    if(editor->findText(searchstring,&beg,&end,pos,searchflags|SEARCH_WRAP))
+    if (editor->findText(searchstring,&beg,&end,pos,searchflags|SEARCH_WRAP))
     {
-        if(beg!=editor->getSelStartPos() || end!=editor->getSelEndPos())
+        if (beg!=editor->getSelStartPos() || end!=editor->getSelEndPos())
         {
             editor->setAnchorPos(beg);
-            editor->extendSelection(end,SELECT_CHARS,TRUE);
+            editor->extendSelection(end,SELECT_CHARS,true);
             editor->setCursorPos(end);
             editor->makePositionVisible(beg);
             editor->makePositionVisible(end);
@@ -2091,11 +2132,13 @@ x:
 long WriteWindow::onCmdGotoLine(FXObject*,FXSelector,void*)
 {
     int row=editor->getCursorRow()+1;
-    if(FXInputDialog::getInteger(row,this,_("Goto Line"),_("&Goto line number:"),gotobigicon,1,2147483647))
+    if (FXInputDialog::getInteger(row,this,_("Goto Line"),_("&Goto line number:"),gotobigicon,1,2147483647))
     {
         update();
-        editor->setCursorRow(row-1,TRUE);
+        editor->setCursorRow(row-1,true);
         editor->makePositionVisible(editor->getCursorPos());
     }
     return 1;
 }
+
+
