@@ -25,9 +25,8 @@
 #include "TextWindow.h"
 #include "SearchWindow.h"
 
-
-// Helper function
-void toolbarSeparator(FXToolBar*);
+// Typedef for the map between program string identifiers and integer indexes
+typedef std::map<FXString, int> progsmap;
 
 
 // Application object
@@ -47,6 +46,8 @@ protected:
 	int panel_view;
     int RunHistSize;
     char RunHistory[RUN_HIST_SIZE][MAX_COMMAND_SIZE];
+    FXbool			vertpanels;
+	FXSplitter* 	panelsplit;
 	FXMenuBar		*menubar;
     FXMenuPane		*toolsmenu;
     FXMenuPane		*filemenu;
@@ -93,22 +94,29 @@ protected:
 	TextWindow*		   helpwindow;
 	FXString 		message;
 	FXuint 			panelfocus;
-	FXString		startdirectory1;
-	FXString		startdirectory2;
+	FXString		startdir1;
+	FXString		startdir2;
+	vector_FXString startURIs;
 	FXbool			starticonic;
 	FXbool			startmaximized;
 	FXbool			smoothscroll;
-	double        twopanels_lpanel_pct;      // Panel sizes, relatively to the window width (in percent)
-	double        treepanel_tree_pct;
-	double        treetwopanels_tree_pct;
-	double        treetwopanels_lpanel_pct;
+	double        	twopanels_lpanel_pct;		// Panel sizes, relatively to the window width (in percent)
+	double        	treepanel_tree_pct;
+	double        	treetwopanels_tree_pct;
+	double        	treetwopanels_lpanel_pct;
 	FXString        prevdir;
-	int			prev_width;
+	int				prev_width;
 	FXuint			search_xpos;
 	FXuint			search_ypos;
 	FXuint			search_width;
 	FXuint			search_height;
 	SearchWindow*	searchwindow;
+	progsmap		progs;						// Map between program string identifiers and integer indexes
+	FXbool 			winshow;					// If true, do not show the Xfe window
+	FXbool 			stop;						// If true, stop Xfe immediately
+	int				nbstartfiles;				// Number of files to open on startup
+
+
 public:
 	enum{
         ID_ABOUT=FXMainWindow::ID_LAST,
@@ -154,13 +162,21 @@ public:
         ID_ADD_BOOKMARK,
         ID_HARVEST,
         ID_QUIT,
+        ID_FILE_ADDCOPY,
+        ID_FILE_ADDCUT,
+		ID_HORZ_PANELS,
+		ID_VERT_PANELS,
 		ID_LAST
     };
+protected:
+    XFileExplorer()
+    {}
 public:
-    XFileExplorer(FXApp *app=NULL,const FXbool iconic=FALSE,const FXbool maximized=FALSE,const FXString startdir1 = "",const FXString startdir2 = "",const char *title = "X File Explorer",FXIcon *bigicon=NULL,FXIcon *miniicon=NULL);
+    XFileExplorer(FXApp *app,vector_FXString URIs,const FXbool iconic=false,const FXbool maximized=false,const char *title = "X File Explorer",FXIcon *bigicon=NULL,FXIcon *miniicon=NULL);
     virtual void create();
     ~XFileExplorer();
     void saveConfig();
+	void openFiles(vector_FXString);
 	long onSigHarvest(FXObject*,FXSelector,void*);
     long onQuit(FXObject*,FXSelector,void*);
 	long onKeyPress(FXObject*,FXSelector,void*);
@@ -176,6 +192,7 @@ public:
     long onCmdXTerm(FXObject*,FXSelector,void*);
 	long onCmdEmptyTrash(FXObject*,FXSelector,void*);
 	long onCmdTrashSize(FXObject*,FXSelector,void*);
+	long onCmdHorzVertPanels(FXObject*,FXSelector,void*);
 	long onCmdShowPanels(FXObject*,FXSelector,void*);
     long onCmdRestart(FXObject*,FXSelector,void*);
 	long onCmdNewWindow(FXObject*,FXSelector,void*);
@@ -183,6 +200,7 @@ public:
 	long onCmdGotoLocation(FXObject*,FXSelector,void*);
 	long onCmdClearLocation(FXObject*,FXSelector,void*);
     long onUpdToggleStatus(FXObject*,FXSelector,void*);
+	long onUpdHorzVertPanels(FXObject*,FXSelector,void*);
 	long onUpdShowPanels(FXObject*,FXSelector,void*);
 	long onUpdFileLocation(FXObject*,FXSelector,void*);
 	long onUpdEmptyTrash(FXObject*,FXSelector,void*);
@@ -205,6 +223,8 @@ public:
 	long onUpdDirForwardHist(FXObject*,FXSelector,void*);
 	long onCmdFileCopyClp(FXObject*,FXSelector,void*);
 	long onCmdFileCutClp(FXObject*,FXSelector,void*);
+	long onCmdFileAddCopyClp(FXObject*,FXSelector,void*);
+	long onCmdFileAddCutClp(FXObject*,FXSelector,void*);
 	long onCmdFilePasteClp(FXObject*,FXSelector,void*);
 	long onCmdFileRename(FXObject*,FXSelector,void*);
 	long onCmdFileMoveto(FXObject*,FXSelector,void*);
@@ -219,6 +239,8 @@ public:
 	long onCmdSwitchPanels(FXObject*,FXSelector,void*);
 	long onUpdSwitchPanels(FXObject*,FXSelector,void*);
 	long onUpdSu(FXObject*,FXSelector,void*);
+	long onUpdQuit(FXObject*,FXSelector,void*);
+	long onUpdFileSearch(FXObject*,FXSelector,void*);
 public:
     // Get associations
     FileDict *getAssociations()
@@ -229,9 +251,9 @@ public:
 	// Change to selected directory
 	void setDirectory(FXString pathname)
 	{
-		lpanel->getCurrent()->setDirectory(pathname,FALSE);
+		lpanel->getCurrent()->setDirectory(pathname,false);
 		lpanel->getCurrent()->updatePath();
-		dirpanel->setDirectory(pathname,TRUE);
+		dirpanel->setDirectory(pathname,true);
 	}
 
 	// Change default cursor for file and dir panels
