@@ -19,7 +19,9 @@ protected:
     FXToolBar         *toolbar;               // Tool bar
     FXToolBarShell    *dragshell1;            // Shell for floating menubar
     FXHorizontalFrame *statusbar;             // Status bar
-    FXSplitter        *splitter;              // Splitter
+    FXbool				filelistbefore;
+    FXbool				vertpanels;
+	FXSplitter* 		splitter;			  // Splitter
     FXVerticalFrame   *filebox;               // Box containing directories/files
     FileList          *filelist;              // File List
 	FXLabel			  *label;				  // Directory path
@@ -32,17 +34,19 @@ protected:
 	FXImage			  *img;					  // Image loaded
 	FXImage			  *tmpimg;				  // Temporary image
     FXColor 		  *tmpdata;				  // Temporary image data
-	int			  indZoom;				  // Zoom index
-	double		  zoomval;				  // Actual zoom factor
+	int			  	indZoom;				  // Zoom index
+	double		  	zoomval;				  // Actual zoom factor
 	FXbool			  fitwin;                 // Fit window when opening an image
 	FXbool            filterimgs;             // List only image files in file list
 	InputDialog*	  printdialog;
 	FXbool			  smoothscroll;
-	double		  fileheight_pct;
+	double		  	filewidth_pct;
+	double		  	fileheight_pct;
 	FXArrowButton     *btnbackhist;           // Back history
 	FXArrowButton     *btnforwardhist;        // Forward history
     PathLinker*		  pathlink;
 	TextLabel*		  pathtext;
+	int 			  prev_width;
 	int 			  prev_height;
 protected:
     XFileImage()
@@ -60,6 +64,7 @@ public:
 	long onCmdSave(FXObject*,FXSelector,void*);
 	long onSigHarvest(FXObject*,FXSelector,void*);
     long onCmdQuit(FXObject*,FXSelector,void*);
+	long onCmdRestart(FXObject*,FXSelector,void*);
     long onUpdTitle(FXObject*,FXSelector,void*);
     long onCmdRecentFile(FXObject*,FXSelector,void*);
     long onCmdRotate(FXObject*,FXSelector,void*);
@@ -94,6 +99,10 @@ public:
     long onUpdDirForwardHist(FXObject*,FXSelector,void*);
 	long onCmdToggleFilterImages(FXObject*,FXSelector,void*);
 	long onUpdToggleFilterImages(FXObject*,FXSelector,void*);
+	long onCmdHorzVertPanels(FXObject*,FXSelector,void*);
+	long onUpdHorzVertPanels(FXObject*,FXSelector,void*);
+	long onCmdToggleFileListBefore(FXObject*,FXSelector,void*);
+	long onUpdToggleFileListBefore(FXObject*,FXSelector,void*);
 
 public:
     enum{
@@ -101,8 +110,8 @@ public:
         ID_OPEN,
 		ID_TOGGLE_HIDDEN,
 		ID_TOGGLE_THUMBNAILS,
-		ID_SHOW_MINI,
-		ID_SHOW_BIG,
+		ID_SHOW_MINI_ICONS,
+		ID_SHOW_BIG_ICONS,
 		ID_SHOW_DETAILS,
 		ID_COLS,
 		ID_ROWS,
@@ -111,6 +120,7 @@ public:
 		ID_PRINT,
         ID_HARVEST,
         ID_QUIT,
+        ID_RESTART,
         ID_FILELIST,
         ID_RECENTFILE,
         ID_ROTATE_90,
@@ -124,13 +134,16 @@ public:
         ID_ZOOM_WIN,
 		ID_TOGGLE_FIT_WIN,
 		ID_TOGGLE_FILTER_IMAGES,
-        ID_HOME,
-        ID_WORK,
+        ID_GO_HOME,
+        ID_GO_WORK,
         ID_DIR_UP,
 		ID_DIR_BACK,
 		ID_DIR_FORWARD,
  		ID_DIR_BACK_HIST,
 		ID_DIR_FORWARD_HIST,
+		ID_HORZ_PANELS,
+		ID_VERT_PANELS,
+		ID_TOGGLE_FILELIST_BEFORE,
         ID_LAST
     };
 public:
