@@ -28,11 +28,12 @@
 #include "clearlooks.cpp"
 
 
+// Global variables
 char **args;
-FXbool dpkg=FALSE;
-FXbool rpm=FALSE;
+FXbool dpkg=false;
+FXbool rpm=false;
 FXColor highlightcolor;
-FXbool allowPopupScroll=FALSE;
+FXbool allowPopupScroll=false;
 FXuint single_click;
 FXbool file_tooltips;
 FXbool relative_resize;
@@ -40,6 +41,7 @@ FXbool save_win_pos;
 FXString homedir;
 FXString xdgconfighome;
 FXString xdgdatahome;
+FXbool run_ibus=false;
 
 // Hand cursor replacement
 #define hand_width 32
@@ -83,8 +85,6 @@ FXDEFMAP(XFilePackage) XFilePackageMap[]=
 	FXMAPFUNC(SEL_COMMAND,XFilePackage::ID_ABOUT,XFilePackage::onCmdAbout),
 	FXMAPFUNC(SEL_COMMAND,XFilePackage::ID_OPEN,XFilePackage::onCmdOpen),
 	FXMAPFUNC(SEL_COMMAND,XFilePackage::ID_INSTALL,XFilePackage::onCmdInstall),
-	FXMAPFUNC(SEL_UPDATE,XFilePackage::ID_DESCRIPTION,XFilePackage::onUpdDescription),
-	FXMAPFUNC(SEL_UPDATE,XFilePackage::ID_FILELIST,XFilePackage::onUpdFileList),
 };
 
 
@@ -236,11 +236,11 @@ long XFilePackage::onCmdOpen(FXObject*,FXSelector,void*)
 	opendialog.setSelectMode(SELECTFILE_EXISTING);
     opendialog.setPatternList(patterns);
   	opendialog.setDirectory(FXPath::directory(filename));
-    if(opendialog.execute())
+    if (opendialog.execute())
     {
         filename=opendialog.getFilename();
-		list_clean=TRUE;
-		desc_clean=TRUE;
+		readDescription();
+		readFileList();
     }
 
     return 1;
@@ -264,9 +264,9 @@ long XFilePackage::onCmdInstall(FXObject*,FXSelector,void*)
 
     // Command to perform
 	FXString ext=FXPath::extension(filename);
-    if(comparecase(ext,"rpm")==0)
+    if (comparecase(ext,"rpm")==0)
 		cmd="rpm -Uvh "+filename;
-	else if(comparecase(ext,"deb")==0)
+	else if (comparecase(ext,"deb")==0)
 		cmd="dpkg -i "+filename;
 	else
 	{
@@ -304,14 +304,14 @@ long XFilePackage::onCmdUninstall(FXObject*,FXSelector,void*)
     // Command to perform
 	FXString package;
 	FXString ext=FXPath::extension(filename);
-    if(comparecase(ext,"rpm")==0)
+    if (comparecase(ext,"rpm")==0)
 	{
 		// Get package name
 		package=FXPath::name(filename);
 		package=package.section('-',0);
 		cmd="rpm -e "+ package;
 	}
-	else if(comparecase(ext,"deb")==0)
+	else if (comparecase(ext,"deb")==0)
 	{
 		// Get package name
 		package=FXPath::name(filename);
@@ -365,10 +365,10 @@ void XFilePackage::saveConfig()
     getApp()->reg().writeStringEntry("OPTIONS","filename",filename.text());
 
     // Toolbar status
-	if(toolbar->shown())
-        getApp()->reg().writeUnsignedEntry("OPTIONS","showtoolbar",TRUE);
+	if (toolbar->shown())
+        getApp()->reg().writeUnsignedEntry("OPTIONS","showtoolbar",true);
     else
-        getApp()->reg().writeUnsignedEntry("OPTIONS","showtoolbar",FALSE);
+        getApp()->reg().writeUnsignedEntry("OPTIONS","showtoolbar",false);
 
 	// Write registry options
 	getApp()->reg().write();
@@ -396,36 +396,31 @@ long XFilePackage::onCmdQuit(FXObject*,FXSelector,void*)
 
 
 // Update file list
-long XFilePackage::onUpdFileList(FXObject*,FXSelector,void*)
+int XFilePackage::readFileList(void)
 {
 	FXString cmd;
-
-	if(!list_clean)
-        return 0;
-	
-    list_clean=FALSE;
  
 	FXString ext=FXPath::extension(filename);
-    if(comparecase(ext,"rpm")==0)
+    if (comparecase(ext,"rpm")==0)
     {
-		errorflag=FALSE;
+		errorflag=false;
 		cmd="rpm -qlp "+::quote(filename);
 	}
-	else if(comparecase(ext,"deb")==0)
+	else if (comparecase(ext,"deb")==0)
 	{
-		errorflag=FALSE;
+		errorflag=false;
 		cmd="dpkg -c "+::quote(filename);
 	}
-	else if (errorflag==FALSE)
+	else if (errorflag==false)
 	{
-		errorflag=TRUE;
+		errorflag=true;
     	list->clearItems();
 		MessageBox::error(this,BOX_OK,_("Error"),_("Unknown package format"));
 		return 0;
 	}
 
     FILE *pcmd=popen(cmd.text(),"r");
-    if(!pcmd)
+    if (!pcmd)
     {
         perror("popen");
         exit(1);
@@ -448,6 +443,10 @@ long XFilePackage::onUpdFileList(FXObject*,FXSelector,void*)
     {
         text[strlen(text)-1]='\0';// kill trailing lf
         list->appendItem(topmost,text,minidocicon,minidocicon);
+		
+		// Force refresh
+		getApp()->forceRefresh();
+		getApp()->repaint();
 	}
 	list->expandTree(topmost);
     getApp()->endWaitCursor();
@@ -457,39 +456,34 @@ long XFilePackage::onUpdFileList(FXObject*,FXSelector,void*)
 }
 
 
-// Update description
-long XFilePackage::onUpdDescription(FXObject*,FXSelector,void*)
+int XFilePackage::readDescription(void)
 {
 	FXString cmd;
-
-    if(!desc_clean)
-        return 0;
-    desc_clean=FALSE;
-
     FXString buf;
+    
 	FXString ext=FXPath::extension(filename);
-    if(comparecase(ext,"rpm")==0)
+    if (comparecase(ext,"rpm")==0)
 	{
-		errorflag=FALSE;
+		errorflag=false;
 		cmd="rpm -qip "+::quote(filename);
 		buf += _("[RPM package]\n"); 
 	}
-	else if(comparecase(ext,"deb")==0)
+	else if (comparecase(ext,"deb")==0)
 	{
-		errorflag=FALSE;
+		errorflag=false;
 		buf += _("[DEB package]\n"); 
 		cmd="dpkg -I "+::quote(filename);
 	}
-	else if (errorflag==FALSE)
+	else if (errorflag==false)
 	{
-		errorflag=TRUE;
+		errorflag=true;
 		list->clearItems();
 		MessageBox::error(this,BOX_OK,_("Error"),_("Unknown package format"));
 		return 0;
 	}
 
     FILE *pcmd=popen(cmd.text(),"r");
-    if(!pcmd)
+    if (!pcmd)
     {
         perror("popen");
         exit(1);
@@ -497,7 +491,7 @@ long XFilePackage::onUpdDescription(FXObject*,FXSelector,void*)
 	
     // Don't display the header for Debian packages
 	int suppress_header=0;
-	if(comparecase(ext,"deb")==0)
+	if (comparecase(ext,"deb")==0)
 		suppress_header=1;
 
     char text[10000]={0};
@@ -514,8 +508,6 @@ long XFilePackage::onUpdDescription(FXObject*,FXSelector,void*)
 		list->clearItems();
         description->setText("");
 		filename="";
-		desc_clean=FALSE;
-    	list_clean=FALSE;
     }
     else
         description->setText(buf.text());
@@ -523,46 +515,39 @@ long XFilePackage::onUpdDescription(FXObject*,FXSelector,void*)
     return 1;
 }
 
+
 // Start the ball rolling
 void XFilePackage::start(FXString startpkg)
 {
     filename=startpkg;
 
-    if(filename != "")
+    if (filename != "")
     {
     	struct stat info;
     	FILE *fp;
-    	if(stat(filename.text(),&info)!=0)
+    	if (stat(filename.text(),&info)!=0)
     	{
         	MessageBox::error(this,BOX_OK,_("Error Loading File"),_("Non-existing file: %s"),filename.text());
 			filename="";
-			desc_clean=FALSE;
-    		list_clean=FALSE;
     	}
     	else
 		{
 			fp=fopen(filename.text(),"r");
-    		if(!fp)
+    		if (!fp)
     		{
         		MessageBox::error(this,BOX_OK,_("Error Loading File"),_("Unable to open file: %s"),filename.text());
 				filename="";
-				desc_clean=FALSE;
-    			list_clean=FALSE;
     		}
 			else
 			{
 				fclose(fp);
-    			desc_clean=TRUE;
-    			list_clean=TRUE;
+				readDescription();
+				readFileList();
 			}
 		}
 	}
 	else
-	{
-		filename="";
-		desc_clean=FALSE;
-    	list_clean=FALSE;
-	}
+		filename="";    
 }
 
 void XFilePackage::create()
@@ -574,7 +559,7 @@ void XFilePackage::create()
 	// Set Xfp text font according to the Xfe registry
 	FXString fontspec;
 	fontspec=reg_xfe->readStringEntry("SETTINGS","textfont","Helvetica,100,normal,regular");
-	if(!fontspec.empty())
+	if (!fontspec.empty())
 	{
     	FXFont* font=new FXFont(getApp(),fontspec);
 		font->create();
@@ -584,7 +569,7 @@ void XFilePackage::create()
 	delete reg_xfe;
 				
 	// Get toolbar status
-    if(getApp()->reg().readUnsignedEntry("OPTIONS","showtoolbar",TRUE)==FALSE)
+    if (getApp()->reg().readUnsignedEntry("OPTIONS","showtoolbar",true)==false)
         toolbar->hide();
 
     // Get size
@@ -608,9 +593,12 @@ void XFilePackage::create()
 	minifolderopenicon->create();
 	minidocicon->create();
 
-    show();
+    // Description is not editable
     description->handle(this,FXSEL(SEL_COMMAND,FXText::ID_TOGGLE_EDITABLE),NULL);
 
+    // Show window
+    show();
+
 #ifdef STARTUP_NOTIFICATION
 	startup_completed();
 #endif
@@ -644,13 +632,13 @@ int main(int argc,char* argv[])
 
 	// Get environment variables $HOME, $XDG_DATA_HOME and $XDG_CONFIG_HOME
 	homedir=FXSystem::getHomeDirectory();
-    if(homedir=="")
+    if (homedir=="")
         homedir=ROOTDIR;
 	xdgdatahome=getenv("XDG_DATA_HOME");
-    if(xdgdatahome=="")
+    if (xdgdatahome=="")
         xdgdatahome=homedir + PATHSEPSTRING DATAPATH;     
 	xdgconfighome=getenv("XDG_CONFIG_HOME");
-    if(xdgconfighome=="")
+    if (xdgconfighome=="")
         xdgconfighome=homedir + PATHSEPSTRING CONFIGPATH;
 
 #ifdef HAVE_SETLOCALE
@@ -665,15 +653,23 @@ int main(int argc,char* argv[])
 	textdomain (PACKAGE);
 #endif
 	
+	// Test if iBus is running (this is used to fix the bug with xim and iBus input managers)
+	FXString cmd="pgrep -u " + FXStringVal(getuid()) + " ibus-daemon";
+	FXuint pid = FXUIntVal(getCommandOutput(cmd));
+	if (pid == 0)
+		run_ibus=false;
+	else
+		run_ibus=true;
+
 	// Parse basic arguments
-	for(i = 1; i < argc; ++i)
+	for (i=1; i<argc; ++i)
 	{
-    	if(compare(argv[i],"-v")==0 || compare(argv[i],"--version")==0)
+    	if (compare(argv[i],"-v")==0 || compare(argv[i],"--version")==0)
 		{
 			fprintf(stdout,"%s version %s\n",PACKAGE,VERSION);
 			exit(0);
 		}
-    	else if(compare(argv[i],"-h")==0 || compare(argv[i],"--help")==0)
+    	else if (compare(argv[i],"-h")==0 || compare(argv[i],"--help")==0)
 		{
 			fprintf(stdout,USAGE_MSG);
 			exit(0);
@@ -713,7 +709,7 @@ int main(int argc,char* argv[])
 	// Set Xfp normal font according to the Xfe registry
 	FXString fontspec;
 	fontspec=reg_xfe->readStringEntry("SETTINGS","font","Helvetica,100,normal,regular");
-	if(!fontspec.empty())
+	if (!fontspec.empty())
 	{
     	FXFont* normalFont=new FXFont(application,fontspec);
 		normalFont->create();
@@ -724,16 +720,16 @@ int main(int argc,char* argv[])
 	single_click=reg_xfe->readUnsignedEntry("SETTINGS","single_click",SINGLE_CLICK_NONE);
 	
 	// Set smooth scrolling according to the Xfe registry
-	FXbool smoothscroll=reg_xfe->readUnsignedEntry("SETTINGS","smooth_scroll",TRUE);
+	FXbool smoothscroll=reg_xfe->readUnsignedEntry("SETTINGS","smooth_scroll",true);
 
 	// Set file list tooltip flag according to the Xfe registry
-	file_tooltips=reg_xfe->readUnsignedEntry("SETTINGS","file_tooltips",TRUE);
+	file_tooltips=reg_xfe->readUnsignedEntry("SETTINGS","file_tooltips",true);
 	
 	// Set relative resizing flag according to the Xfe registry
-	relative_resize=reg_xfe->readUnsignedEntry("SETTINGS","relative_resize",TRUE);
+	relative_resize=reg_xfe->readUnsignedEntry("SETTINGS","relative_resize",true);
 	
     // Get value of the window position flag
-	save_win_pos=reg_xfe->readUnsignedEntry("SETTINGS","save_win_pos",FALSE);
+	save_win_pos=reg_xfe->readUnsignedEntry("SETTINGS","save_win_pos",false);
 
 	// Delete the Xfe registry
 	delete reg_xfe;
@@ -742,7 +738,7 @@ int main(int argc,char* argv[])
 	XFilePackage* window=new XFilePackage(application);
 
  	// Catch SIGCHLD to harvest zombie child processes
-	application->addSignal(SIGCHLD,window,XFilePackage::ID_HARVEST,TRUE);
+	application->addSignal(SIGCHLD,window,XFilePackage::ID_HARVEST,true);
 
 	// Smooth scrolling
 	window->setSmoothScroll(smoothscroll);
@@ -757,45 +753,23 @@ int main(int argc,char* argv[])
 	application->setTooltipTime(TOOLTIP_TIME);
 	
     // Test the existence of the Debian package manager (dpkg)
-	// This is done by checking the existence of the string 'Debian'
-	// in the response to the command 'dpkg' (with --version argument)
-	FXString cmd="dpkg --version 2>&1";
-    FILE *debcmd=popen(cmd.text(),"r");
-    if(!debcmd)
-    {
-        perror("popen");
-        exit(1);
-    }
-    char textdeb[10000]={0};
-    FXString bufdeb;
-    while(fgets(textdeb,sizeof(textdeb),debcmd))
-        bufdeb+=textdeb;
-    snprintf(textdeb,sizeof(textdeb)-1,"%s",bufdeb.text());
-	if (strstr(textdeb,"Debian")!=NULL)
-		dpkg=TRUE;
-	pclose(debcmd);
-	
-    // Test the existence of the RedHat package manager (rpm)
-	// This is done by checking the existence of the string 'RPM'
-	// in the response to the command 'rpm --version'
-	cmd="rpm --version 2>&1";
-    FILE *rpmcmd=popen(cmd.text(),"r");
-    if(!rpmcmd)
-    {
-        perror("popen");
-        exit(1);
-    }
-    char textrpm[10000]={0};
-    FXString bufrpm;
-    while(fgets(textrpm,sizeof(textrpm),rpmcmd))
-        bufrpm+=textrpm;
-    snprintf(textrpm,sizeof(textrpm)-1,"%s",bufrpm.text());
-	if (strstr(textrpm,"RPM")!=NULL)
-		rpm=TRUE;
-	pclose(rpmcmd);
+    // and the RedHat package manager (rpm)
+	FXString str;
 	
+	cmd="dpkg --version";
+	str=getCommandOutput(cmd);
+
+	if (str.find("Debian") != -1)
+		dpkg=true;
+
+	cmd="rpm --version";
+	str=getCommandOutput(cmd);
+		
+	if (str.find("RPM") != -1)
+		rpm=true;
+
 	// No package manager was found
-	if ((dpkg==FALSE) && (rpm==FALSE))
+	if ((dpkg==false) && (rpm==false))
 	{
         MessageBox::error(window,BOX_OK,_("Error"),_("No compatible package manager (rpm or dpkg) found!"));
 		exit(1);
@@ -803,7 +777,7 @@ int main(int argc,char* argv[])
 
     // Start
     window->start(startpkg);
-
+    
     // Run the application
     application->run();
 
