@@ -16,8 +16,6 @@ protected:
     FXString 			filename;			// Current package name
     FXTreeList 			*list;				// File list
     FXText 				*description;		// Package description
-    FXbool 				desc_clean;			// Clean description flag
-    FXbool 				list_clean;			// Clean list flag
 	FXbool				smoothscroll;
 	FXbool 				errorflag;
 protected:
@@ -47,11 +45,12 @@ public:
     long onCmdInstall(FXObject*,FXSelector,void*);
 	long onCmdAbout(FXObject*,FXSelector,void*);
 	long onCmdOpen(FXObject*,FXSelector,void*);
-    long onUpdDescription(FXObject*,FXSelector,void*);
-    long onUpdFileList(FXObject*,FXSelector,void*);
+    int readDescription();
+    int readFileList();
 	void saveConfig();
 	long onSigHarvest(FXObject*,FXSelector,void*);
     long onCmdQuit(FXObject*,FXSelector,void*);
+	long onUpdWindow(FXObject*,FXSelector,void*);
 };
 
 #endif
