@@ -28,14 +28,16 @@
 #include "foxhacks.cpp"
 #include "clearlooks.cpp"
 
+// Global variables
 FXColor highlightcolor;
-FXbool allowPopupScroll=FALSE;
+FXbool allowPopupScroll=false;
 FXuint single_click;
 FXbool file_tooltips;
 FXbool relative_resize;
 FXString homedir;
 FXString xdgconfighome;
 FXString xdgdatahome;
+FXbool run_ibus=false;
 
 
 // Hand cursor replacement
@@ -113,7 +115,7 @@ void XFileWrite::exit(int code)
 // Close all windows
 long XFileWrite::onCmdCloseAll(FXObject*,FXSelector,void*)
 {
-    while(0<windowlist.no() && windowlist[0]->close(TRUE));
+    while(0<windowlist.no() && windowlist[0]->close(true));
     return 1;
 }
 
@@ -131,6 +133,7 @@ XFileWrite::~XFileWrite()
 \n\
     [options] can be any of the following:\n\
 \n\
+        -r, --read-only    Open files in read-only mode.\n\
         -h, --help         Print (this) help screen and exit.\n\
         -v, --version      Print version information and exit.\n\
 \n\
@@ -148,16 +151,17 @@ int main(int argc,char *argv[])
 	const char *xfename = XFEAPPNAME;
 	const char *vdrname = XFEVDRNAME;
 	FXbool loadicons;
+	FXbool readonly=false;
 
 	// Get environment variables $HOME, $XDG_DATA_HOME and $XDG_CONFIG_HOME
 	homedir=FXSystem::getHomeDirectory();
-    if(homedir=="")
+    if (homedir=="")
         homedir=ROOTDIR;
 	xdgdatahome=getenv("XDG_DATA_HOME");
-    if(xdgdatahome=="")
+    if (xdgdatahome=="")
         xdgdatahome=homedir + PATHSEPSTRING DATAPATH;     
 	xdgconfighome=getenv("XDG_CONFIG_HOME");
-    if(xdgconfighome=="")
+    if (xdgconfighome=="")
         xdgconfighome=homedir + PATHSEPSTRING CONFIGPATH;
 
 #ifdef HAVE_SETLOCALE
@@ -172,6 +176,14 @@ int main(int argc,char *argv[])
 	textdomain (PACKAGE);
 #endif
 	
+	// Test if iBus is running (this is used to fix the bug with xim and iBus input managers)
+	FXString cmd="pgrep -u " + FXStringVal(getuid()) + " ibus-daemon";
+	FXuint pid = FXUIntVal(getCommandOutput(cmd));
+	if (pid == 0)
+		run_ibus=false;
+	else
+		run_ibus=true;
+
     // Make application
     XFileWrite* application=new XFileWrite(appname,vdrname);
 
@@ -206,13 +218,13 @@ int main(int argc,char *argv[])
 	single_click=reg_xfe->readUnsignedEntry("SETTINGS","single_click",SINGLE_CLICK_NONE);
 
 	// Set smooth scrolling according to the Xfe registry
-	FXbool smoothscroll=reg_xfe->readUnsignedEntry("SETTINGS","smooth_scroll",TRUE);
+	FXbool smoothscroll=reg_xfe->readUnsignedEntry("SETTINGS","smooth_scroll",true);
 
 	// Set file list tooltip flag according to the Xfe registry
-	file_tooltips=reg_xfe->readUnsignedEntry("SETTINGS","file_tooltips",TRUE);
+	file_tooltips=reg_xfe->readUnsignedEntry("SETTINGS","file_tooltips",true);
 
 	// Set relative resizing flag according to the Xfe registry
-	relative_resize=reg_xfe->readUnsignedEntry("SETTINGS","relative_resize",TRUE);
+	relative_resize=reg_xfe->readUnsignedEntry("SETTINGS","relative_resize",true);
 	
 	// Delete the Xfe registry
 	delete reg_xfe;
@@ -229,30 +241,35 @@ int main(int argc,char *argv[])
 	application->setTooltipPause(TOOLTIP_PAUSE);
 	application->setTooltipTime(TOOLTIP_TIME);
 
-    // Loop over args
-    for(i=1; i<argc; ++i)
+	// Parse basic arguments
+    for (i=1; i<argc; ++i)
     {
 
         // Parse a few options
-    	if(compare(argv[i],"-v")==0 || compare(argv[i],"--version")==0)
+    	if (compare(argv[i],"-v")==0 || compare(argv[i],"--version")==0)
 		{
 			fprintf(stdout,"%s version %s\n",PACKAGE,VERSION);
 			exit(0);
 		}
-        if(compare(argv[i],"-h")==0 || compare(argv[i],"--help")==0)
+        if (compare(argv[i],"-h")==0 || compare(argv[i],"--help")==0)
         {
 			fprintf(stdout,USAGE_MSG);
             exit(0);
         }
 
+        if (compare(argv[i],"-r")==0 || compare(argv[i],"--read-only")==0)
+        {
+			readonly=true;
+        }
+
         // Load the file
         else
         {
             file=FXPath::absolute(argv[i]);
-            window=new WriteWindow(application,_("untitled"));
+            window=new WriteWindow(application,_("untitled"),readonly);
 
 			// Catch SIGCHLD to harvest zombie child processes
-			application->addSignal(SIGCHLD,window,WriteWindow::ID_HARVEST,TRUE);
+			application->addSignal(SIGCHLD,window,WriteWindow::ID_HARVEST,true);
 
  			window->setSmoothScroll(smoothscroll);
 			window->create();
@@ -261,12 +278,12 @@ int main(int argc,char *argv[])
     }
 
     // Make window, if none opened yet
-    if(!window)
+    if (!window)
     {
-        window=new WriteWindow(application,_("untitled"));
+        window=new WriteWindow(application,_("untitled"),readonly);
 
 		// Catch SIGCHLD to harvest zombie child processes
-		application->addSignal(SIGCHLD,window,WriteWindow::ID_HARVEST,TRUE);
+		application->addSignal(SIGCHLD,window,WriteWindow::ID_HARVEST,true);
 
 		window->setSmoothScroll(smoothscroll);
         window->create();
