@@ -31,7 +31,7 @@ public:
     XFileWrite(const FXString&, const FXString&);
 
     // Initialize application
-    virtual void init(int& argc, char** argv,bool connect=TRUE);
+    virtual void init(int& argc, char** argv,bool connect=true);
 
     // Exit application
     virtual void exit(int code=0);
