@@ -12,7 +12,7 @@
 
 // Draw rectangle with gradient effect
 // Default is vertical gradient
-static void drawGradientRectangle(FXDC& dc,FXColor upper,FXColor lower,int x,int y,int w,int h, FXbool vert=TRUE)
+static void drawGradientRectangle(FXDC& dc,FXColor upper,FXColor lower,int x,int y,int w,int h, FXbool vert=true)
 {
     register int rr,gg,bb,dr,dg,db,r1,g1,b1,r2,g2,b2,yl,yh,yy,dy,n,t,ww;
     const int MAXSTEPS=128;
@@ -143,8 +143,8 @@ else                                                                   \
 
 
 #define INIT_CLEARLOOKS                                                                   \
-static FXbool init=TRUE;                                                                  \
-static FXbool use_clearlooks=TRUE;                                                        \
+static FXbool init=true;                                                                  \
+static FXbool use_clearlooks=true;                                                        \
 static FXColor topcolor, bottomcolor, shadecolor, bordercolor;                            \
                                                                                           \
 FXPoint basebackground[4]={FXPoint(0,0),FXPoint(width-1,0),FXPoint(0,height-1),           \
@@ -161,7 +161,7 @@ FXPoint bordercorners[4]={FXPoint(1,1),FXPoint(1,height-2),FXPoint(width-2,1),
                                                                                           \
 if (init)                                                                                 \
 {                                                                                         \
-	use_clearlooks=getApp()->reg().readUnsignedEntry("SETTINGS","use_clearlooks",TRUE);   \
+	use_clearlooks=getApp()->reg().readUnsignedEntry("SETTINGS","use_clearlooks",true);   \
                                                                                           \
 	if (use_clearlooks)                                                                   \
 	{                                                                                     \
@@ -176,7 +176,7 @@ if (init)
 		shadecolor=FXRGB(0.9*r,0.9*g,0.9*b);                                              \
 		bordercolor=FXRGB(0.5*r,0.5*g,0.5*b);                                             \
 	}                                                                                     \
-	init=FALSE;                                                                           \
+	init=false;                                                                           \
 }
 
 
@@ -392,13 +392,13 @@ long FXButton::onPaint(FXObject*,FXSelector,void* ptr)
 long FXCheckButton::onPaint(FXObject*,FXSelector,void* ptr)
 {
     // Initialize Clearlooks (don't use the macro because here it's different)
-    static FXbool init=TRUE;
-    static FXbool use_clearlooks=TRUE;
+    static FXbool init=true;
+    static FXbool use_clearlooks=true;
     static FXColor shadecolor, bordercolor;
 
     if (init)
     {
-        use_clearlooks=getApp()->reg().readUnsignedEntry("SETTINGS","use_clearlooks",TRUE);
+        use_clearlooks=getApp()->reg().readUnsignedEntry("SETTINGS","use_clearlooks",true);
 
         if (use_clearlooks)
         {
@@ -409,7 +409,7 @@ long FXCheckButton::onPaint(FXObject*,FXSelector,void* ptr)
             shadecolor=FXRGB(0.9*r,0.9*g,0.9*b);
             bordercolor=FXRGB(0.5*r,0.5*g,0.5*b);
         }
-        init=FALSE;
+        init=false;
     }
 
     FXEvent *ev=(FXEvent*)ptr;
@@ -418,7 +418,7 @@ long FXCheckButton::onPaint(FXObject*,FXSelector,void* ptr)
     FXDCWindow dc(this,ev);
 
     // Figure text size
-    if(!label.empty())
+    if (!label.empty())
     {
         tw=labelWidth(label);
         th=labelHeight(label);
@@ -436,13 +436,13 @@ long FXCheckButton::onPaint(FXObject*,FXSelector,void* ptr)
         dc.fillRectangle(ev->rect.x,ev->rect.y,ev->rect.w,ev->rect.h);
 
         // Check background
-        if(check==MAYBE || !isEnabled())
+        if (check==MAYBE || !isEnabled())
             dc.setForeground(baseColor);
         else
             dc.setForeground(boxColor);
 
         // Check border for +
-        if(options&CHECKBUTTON_PLUS)
+        if (options&CHECKBUTTON_PLUS)
         {
             dc.fillRectangle(ix+2,iy+2,9,9);
             dc.setForeground(bordercolor);
@@ -471,7 +471,7 @@ long FXCheckButton::onPaint(FXObject*,FXSelector,void* ptr)
         }
 
         // Check color
-        if(check==MAYBE || !isEnabled())
+        if (check==MAYBE || !isEnabled())
             dc.setForeground(shadowColor);
         else
             dc.setForeground(checkColor);
@@ -485,14 +485,14 @@ long FXCheckButton::onPaint(FXObject*,FXSelector,void* ptr)
         dc.fillRectangle(ev->rect.x,ev->rect.y,ev->rect.w,ev->rect.h);
 
         // Check background
-        if(check==MAYBE || !isEnabled())
+        if (check==MAYBE || !isEnabled())
             dc.setForeground(baseColor);
         else
             dc.setForeground(boxColor);
         dc.fillRectangle(ix+2,iy+2,9,9);
 
         // Check border for +
-        if(options&CHECKBUTTON_PLUS)
+        if (options&CHECKBUTTON_PLUS)
         {
             dc.setForeground(textColor);
             dc.drawRectangle(ix+2,iy+2,8,8);
@@ -516,16 +516,16 @@ long FXCheckButton::onPaint(FXObject*,FXSelector,void* ptr)
         }
 
         // Check color
-        if(check==MAYBE || !isEnabled())
+        if (check==MAYBE || !isEnabled())
             dc.setForeground(shadowColor);
         else
             dc.setForeground(checkColor);
     }
 
     // Show as +
-    if(options&CHECKBUTTON_PLUS)
+    if (options&CHECKBUTTON_PLUS)
     {
-        if(check!=TRUE)
+        if (check!=true)
             dc.fillRectangle(ix+6,iy+4,1,5);
         dc.fillRectangle(ix+4,iy+6,5,1);
     }
@@ -533,7 +533,7 @@ long FXCheckButton::onPaint(FXObject*,FXSelector,void* ptr)
     // Show as v
     else
     {
-        if(check!=FALSE)
+        if (check!=false)
         {
             FXSegment seg[6];
             seg[0].x1=3+ix;
@@ -565,14 +565,14 @@ long FXCheckButton::onPaint(FXObject*,FXSelector,void* ptr)
     }
 
     // Text
-    if(!label.empty())
+    if (!label.empty())
     {
         dc.setFont(font);
-        if(isEnabled())
+        if (isEnabled())
         {
             dc.setForeground(textColor);
             drawLabel(dc,label,hotoff,tx,ty,tw,th);
-            if(hasFocus())
+            if (hasFocus())
                 dc.drawFocusRectangle(tx-1,ty-1,tw+2,th+2);
         }
         else
@@ -591,7 +591,6 @@ long FXCheckButton::onPaint(FXObject*,FXSelector,void* ptr)
 }
 
 
-
 //
 // Hack of FXTextField
 //
@@ -605,7 +604,7 @@ long FXTextField::onPaint(FXObject*,FXSelector,void* ptr)
     FXEvent *ev=(FXEvent*)ptr;
     FXDCWindow dc(this,ev);
 
-    // Draw frame
+    // Draw frame   
     drawFrame(dc,0,0,width,height);
 
     // Draw background
@@ -613,7 +612,8 @@ long FXTextField::onPaint(FXObject*,FXSelector,void* ptr)
     dc.fillRectangle(border,border,width-(border<<1),height-(border<<1));
 
     // !!! Hack to get an optional rounded rectangle shape
-    if (use_clearlooks)
+    // only if _TEXTFIELD_NOFRAME is not specified !!!
+    if ( !(options&_TEXTFIELD_NOFRAME)  & use_clearlooks )
     {
         // Outside Background
         dc.setForeground(baseColor);
@@ -861,7 +861,7 @@ static void drawGradientScrollButton(FXDCWindow& dc, FXColor topcolor, FXColor b
                                      FXuint options, int x, int y, int w, int h)
 {
     // Fill rectangle with gradient in the right direction (vertical or horizontal)
-    FXbool vertical=((options&SCROLLBAR_HORIZONTAL) ? TRUE : FALSE);
+    FXbool vertical=((options&SCROLLBAR_HORIZONTAL) ? true : false);
     drawGradientRectangle(dc,topcolor,bottomcolor,x,y,w,h,vertical);
 
     // Draw button borders
@@ -1100,7 +1100,7 @@ static void drawGradientArrowButton(FXDCWindow& dc, FXColor backcolor, FXColor t
     if (!down)
     {
         // Fill rectangle with gradient in the right direction (vertical or horizontal)
-        FXbool vertical=((options&SCROLLBAR_HORIZONTAL) ? TRUE : FALSE);
+        FXbool vertical=((options&SCROLLBAR_HORIZONTAL) ? true : false);
         drawGradientRectangle(dc,topcolor,bottomcolor,x,y,w,h,vertical);
 
         // Button borders
@@ -1163,7 +1163,7 @@ static void drawFlatScrollButton(FXDCWindow& dc,FXint x,FXint y,FXint w,FXint h,
 {
     dc.setForeground(scrollbarcolor);
     dc.fillRectangle(x+2,y+2,w-4,h-4);
-    if(!down)
+    if (!down)
     {
         dc.setForeground(scrollbarcolor);
         dc.fillRectangle(x,y,w-1,1);
@@ -1201,8 +1201,8 @@ long FXScrollBar::onPaint(FXObject*,FXSelector,void* ptr)
 {
     // Caution! Don't use the macro here because it's slightly different
 
-    static FXbool init=TRUE;
-    static FXbool use_clearlooks=TRUE;
+    static FXbool init=true;
+    static FXbool use_clearlooks=true;
     static FXColor bg_topcolor, bg_bottomcolor, bg_shadecolor, bg_bordercolor, bg_lightcolor;
     static FXColor sb_topcolor, sb_bottomcolor, sb_shadecolor, sb_bordercolor, sb_lightcolor, scrollbarcolor;
 
@@ -1213,7 +1213,7 @@ long FXScrollBar::onPaint(FXObject*,FXSelector,void* ptr)
     // At first run, select the scrollbar style and color
     if (init)
     {
-        use_clearlooks=getApp()->reg().readUnsignedEntry("SETTINGS","use_clearlooks",TRUE);
+        use_clearlooks=getApp()->reg().readUnsignedEntry("SETTINGS","use_clearlooks",true);
         scrollbarcolor=getApp()->reg().readColorEntry("SETTINGS","scrollbarcolor",FXRGB(237,233,227));
 
         // Compute gradient colors from the base color
@@ -1242,7 +1242,7 @@ long FXScrollBar::onPaint(FXObject*,FXSelector,void* ptr)
             sb_bordercolor=sb_bordercolor; // avoids unused variable compiler warning
             sb_lightcolor=FXRGB(FXMIN(1.3*r,255),FXMIN(1.3*g,255),FXMIN(1.3*b,255));
         }
-        init=FALSE;
+        init=false;
     }
 
     // Nice scrollbar with gradient and rounded corners
@@ -1412,7 +1412,7 @@ FXComboBox::FXComboBox(FXComposite *p,int cols,FXObject* tgt,FXSelector sel,FXui
     // !!! End of hack
 
     if (options&COMBOBOX_STATIC)
-        field->setEditable(FALSE);
+        field->setEditable(false);
     pane=new FXPopup(this,FRAME_LINE);
     list=new FXList(pane,this,FXComboBox::ID_LIST,LIST_BROWSESELECT|LIST_AUTOSELECT|LAYOUT_FILL_X|LAYOUT_FILL_Y|SCROLLERS_TRACK|HSCROLLER_NEVER);
     if (options&COMBOBOX_STATIC)
@@ -1446,9 +1446,9 @@ long FXMenuTitle::onPaint(FXObject*,FXSelector,void* ptr)
     xx=6;
     yy=0;
 
-    if(isEnabled())
+    if (isEnabled())
     {
-        if(isActive())
+        if (isActive())
         {
             // Button with nice gradient effect and rounded corners (Clearlooks)
             if (use_clearlooks)
@@ -1482,7 +1482,7 @@ long FXMenuTitle::onPaint(FXObject*,FXSelector,void* ptr)
             xx++;
             yy++;
         }
-        else if(underCursor())
+        else if (underCursor())
         {
             // Button with nice gradient effect and rounded corners (Clearlooks)
             if (use_clearlooks)
@@ -1510,18 +1510,18 @@ long FXMenuTitle::onPaint(FXObject*,FXSelector,void* ptr)
             dc.fillRectangle(0,0,width,height);
         }
 
-        if(icon)
+        if (icon)
         {
             dc.drawIcon(icon,xx,yy+(height-icon->getHeight())/2);
             xx+=5+icon->getWidth();
         }
 
-        if(!label.empty())
+        if (!label.empty())
         {
             yy+=font->getFontAscent()+(height-font->getFontHeight())/2;
             dc.setForeground(isActive() ? seltextColor : textColor);
             dc.drawText(xx,yy,label);
-            if(0<=hotoff)
+            if (0<=hotoff)
                 dc.fillRectangle(xx+font->getTextWidth(&label[0],hotoff),yy+1,font->getTextWidth(&label[hotoff],wclen(&label[hotoff])),1);
         }
     }
@@ -1530,21 +1530,21 @@ long FXMenuTitle::onPaint(FXObject*,FXSelector,void* ptr)
     {
         dc.setForeground(backColor);
         dc.fillRectangle(0,0,width,height);
-        if(icon)
+        if (icon)
         {
             dc.drawIconSunken(icon,xx,yy+(height-icon->getHeight())/2);
             xx+=5+icon->getWidth();
         }
-        if(!label.empty())
+        if (!label.empty())
         {
             yy+=font->getFontAscent()+(height-font->getFontHeight())/2;
             dc.setForeground(hiliteColor);
             dc.drawText(xx+1,yy+1,label);
-            if(0<=hotoff)
+            if (0<=hotoff)
                 dc.fillRectangle(xx+font->getTextWidth(&label[0],hotoff),yy+1,font->getTextWidth(&label[hotoff],wclen(&label[hotoff])),1);
             dc.setForeground(shadowColor);
             dc.drawText(xx,yy,label);
-            if(0<=hotoff)
+            if (0<=hotoff)
                 dc.fillRectangle(xx+font->getTextWidth(&label[0],hotoff),yy+1,font->getTextWidth(&label[hotoff],wclen(&label[hotoff])),1);
         }
     }
@@ -1562,13 +1562,13 @@ long FXMenuTitle::onPaint(FXObject*,FXSelector,void* ptr)
 long FXRadioButton::onPaint(FXObject*,FXSelector,void* ptr)
 {
     // Initialize Clearlooks (don't use the macro because here it's different)
-    static FXbool init=TRUE;
-    static FXbool use_clearlooks=TRUE;
+    static FXbool init=true;
+    static FXbool use_clearlooks=true;
     static FXColor bordercolor;
 
     if (init)
     {
-        use_clearlooks=getApp()->reg().readUnsignedEntry("SETTINGS","use_clearlooks",TRUE);
+        use_clearlooks=getApp()->reg().readUnsignedEntry("SETTINGS","use_clearlooks",true);
 
         if (use_clearlooks)
         {
@@ -1578,7 +1578,7 @@ long FXRadioButton::onPaint(FXObject*,FXSelector,void* ptr)
 
             bordercolor=FXRGB(0.5*r,0.5*g,0.5*b);
         }
-        init=FALSE;
+        init=false;
     }
 
     FXEvent *ev=(FXEvent*)ptr;
@@ -1589,7 +1589,7 @@ long FXRadioButton::onPaint(FXObject*,FXSelector,void* ptr)
     dc.setForeground(backColor);
     dc.fillRectangle(ev->rect.x,ev->rect.y,ev->rect.w,ev->rect.h);
 
-    if(!label.empty())
+    if (!label.empty())
     {
         tw=labelWidth(label);
         th=labelHeight(label);
@@ -1619,7 +1619,7 @@ long FXRadioButton::onPaint(FXObject*,FXSelector,void* ptr)
     recs[4].y=iy+9;
     recs[4].w=4;
     recs[4].h=1;
-    if(!isEnabled())                   // fix by Daniel Gehriger (gehriger@linkcad.com)
+    if (!isEnabled())                   // fix by Daniel Gehriger (gehriger@linkcad.com)
         dc.setForeground(baseColor);
     else
         dc.setForeground(diskColor);
@@ -1802,7 +1802,7 @@ long FXRadioButton::onPaint(FXObject*,FXSelector,void* ptr)
 	}
 
     // Ball inside
-    if(check!=FALSE)
+    if (check!=false)
     {
         recs[0].x=ix+5;
         recs[0].y=iy+4;
@@ -1816,7 +1816,7 @@ long FXRadioButton::onPaint(FXObject*,FXSelector,void* ptr)
         recs[2].y=iy+7;
         recs[2].w=2;
         recs[2].h=1;
-        if(isEnabled())
+        if (isEnabled())
             dc.setForeground(radioColor);
         else
             dc.setForeground(shadowColor);
@@ -1824,14 +1824,14 @@ long FXRadioButton::onPaint(FXObject*,FXSelector,void* ptr)
     }
 
     // Label
-    if(!label.empty())
+    if (!label.empty())
     {
         dc.setFont(font);
-        if(isEnabled())
+        if (isEnabled())
         {
             dc.setForeground(textColor);
             drawLabel(dc,label,hotoff,tx,ty,tw,th);
-            if(hasFocus())
+            if (hasFocus())
             {
                 dc.drawFocusRectangle(tx-1,ty-1,tw+2,th+2);
             }
@@ -2339,14 +2339,14 @@ long FXArrowButton::onPaint(FXObject*,FXSelector,void* ptr)
 // Draw only the interior, i.e. the part that changes
 void FXProgressBar::drawInterior(FXDCWindow& dc)
 {
-    static FXbool init=TRUE;
-    static FXbool use_clearlooks=TRUE;
+    static FXbool init=true;
+    static FXbool use_clearlooks=true;
     static FXColor topcolor, bottomcolor;
 
     // Init Clearlooks (don't use the macro because here it's different)
     if (init)
     {
-        use_clearlooks=getApp()->reg().readUnsignedEntry("SETTINGS","use_clearlooks",TRUE);
+        use_clearlooks=getApp()->reg().readUnsignedEntry("SETTINGS","use_clearlooks",true);
 
         if (use_clearlooks)
         {
@@ -2357,11 +2357,11 @@ void FXProgressBar::drawInterior(FXDCWindow& dc)
             topcolor=FXRGB(FXMIN(1.2*r,255),FXMIN(1.2*g,255),FXMIN(1.2*b,255));
             bottomcolor=FXRGB(0.9*r,0.9*g,0.9*b);
         }
-        init=FALSE;
+        init=false;
     }
 
     int percent,barlength,barfilled,tx,ty,tw,th,n,d;
-    char numtext[5];
+    char numtext[6];
 
     if (options&PROGRESSBAR_DIAL)
     {
@@ -2456,7 +2456,7 @@ void FXProgressBar::drawInterior(FXDCWindow& dc)
             if (use_clearlooks)
             {
                 dc.setForeground(barColor);
-                drawGradientRectangle(dc,topcolor,bottomcolor,border,height-border-barfilled,width-(border<<1),barfilled,FALSE);
+                drawGradientRectangle(dc,topcolor,bottomcolor,border,height-border-barfilled,width-(border<<1),barfilled,false);
             }
             // Standard (flat)
             else
@@ -2528,7 +2528,7 @@ void FXProgressBar::drawInterior(FXDCWindow& dc)
             if (use_clearlooks)
             {
                 dc.setForeground(barColor);
-                drawGradientRectangle(dc,topcolor,bottomcolor,border,border,barfilled,height-(border<<1),TRUE);
+                drawGradientRectangle(dc,topcolor,bottomcolor,border,border,barfilled,height-(border<<1),true);
             }
             // Standard (flat)
             else
@@ -2589,8 +2589,8 @@ void FXProgressBar::drawInterior(FXDCWindow& dc)
 // This hack optionally draws a rectangle with rounded corners (Clearlooks)
 void FXPacker::drawGrooveRectangle(FXDCWindow& dc,FXint x,FXint y,FXint w,FXint h)
 {
-    static FXbool init=TRUE;
-    static FXbool use_clearlooks=TRUE;
+    static FXbool init=true;
+    static FXbool use_clearlooks=true;
     static FXColor shadecolor, bordercolor;
 
     FXPoint bordershade[16]= {FXPoint(x,y+1),FXPoint(x+1,y),FXPoint(x+1,y+2),FXPoint(x+2,y+1),
@@ -2606,7 +2606,7 @@ void FXPacker::drawGrooveRectangle(FXDCWindow& dc,FXint x,FXint y,FXint w,FXint
 
     if (init)
     {
-        use_clearlooks=getApp()->reg().readUnsignedEntry("SETTINGS","use_clearlooks",TRUE);
+        use_clearlooks=getApp()->reg().readUnsignedEntry("SETTINGS","use_clearlooks",true);
 
         if (use_clearlooks)
         {
@@ -2618,7 +2618,7 @@ void FXPacker::drawGrooveRectangle(FXDCWindow& dc,FXint x,FXint y,FXint w,FXint
             bordercolor=FXRGB(0.5*r,0.5*g,0.5*b);
             bordercolor=bordercolor; // // avoids unused variable compiler warning
         }
-        init=FALSE;
+        init=false;
     }
 
     if (0<w && 0<h)
