@@ -45,13 +45,14 @@
     - UTF-8 support\n \
     - Commander/Explorer interface with four file manager modes : a) one panel, b) a folder tree\n \
       and one panel, c) two panels and d) a folder tree and two panels\n \
+    - Horizontal or vertical file panels stacking\n \
     - Panels synchronization and switching\n \
-    - Integrated text editor (X File Write, Xfw)\n \
-    - Integrated text viewer (X File View, Xfv)\n \
+    - Integrated text editor and viewer (X File Write, Xfw)\n \
     - Integrated image viewer (X File Image, Xfi)\n \
     - Integrated package (rpm or deb) viewer / installer / uninstaller (X File Package, Xfp)\n \
     - Custom shell scripts (like Nautilus scripts)\n \
     - Search files and directories\n \
+    - Natural sort order (foo10.txt comes after foo2.txt...)\n \
     - Copy/Cut/Paste files from and to your favorite desktop (GNOME/KDE/XFCE/ROX)\n \
     - Drag and Drop files from and to your favorite desktop (GNOME/KDE/XFCE/ROX)\n \
     - Root mode with authentication by su or sudo\n \
@@ -71,6 +72,7 @@
     - Icon themes (Xfe, GNOME, KDE, XFCE, Tango, Windows...)\n \
     - Control themes (Standard or Clearlooks like)\n \
     - Create archives (tar, compress, zip, gzip, bzip2, xz and 7zip formats are supported)\n \
+    - File comparison (through external tool)\n \
     - Extract archives (tar, compress, zip, gzip, bzip2, xz, lzh, rar, ace, arj and 7zip formats are supported)\n \
     - Tooltips with file properties\n \
     - Progress bars or dialogs for lengthy file operations\n \
@@ -89,7 +91,7 @@
     * Select all                         - Ctrl-A\n \
     * Copy to clipboard                  - Ctrl-C\n \
     * Search                             - Ctrl-F\n \
-    * Search previous                    - Shift-Ctrl-G\n \
+    * Search previous                    - Ctrl-Shift-G\n \
     * Search next                        - Ctrl-G\n \
     * Go to home folder                  - Ctrl-H\n \
     * Invert selection                   - Ctrl-I\n \
@@ -108,6 +110,8 @@
     * Detailed file list                 - F12\n \
     * Toggle display hidden files        - Ctrl-F6\n \
     * Toggle display thumbnails          - Ctrl-F7\n \
+    * Vertical panels                    - Ctrl-Shift-F1\n \
+    * Horizontal panels                  - Ctrl-Shift-F2\n \
     * Go to working folder               - Shift-F2\n \
     * Go to parent folder                - Backspace\n \
     * Go to previous folder              - Ctrl-Backspace\n \
@@ -166,21 +170,20 @@
     * Replace string                    - Ctrl-R\n \
     * Save changes to file              - Ctrl-S\n \
     * Toggle line numbers mode          - Ctrl-T\n \
-    * Toggle upper case mode            - Shift-Ctrl-U\n \
+    * Toggle upper case mode            - Ctrl-Shift-U\n \
     * Toggle lower case mode            - Ctrl-U\n \
     * Redo last change                  - Ctrl-Y\n \
     * Undo last change                  - Ctrl-Z\n \
 \n \
 \n \
- X File View (Xfv) and X File Package (Xfp) only use some of the global key bindings.\n \
+ X File Package (Xfp) only use some of the global key bindings.\n \
 \n \
  Note that all the default key bindings listed above can be customized in the Xfe Preferences dialog. However,\n \
  some key actions are hardcoded an cannot be changed. These include:\n \
 \n \
     * Ctrl-+ and Ctrl--                 - zoom in and zoom out image in Xfi\n \
     * Shift-F10                         - display context menus in Xfe\n \
-    * Return                            - enter folders in file lists, open files, select button actions, etc.\n \
-    * Space                             - enter folders in file lists\n \
+    * Return, Space                     - enter folders in file lists, open files, select button actions, etc.\n \
     * Esc                               - close current dialog, unselect files, etc.\n \
 \n \
 \n \
@@ -219,8 +222,8 @@
  Starting with version 1.32, the location of the local configuration files has changed. This is to be compliant\n \
  with the freedesktop.org standards.\n \
  \n \
- The local configuration files for Xfe, Xfw, Xfv, Xfi, Xfp are now located in the ~/.config/xfe folder.\n \
- They are named xferc, xfwrc, xfvrc, xfirc and xfprc.\n \
+ The local configuration files for Xfe, Xfw, Xfi, Xfp are now located in the ~/.config/xfe folder.\n \
+ They are named xferc, xfwrc, xfirc and xfprc.\n \
  \n \
  At the very first Xfe run, the system-wide configuration file is copied into the local configuration file\n \
  ~/.config/xfe/xferc which does not exists yet. If the system-wide configuration file is not found\n \
@@ -313,6 +316,13 @@
       the file name.\n \
     - In a file operation dialog, select a filename in the line containing the source name and paste it directly\n \
       to the destination using the middle button of your mouse. Then modify it to suit your needs.\n \
+\n \
+ Add files to the clipboard\n \
+    - You can select files from a directory, copy them to the clipboard by pressing Ctrl-C. This erases the previous\n \
+      clipboard content. Then, you can move to another directory, select other files and add them to the clipboard\n \
+      content by pressing Shift-Ctrl-C. This does not erase the previous clipboard content. At last, you can move\n \
+      to the destination and press Ctrl-V to copy all the files you have in the clipboard. Of course, this also works\n \
+      with Ctrl-X and Shift-Ctrl-X to cut and paste the files.\n \
 \n \
  Startup notification\n \
     - Startup notification is the process that displays a feedback (a sandbox cursor or whatever) to the user when\n \
@@ -322,6 +332,14 @@
       applications, by using the dedicated option in the first tab of the Properties dialog. This latter way is\n \
       only available when the file is an executable. Disabling startup notification can be useful when starting\n \
       an old application that doesn't support the startup notification protocol (e.g. Xterm).\n \
+\n \
+  Root mode\n \
+    - If you use the sudo root mode, it can be useful to add password feedback to the sudo command. For this purpose,\n \
+      edit your sudoers file like this:\n \
+          sudo visudo -f /etc/suoders\n \
+      and then add 'pwfeedback' to the default options, as shown below:\n \
+          Defaults         env_reset,pwfeedback\n \
+      After that, you should see stars (like *****) when you type your password in the small authentication window.\n \
 \n \
 \n \
 \n \
@@ -352,7 +370,7 @@
  Many thanks to Maxim Baranov for his excellent X Win Commander and to all people that have provided useful\n \
  patches, translations, tests and advices.\n \
 \n \
- [Last revision: 16/09/2013]\n \
+ [Last revision: 11/01/2015]\n \
 \n \
  ")
 ;
