@@ -7,18 +7,19 @@
 #include <FXPNGIcon.h>
 
 #include "xfedefs.h"
+#include "xfeutils.h"
 #include "icons.h"
 
 
 // Icons (global variables)
 
 FXIcon *archaddicon, *archexticon, *attribicon, *bigblockdevicon, *bigbrokenlinkicon, *bigcdromicon, *bigchardevicon;
-FXIcon *bigdocicon, *bigexecicon, *bigfloppyicon, *bigfolderlockedicon, *bigfolderopenicon;
+FXIcon *bigcompareicon, *bigdocicon, *bigexecicon, *bigfloppyicon, *bigfolderlockedicon, *bigfolderopenicon;
 FXIcon *bigfoldericon, *bigfolderupicon, *bigharddiskicon, *bigiconsicon, *biglinkicon, *bignfsdriveicon;
 FXIcon *bignfsdriveumticon, *bigpipeicon, *bigsocketicon, *bigzipicon, *cdromicon;
 FXIcon *closefileicon, *clrbookicon, *collfoldericon, *copy_bigicon, *colltreeicon;
 FXIcon *copy_clpicon, *cut_clpicon, *delete_big_permicon, *delete_bigicon, *deselicon, *detailsicon;
-FXIcon *dirupicon, *editicon, *entericon, *errorbigicon, *exptreeicon;
+FXIcon *dirupicon, *editicon, *entericon, *errorbigicon, *exptreeicon, *compareicon;
 FXIcon *filedelete_permicon, *filedeleteicon, *fileopenicon;
 FXIcon *viewicon, *filtericon, *find_againicon, *fliplricon, *flipudicon, *floppyicon;
 FXIcon *fontsicon, *gotobigicon, *gotodiricon, *gotolineicon, *harddiskicon, *helpicon, *hidehiddenicon;
@@ -35,56 +36,18 @@ FXIcon *searchnexticon, *searchicon, *searchprevicon, *selallicon, *setbookicon,
 FXIcon *showhiddenicon, *shownumbersicon, *showthumbicon, *smalliconsicon;
 FXIcon *trash_full_bigicon, *trash_fullicon, *treeonepanelicon, *treetwopanelsicon, *twopanelsicon;
 FXIcon *undoicon, *unmaphosticon, *uppercaseicon, *warningbigicon, *workicon, *wrapofficon, *wraponicon, *xfeicon, *xfiicon;
-FXIcon *xfpicon, *xfvicon, *xfwicon, *zipicon, *zoom100icon, *zoominicon, *zoomouticon, *zoomwinicon;
+FXIcon *xfpicon, *xfwicon, *zipicon, *zoom100icon, *zoominicon, *zoomouticon, *zoomwinicon;
 FXIcon *totrashicon, *dirbackicon, *dirforwardicon, *minixfeicon, *minixferooticon, *filedialogicon, *bigarchaddicon;
 FXIcon *switchpanelsicon, *syncpanelsicon, *newlinkicon, *greenbuttonicon, *graybuttonicon;
-FXIcon *keybindingsicon, *minikeybindingsicon, *filerestoreicon, *restore_bigicon;
+FXIcon *keybindingsicon, *minikeybindingsicon, *filerestoreicon, *restore_bigicon, *vertpanelsicon, *horzpanelsicon;
 
 
-// Load a PNG icon from a file in the icon path
-FXIcon* loadiconfile(FXApp *app, const FXString iconpath, const FXString iconname)
-{
-	// New PNG icon
-	FXIcon *icon=NULL;
-	icon=new FXPNGIcon(app);
-
-	if(icon)
-	{
-		// Find icon in the icon directory
-		FXString iconfile=FXPath::search(iconpath,iconname.text());
-
-		if(!iconfile.empty())
-		{
-			FXFileStream str;
-
-			// Try open the file
-			if(str.open(iconfile,FXStreamLoad))
-			{
-				// Load it
-				icon->loadPixels(str);
-
-				// Create it
-				icon->create();
-
-				// Done
-				str.close();
-
-				return icon;
-			}
-		}
-
-		// Failed, delete the icon
-		fprintf(stderr,_("Error: Failed to load %s icon. Please check your icon path...\n"),iconname.text());
-		delete icon;
-	}
-    return NULL;
-}
 
 
 // Load all application icons as global variables
 FXbool loadAppIcons(FXApp *app)
 {
-	FXbool success=TRUE;
+	FXbool success=true;
 	
 	// Icon path
 	FXString iconpath=app->reg().readStringEntry("SETTINGS","iconpath",DEFAULTICONPATH);
@@ -97,6 +60,7 @@ FXbool loadAppIcons(FXApp *app)
 	success=( (bigbrokenlinkicon=loadiconfile(app,iconpath,"bigbrokenlink.png")) != NULL ) & success;
 	success=( (bigcdromicon=loadiconfile(app,iconpath,"bigcdrom.png")) != NULL ) & success;
 	success=( (bigchardevicon=loadiconfile(app,iconpath,"bigchardev.png")) != NULL ) & success;
+	success=( (bigcompareicon=loadiconfile(app,iconpath,"bigcompare.png")) != NULL ) & success;
 	success=( (bigdocicon=loadiconfile(app,iconpath,"bigdoc.png")) != NULL ) & success;
 	success=( (bigexecicon=loadiconfile(app,iconpath,"bigexec.png")) != NULL ) & success;
 	success=( (bigfloppyicon=loadiconfile(app,iconpath,"bigfloppy.png")) != NULL ) & success;
@@ -128,6 +92,7 @@ FXbool loadAppIcons(FXApp *app)
 	success=( (entericon=loadiconfile(app,iconpath,"enter.png")) != NULL ) & success;
 	success=( (errorbigicon=loadiconfile(app,iconpath,"errorbig.png")) != NULL ) & success;
 	success=( (exptreeicon=loadiconfile(app,iconpath,"exptree.png")) != NULL ) & success;
+	success=( (compareicon=loadiconfile(app,iconpath,"compare.png")) != NULL ) & success;
 	success=( (filedelete_permicon=loadiconfile(app,iconpath,"filedelete_perm.png")) != NULL ) & success;
 	success=( (filedeleteicon=loadiconfile(app,iconpath,"filedelete.png")) != NULL ) & success;
 	success=( (fileopenicon=loadiconfile(app,iconpath,"fileopen.png")) != NULL ) & success;
@@ -217,7 +182,6 @@ FXbool loadAppIcons(FXApp *app)
 	success=( (xfeicon=loadiconfile(app,iconpath,"xfe.png")) != NULL ) & success;
 	success=( (xfiicon=loadiconfile(app,iconpath,"xfi.png")) != NULL ) & success;
 	success=( (xfpicon=loadiconfile(app,iconpath,"xfp.png")) != NULL ) & success;
-	success=( (xfvicon=loadiconfile(app,iconpath,"xfv.png")) != NULL ) & success;
 	success=( (xfwicon=loadiconfile(app,iconpath,"xfw.png")) != NULL ) & success;
 	success=( (zipicon=loadiconfile(app,iconpath,"zip.png")) != NULL ) & success;
 	success=( (zoom100icon=loadiconfile(app,iconpath,"zoom100.png")) != NULL ) & success;
@@ -240,6 +204,8 @@ FXbool loadAppIcons(FXApp *app)
 	success=( (minikeybindingsicon=loadiconfile(app,iconpath,"minikeybindings.png")) != NULL ) & success;
 	success=( (filerestoreicon=loadiconfile(app,iconpath,"filerestore.png")) != NULL ) & success;
 	success=( (restore_bigicon=loadiconfile(app,iconpath,"restore_big.png")) != NULL ) & success;
+	success=( (horzpanelsicon=loadiconfile(app,iconpath,"horzpanels.png")) != NULL ) & success;
+	success=( (vertpanelsicon=loadiconfile(app,iconpath,"vertpanels.png")) != NULL ) & success;
 		
 	return success;
 }
