@@ -3,7 +3,6 @@
 
 
 // Prototypes
-FXIcon* loadiconfile(FXApp *app, const FXString iconpath, const FXString iconname);
 FXbool loadAppIcons(FXApp *app);
 
 
@@ -15,6 +14,7 @@ extern FXIcon *bigblockdevicon;
 extern FXIcon *bigbrokenlinkicon;
 extern FXIcon *bigcdromicon;
 extern FXIcon *bigchardevicon;
+extern FXIcon *bigcompareicon;
 extern FXIcon *bigdocicon;
 extern FXIcon *bigexecicon;
 extern FXIcon *bigfloppyicon;
@@ -51,6 +51,7 @@ extern FXIcon *filedeleteicon;
 extern FXIcon *fileopenicon;
 extern FXIcon *viewicon;
 extern FXIcon *filtericon;
+extern FXIcon *compareicon;
 extern FXIcon *find_againicon;
 extern FXIcon *fliplricon;
 extern FXIcon *flipudicon;
@@ -135,7 +136,6 @@ extern FXIcon *wraponicon;
 extern FXIcon *xfeicon;
 extern FXIcon *xfiicon;
 extern FXIcon *xfpicon;
-extern FXIcon *xfvicon;
 extern FXIcon *xfwicon;
 extern FXIcon *zipicon;
 extern FXIcon *zoom100icon;
@@ -158,5 +158,7 @@ extern FXIcon *keybindingsicon;
 extern FXIcon *minikeybindingsicon;
 extern FXIcon *filerestoreicon;
 extern FXIcon *restore_bigicon;
+extern FXIcon *horzpanelsicon;
+extern FXIcon *vertpanelsicon;
 #endif
 
