@@ -158,7 +158,7 @@ bool FXApp::runOneEvent(bool blocking)
 	// root window (but not all as INITIATE messages go to
 	// all root windows)
 
-	static FXbool firstcall=TRUE;
+	static FXbool firstcall=true;
 	static SnDisplay *sndisplay;
 	//static SnMonitorContext *context;
 	if (firstcall)
@@ -168,10 +168,10 @@ bool FXApp::runOneEvent(bool blocking)
 		sndisplay = sn_display_new ((Display*)display,error_trap_push,error_trap_pop);
 		//context = sn_monitor_context_new (sndisplay, DefaultScreen ((Display*)display),snmonitor,NULL, NULL);  
 		sn_monitor_context_new (sndisplay, DefaultScreen ((Display*)display),snmonitor,NULL, NULL);  
-		firstcall=FALSE;
+		firstcall=false;
 	}
  
-	if(getNextEvent(ev,blocking))
+	if (getNextEvent(ev,blocking))
 	{		
 		// Check if startup timeout expired
 		time_t t;
@@ -195,11 +195,14 @@ bool FXApp::runOneEvent(bool blocking)
 
 // Global variables
 char **args;
+FXbool run_ibus=false;
+
 #if defined(linux)
-FXbool deb_based=FALSE;
-FXbool rpm_based=FALSE;
+FXuint pkg_format;
 #endif
 
+
+
 // Base directories (according to the Freedesktop specification version 0.7)
 FXString homedir;
 FXString xdgdatahome;
@@ -242,9 +245,9 @@ int panel_mode=-1;
   
 // Usage message
 #define USAGE_MSG	_("\
-\nUsage: xfe [options] [startdir1] [startdir2]\n\
+\nUsage: xfe [options...] [FOLDER|FILE...]\n\
 \n\
-    [options] can be any of the following:\n\
+    [options...] are the following:\n\
 \n\
         -h,   --help         Print (this) help screen and exit.\n\
         -v,   --version      Print version information and exit.\n\
@@ -253,8 +256,9 @@ int panel_mode=-1;
         -p n, --panel n      Force panel view mode to n (n=0 => Tree and one panel,\n\
                              n=1 => One panel, n=2 => Two panels, n=3 => Tree and two panels).\n\
 \n\
-    [startdir1] and [startdir2] are the paths to the initial folders you want to\n\
-    open on start up.\n\
+    [FOLDER|FILE...] is a list of folders or files to open on startup.\n\
+    The first two folders are displayed in the file panels, the others are ignored.\n\
+    The number of files to open is not limited.\n\
 \n")
 
 
@@ -266,20 +270,23 @@ int main(int argc,char *argv[])
 	const char *vdrname = "Xfe";
 	int i;
 	FXbool loadicons;
-	FXString startdir1="";
+	FXString startfiledir1="";
 	FXString startdir2="";
-	FXbool iconic=FALSE;
-	FXbool maximized=FALSE;
+	FXbool iconic=false;
+	FXbool maximized=false;
+
+	// Vector of URIs to open on startup
+    vector_FXString startURIs;
 
 	// Get environment variables $HOME, $XDG_DATA_HOME and $XDG_CONFIG_HOME
 	homedir=FXSystem::getHomeDirectory();
-    if(homedir=="")
+    if (homedir=="")
         homedir=ROOTDIR;
 	xdgdatahome=getenv("XDG_DATA_HOME");
-    if(xdgdatahome=="")
+    if (xdgdatahome=="")
         xdgdatahome=homedir + PATHSEPSTRING DATAPATH;     
 	xdgconfighome=getenv("XDG_CONFIG_HOME");
-    if(xdgconfighome=="")
+    if (xdgconfighome=="")
         xdgconfighome=homedir + PATHSEPSTRING CONFIGPATH;
 
 #ifdef HAVE_SETLOCALE
@@ -296,70 +303,62 @@ int main(int argc,char *argv[])
 
 #if defined(linux)
 
-    // Test the existence of dpkg to see if the Linux distro is Debian based
-	// This is done by checking the existence of the string 'Debian'
-	// in the response to the command 'dpkg' (with --version argument)
-	FXString cmd="dpkg --version 2>&1";
-    FILE *debcmd=popen(cmd.text(),"r");
-    if(!debcmd)
-    {
-        perror("popen");
-        exit(1);
-    }
-    char textdeb[10000]={0};
-    FXString bufdeb;
-    while(fgets(textdeb,sizeof(textdeb),debcmd))
-        bufdeb+=textdeb;
-    snprintf(textdeb,sizeof(textdeb)-1,"%s",bufdeb.text());
-	if (strstr(textdeb,"Debian")!=NULL)
-		deb_based=TRUE;
-	pclose(debcmd);
-	
-	// If the distro is not Debian based, test if it is Redhat based
-	// This is done by checking the existence of the string 'RPM'
-	// in the response to the command 'rpm --version'	
-	if (!deb_based)
+    // For package query on Linux systems, try to guess if the default package format is deb or rpm:
+    //   - if dpkg exists then the system uses deb packages
+    //   - else if rpm exists, then the system uses rpm packages
+	//   - else another (unsupported) package manager is used
+	FXString cmd, str;
+
+	cmd="dpkg --version";
+	str=getCommandOutput(cmd);
+
+	if (str.find("Debian") != -1)
+		pkg_format=DEB_PKG; // deb based system
+
+	else
 	{
-		cmd="rpm --version 2>&1";
-		FILE *rpmcmd=popen(cmd.text(),"r");
-		if(!rpmcmd)
-		{
-			perror("popen");
-			exit(1);
-		}
-		char textrpm[10000]={0};
-		FXString bufrpm;
-		while(fgets(textrpm,sizeof(textrpm),rpmcmd))
-			bufrpm+=textrpm;
-		snprintf(textrpm,sizeof(textrpm)-1,"%s",bufrpm.text());
-		if (strstr(textrpm,"RPM")!=NULL)
-			rpm_based=TRUE;
-		pclose(rpmcmd);
+		cmd="rpm --version";
+		str=getCommandOutput(cmd);
+		
+		if (str.find("RPM") != -1)
+			pkg_format=RPM_PKG; // rpm based system
+		
+		else
+			pkg_format=OTHER_PKG; // other (unsupported) package system
 	}
+
 #endif
 
+	// Test if iBus is running (this is used to fix the bug with xim and iBus input managers)
+	cmd="pgrep -u " + FXStringVal(getuid()) + " ibus-daemon";
+	FXuint pid = FXUIntVal(getCommandOutput(cmd));
+	if (pid == 0)
+		run_ibus=false;
+	else
+		run_ibus=true;
+
 	// Parse basic arguments
-	for(i = 1; i < argc; ++i)
+	for (i=1; i<argc; ++i)
 	{
-    	if(compare(argv[i],"-v")==0 || compare(argv[i],"--version")==0)
+    	if (compare(argv[i],"-v")==0 || compare(argv[i],"--version")==0)
 		{
 			fprintf(stdout,"%s version %s\n",PACKAGE,VERSION);
 			exit(0);
 		}
-    	else if(compare(argv[i],"-h")==0 || compare(argv[i],"--help")==0)
+    	else if (compare(argv[i],"-h")==0 || compare(argv[i],"--help")==0)
 		{
 			fprintf(stdout,USAGE_MSG);
 			exit(0);
 		}
-    	else if(compare(argv[i],"-i")==0 || compare(argv[i],"--iconic")==0)
+    	else if (compare(argv[i],"-i")==0 || compare(argv[i],"--iconic")==0)
 		{
-			iconic=TRUE;
+			iconic=true;
 		}
-		else if(compare(argv[i],"-m")==0 || compare(argv[i],"--maximized")==0)
+		else if (compare(argv[i],"-m")==0 || compare(argv[i],"--maximized")==0)
 		{
-			maximized=TRUE;
+			maximized=true;
 		}
-		else if(compare(argv[i],"-p")==0 || compare(argv[i],"--panel")==0 || compare(argv[i],"--panels")==0)
+		else if (compare(argv[i],"-p")==0 || compare(argv[i],"--panel")==0 || compare(argv[i],"--panels")==0)
 		{
 			if ( ++i < argc ) panel_mode=atoi(argv[i]); 
 			if ( (panel_mode<0) || (panel_mode>3) )
@@ -378,14 +377,8 @@ int main(int argc,char *argv[])
 			panel_mode = 3;
 		else
 	    {
-			// Start directories, if any
-			if (startdir1=="")
-			{
-				startdir1=argv[i];
-				continue;
-			}
-			if (startdir2=="")
-				startdir2=argv[i];
+			// Starting URIs, if any
+			startURIs.push_back(::filePath(::fileFromURI(argv[i])));
 	    }
 	}
 
@@ -413,7 +406,7 @@ int main(int argc,char *argv[])
 	// Set normal font
 	FXString fontspec;
 	fontspec=application->reg().readStringEntry("SETTINGS","font","Helvetica,100,normal,regular");
-	if(!fontspec.empty())
+	if (!fontspec.empty())
 	{
     	FXFont* normalFont=new FXFont(application,fontspec);
         application->setNormalFont(normalFont);
@@ -423,21 +416,11 @@ int main(int argc,char *argv[])
 	if (getuid()==0)
         title="Xfe (root)";
 
-	// In case start directories are given in URI form, convert them
-	startdir1=::fileFromURI(startdir1);
-	startdir2=::fileFromURI(startdir2);
-
-	// Make sure start directory paths are clean 
-	if(startdir1!="")
-		startdir1=::filePath(startdir1);
-	if(startdir2!="")
-		startdir2=::filePath(startdir2);
-
    	// Create and run application
-	mainWindow=new XFileExplorer(application,iconic,maximized,startdir1,startdir2,title,xfeicon,minixfeicon);
+	mainWindow=new XFileExplorer(application,startURIs,iconic,maximized,title,xfeicon,minixfeicon);
 
 	// Catch SIGCHLD to harvest zombie child processes
-	application->addSignal(SIGCHLD,mainWindow,XFileExplorer::ID_HARVEST,TRUE);
+	application->addSignal(SIGCHLD,mainWindow,XFileExplorer::ID_HARVEST,true);
 
 	// Also catch interrupt so we can gracefully terminate
 	application->addSignal(SIGINT,mainWindow,XFileExplorer::ID_QUIT);
