@@ -34,7 +34,7 @@ void startup_completed(void)
 		launchee = sn_launchee_context_new_from_environment (display,DefaultScreen (xdisplay));
 
 		// Indicate startup has completed and free resources
-		if(launchee)
+		if (launchee)
 		{
 			sn_launchee_context_complete(launchee);
 			sn_launchee_context_unref(launchee);
@@ -59,7 +59,7 @@ Time gettimestamp (void)
 	window = XCreateWindow(display, DefaultRootWindow (display), 0, 0, 1, 1, 0, 0, InputOnly, 0, 0, NULL);
 	XSelectInput(display, window, PropertyChangeMask);
 	atom_name = XInternAtom(display, "_NET_WM_USER_TIME_WINDOW", False);
-	atom_type = XInternAtom(display, "WINDOW", TRUE);
+	atom_type = XInternAtom(display, "WINDOW", true);
 	XChangeProperty(display, window, atom_name, atom_type, 8, PropModeReplace, (const FXuchar*)&window, 1);
 	XNextEvent(display, &event);
 	assert(event.type == PropertyNotify);
@@ -70,7 +70,7 @@ Time gettimestamp (void)
 
 
 // Launch a command and initiate a startup notification 
-int runcmd(FXString cmd, FXString cmdname, FXString dir, FXString startdir, FXbool usesn=TRUE, FXString snexcepts="")
+int runcmd(FXString cmd, FXString cmdname, FXString dir, FXString startdir, FXbool usesn=true, FXString snexcepts="")
 {
 	int ret;
 	
@@ -91,18 +91,18 @@ int runcmd(FXString cmd, FXString cmdname, FXString dir, FXString startdir, FXbo
 	cmdname=cmdname.before(' ');
 	
 	// Check if command is in the startup notification exception list
-	FXbool startup_notify=TRUE;
-	if(snexcepts != "")
+	FXbool startup_notify=true;
+	if (snexcepts != "")
 	{
 		FXString entry;
-		for(int i=0; ; i++)
+		for (int i=0; ; i++)
 		{
 			entry=snexcepts.section(':',i);
-			if(streq(entry.text(),""))
+			if (streq(entry.text(),""))
 				break;
-			if(streq(entry.text(),cmdname.text()))
+			if (streq(entry.text(),cmdname.text()))
 			{
-				startup_notify=FALSE;
+				startup_notify=false;
 				break;
 			}
 		}
