@@ -9,11 +9,13 @@
 
 void startup_completed (void);
 Time gettimestamp (void);
-FXint runcmd(FXString, FXString, FXbool, FXString);
+int runcmd(FXString, FXString, FXString, FXString, FXbool, FXString);
 
 #else
 
-FXint runcmd(FXString);
+#include <X11/Xlib.h>
+
+int runcmd(FXString, FXString, FXString);
 
 #endif
 
