@@ -15,6 +15,7 @@
 
 #include <fx.h>
 #include <fxkeys.h>
+#include <FXPNGIcon.h>
 
 #include "xfedefs.h"
 #include "icons.h"
@@ -23,6 +24,36 @@
 
 
 
+// Decode filename to get original again
+FXString FXPath::dequote(const FXString& file){
+  FXString result(file);
+  if (0<result.length()){
+    register FXint e=result.length();
+    register FXint b=0;
+    register FXint r=0;
+    register FXint q=0;
+
+    // Trim tail
+    while(0<e && Ascii::isSpace(result[e-1])) --e;
+
+    // Trim head
+    while(b<e && Ascii::isSpace(result[b])) ++b;
+
+    // Dequote the rest
+    while(b<e){
+      if (result[b]=='\''){ q=!q; b++; continue; }
+      if (result[b]=='\\' && result[b+1]=='\'' && !q){ b++; }
+      result[r++]=result[b++];
+      }
+
+    // Trunc to size
+    result.trunc(r);
+    }
+  return result;
+  }
+
+
+
 // Note : the original function from FXAccelTable is buggy!!
 // Parse accelerator from string
 FXHotKey _parseAccel(const FXString& string)
@@ -38,27 +69,27 @@ FXHotKey _parseAccel(const FXString& string)
 	while(pos<string.length())
 	{
 		// Modifier
-		if(comparecase(&string[pos],"ctl",3)==0)
+		if (comparecase(&string[pos],"ctl",3)==0)
 		{
 			mods|=CONTROLMASK;
 			pos+=3;
 		}
-		else if(comparecase(&string[pos],"ctrl",4)==0)
+		else if (comparecase(&string[pos],"ctrl",4)==0)
 		{
 			mods|=CONTROLMASK;
 			pos+=4;
 		}
-		else if(comparecase(&string[pos],"alt",3)==0)
+		else if (comparecase(&string[pos],"alt",3)==0)
 		{
 			mods|=ALTMASK;
 			pos+=3;
 		}
-		else if(comparecase(&string[pos],"meta",4)==0)
+		else if (comparecase(&string[pos],"meta",4)==0)
 		{
 			mods|=METAMASK;
 			pos+=4;
 		}
-		else if(comparecase(&string[pos],"shift",5)==0)
+		else if (comparecase(&string[pos],"shift",5)==0)
 		{
 			mods|=SHIFTMASK;
 			pos+=5;
@@ -67,50 +98,50 @@ FXHotKey _parseAccel(const FXString& string)
 			break;
 
 		// Separator
-		if(string[pos]=='+' || string[pos]=='-' || Ascii::isSpace(string[pos]))
+		if (string[pos]=='+' || string[pos]=='-' || Ascii::isSpace(string[pos]))
 			pos++;
 	}
 
 	// Test for some special keys
-	if(comparecase(&string[pos],"home",4)==0)
+	if (comparecase(&string[pos],"home",4)==0)
 		code=KEY_Home;
-	else if(comparecase(&string[pos],"end",3)==0)
+	else if (comparecase(&string[pos],"end",3)==0)
 		code=KEY_End;
-	else if(comparecase(&string[pos],"pgup",4)==0)
+	else if (comparecase(&string[pos],"pgup",4)==0)
 		code=KEY_Page_Up;
-	else if(comparecase(&string[pos],"pgdn",4)==0)
+	else if (comparecase(&string[pos],"pgdn",4)==0)
 		code=KEY_Page_Down;
-	else if(comparecase(&string[pos],"left",4)==0)
+	else if (comparecase(&string[pos],"left",4)==0)
 		code=KEY_Left;
-	else if(comparecase(&string[pos],"right",5)==0)
+	else if (comparecase(&string[pos],"right",5)==0)
 		code=KEY_Right;
-	else if(comparecase(&string[pos],"up",2)==0)
+	else if (comparecase(&string[pos],"up",2)==0)
 		code=KEY_Up;
-	else if(comparecase(&string[pos],"down",4)==0)
+	else if (comparecase(&string[pos],"down",4)==0)
 		code=KEY_Down;
-	else if(comparecase(&string[pos],"ins",3)==0)
+	else if (comparecase(&string[pos],"ins",3)==0)
 		code=KEY_Insert;
-	else if(comparecase(&string[pos],"del",3)==0)
+	else if (comparecase(&string[pos],"del",3)==0)
 		code=KEY_Delete;
-	else if(comparecase(&string[pos],"esc",3)==0)
+	else if (comparecase(&string[pos],"esc",3)==0)
 		code=KEY_Escape;
-	else if(comparecase(&string[pos],"tab",3)==0)
+	else if (comparecase(&string[pos],"tab",3)==0)
 		code=KEY_Tab;
-	else if(comparecase(&string[pos],"return",6)==0)
+	else if (comparecase(&string[pos],"return",6)==0)
 		code=KEY_Return;
-	else if(comparecase(&string[pos],"enter",5)==0)
+	else if (comparecase(&string[pos],"enter",5)==0)
 		code=KEY_Return;
-	else if(comparecase(&string[pos],"back",4)==0)
+	else if (comparecase(&string[pos],"back",4)==0)
 		code=KEY_BackSpace;
-	else if(comparecase(&string[pos],"spc",3)==0)
+	else if (comparecase(&string[pos],"spc",3)==0)
 		code=KEY_space;
-	else if(comparecase(&string[pos],"space",5)==0)
+	else if (comparecase(&string[pos],"space",5)==0)
 		code=KEY_space;
 
 	// Test for function keys
-	else if(Ascii::toLower(string[pos])=='f' && Ascii::isDigit(string[pos+1]))
+	else if (Ascii::toLower(string[pos])=='f' && Ascii::isDigit(string[pos+1]))
 	{
-		if(Ascii::isDigit(string[pos+2]))
+		if (Ascii::isDigit(string[pos+2]))
 		{			
 			// !!!! Hack to fix a bug in FOX !!!!
 			code=KEY_F1+10*(string[pos+1]-'0')+(string[pos+2]-'0')-1;
@@ -120,13 +151,13 @@ FXHotKey _parseAccel(const FXString& string)
 			code=KEY_F1+string[pos+1]-'1';
 	}
 	// Test if hexadecimal code designator
-	else if(string[pos]=='#')
+	else if (string[pos]=='#')
 		code=strtoul(&string[pos+1],NULL,16);
 
 	// Test if its a single character accelerator
-	else if(Ascii::isPrint(string[pos]))
+	else if (Ascii::isPrint(string[pos]))
 	{
-		if(mods&SHIFTMASK)
+		if (mods&SHIFTMASK)
 			code=Ascii::toUpper(string[pos])+KEY_space-' ';
 		else
 			code=Ascii::toLower(string[pos])+KEY_space-' ';
@@ -135,6 +166,7 @@ FXHotKey _parseAccel(const FXString& string)
 }
 
 
+// Find if the specified command exists
 FXbool existCommand(const FXString cmd)
 {
 	struct stat linfo;
@@ -147,7 +179,7 @@ FXbool existCommand(const FXString cmd)
 	{
 		// Check if command file name exists and is not a directory
 		if (!cmdpath.empty() && (lstatrep(cmdpath.text(),&linfo)==0) && !S_ISDIR(linfo.st_mode))
-			return TRUE;	
+			return true;	
 	}
 
 	// If first character is '~' then cmdpath is a path relative to home directory
@@ -158,7 +190,7 @@ FXbool existCommand(const FXString cmd)
 		
 		// Check if command file name exists and is not a directory
 		if (!cmdpath.empty() && (lstatrep(cmdpath.text(),&linfo)==0) && !S_ISDIR(linfo.st_mode))
-			return TRUE;
+			return true;
 		
 	}
 	
@@ -168,15 +200,15 @@ FXbool existCommand(const FXString cmd)
 		// Get exec path
 		FXString execpath=FXSystem::getExecPath();
 		
-		if(execpath != "")
+		if (execpath != "")
 		{
 			FXString path;
 
-			for(int i=0;;i++)
+			for (int i=0;;i++)
 			{
 				// Obtain path component
 				path=execpath.section(':',i);
-				if(path=="")
+				if (path=="")
 					break;
 				
 				// Form command absolute path
@@ -184,12 +216,12 @@ FXbool existCommand(const FXString cmd)
 
 				// Check if command file name exists and is not a directory
 				if (!path.empty() && (lstatrep(path.text(),&linfo)==0) && !S_ISDIR(linfo.st_mode))
-					return TRUE;
+					return true;
 			}
 		}
     }
 
-	return FALSE;
+	return false;
 }
 
 
@@ -205,13 +237,13 @@ FXString getKeybinding(FXEvent* event)
 	FXString s;
 
 	// Handle modifier keys
-	if(mods&CONTROLMASK)
+	if (mods&CONTROLMASK)
 		s+="Ctrl-";
-	if(mods&ALTMASK)
+	if (mods&ALTMASK)
 		s+="Alt-";
-	if(mods&SHIFTMASK)
+	if (mods&SHIFTMASK)
 		s+="Shift-";
-	if(mods&METAMASK)
+	if (mods&METAMASK)
 		s+="Meta-";
 
 	// Handle some special keys
@@ -301,7 +333,7 @@ FXString getKeybinding(FXEvent* event)
 			s+=buffer;
 			break;
 		default:
-		if(Ascii::isPrint(code))
+		if (Ascii::isPrint(code))
 			s+=Ascii::toUpper(code);
 		else
 			s="";  // Invalid case
@@ -435,7 +467,7 @@ FXString mimetype(FXString pathname)
 {
     FXString cmd ="/usr/bin/file -b -i " + pathname;
     FILE *filecmd=popen(cmd.text(),"r");
-    if(!filecmd)
+    if (!filecmd)
     {
         perror("popen");
         exit(1);
@@ -480,7 +512,7 @@ FXbool isUtf8(const char* string, FXuint length)
         if (((FXuchar)(string[0]) & 0xE0) == 0xC0)
         {
             if (!string[1] || (((FXuchar)(string[1]) & 0xC0) != 0x80))
-                return FALSE;
+                return false;
             string += 2;
 			n += 2;
         }
@@ -490,7 +522,7 @@ FXbool isUtf8(const char* string, FXuint length)
             if (!string[1] || !string[2]
                 || (((FXuchar)(string[1]) & 0xC0) != 0x80)
                 || (((FXuchar)(string[2]) & 0xC0) != 0x80))
-                return FALSE;
+                return false;
             string += 3;
 			n += 3;
        }
@@ -501,14 +533,14 @@ FXbool isUtf8(const char* string, FXuint length)
                 || (((FXuchar)(string[1]) & 0xC0) != 0x80)
                 || (((FXuchar)(string[2]) & 0xC0) != 0x80)
                 || (((FXuchar)(string[3]) & 0xC0) != 0x80))
-                return FALSE;
+                return false;
             string += 4;
 			n += 4;
         }
         // UTF-8, 1 byte, should be: 0vvvvvvv
         else if ((FXuchar)(string[0]) >= 0x80)
 		{
-            return FALSE;
+            return false;
 		}
         // Next byte
 		else
@@ -517,7 +549,7 @@ FXbool isUtf8(const char* string, FXuint length)
 			n++;
 		}
     }
-	return TRUE;
+	return true;
 }
 
 
@@ -585,7 +617,7 @@ FXulong dirsize(const char* path)
 	FXulong dsize=0;
 	int ret;
 			
-	if((dp=opendir(path))==NULL)
+	if ((dp=opendir(path))==NULL)
         return 0;
 	
 	while((dirp=readdir(dp)))
@@ -600,18 +632,18 @@ FXulong dirsize(const char* path)
 		
 #if defined(linux)
 		// Mount points are not processed to improve performances 
-		if(mtdevices->find(buf))
+		if (mtdevices->find(buf))
 			continue;
 #endif
 		
 		ret=lstatrep(buf,&statbuf);
-		if(ret==0)
+		if (ret==0)
 		{
-			if(!S_ISDIR(statbuf.st_mode))
+			if (!S_ISDIR(statbuf.st_mode))
 		  		dsize += (FXulong) statbuf.st_size;
 		}
 	}
-	if(closedir(dp)<0)
+	if (closedir(dp)<0)
         fprintf(stderr,_("Error: Can't close folder %s\n"), path);
 	return dsize;
 }
@@ -632,31 +664,31 @@ FXulong pathsize(char* path, FXuint* nbfiles, FXuint* nbsubdirs)
 	int ret;
 
 	ret=lstatrep(path,&statbuf);
-	if(ret<0)
+	if (ret<0)
         return 0;
     dsize = (FXulong) statbuf.st_size;
 	(*nbfiles)++;
     
 	// Not a directory
-	if(!S_ISDIR(statbuf.st_mode))
+	if (!S_ISDIR(statbuf.st_mode))
         return dsize;
 	
 	// Directory
 	(*nbsubdirs)++;
 
 	ptr=(char*)path + strlen(path);
-    if(ptr[-1]!='/')
+    if (ptr[-1]!='/')
     {
         *ptr++='/';
         *ptr='\0';
     }
     
-	if((dp=opendir(path))==NULL)
+	if ((dp=opendir(path))==NULL)
         return 0;
     
 	while((dirp=readdir(dp)))
     {
-        if( streq(dirp->d_name, ".") || streq(dirp->d_name, "..") )
+        if ( streq(dirp->d_name, ".") || streq(dirp->d_name, "..") )
             continue;
         strlcpy(ptr, dirp->d_name, strlen(dirp->d_name)+1);
 		
@@ -666,13 +698,14 @@ FXulong pathsize(char* path, FXuint* nbfiles, FXuint* nbsubdirs)
 	
     ptr[-1]='\0'; // ??
 	
-    if(closedir(dp)<0)
+    if (closedir(dp)<0)
         fprintf(stderr,_("Error: Can't close folder %s\n"), path);
     return dsize;
 }
 
 
 // Write the file size in human readable form (bytes or Kbytes or Mbytes)
+// We use a decimal basis for KB, MB, GB count
 FXString hSize(char* size)
 {
     int flag=0;
@@ -684,28 +717,28 @@ FXString hSize(char* size)
     float fsize=0.0;
 
 	strlcpy(suf,_("bytes"),sizeof(suf)); 
-	if(lsize>1000000000)
+	if (lsize>1e9)
     {
-        fsize=lsize/1073741824.0;
+        fsize=lsize/1e9;
         strlcpy(suf,_("GB"),sizeof(suf));
         flag=1;
     }
-	else if(lsize>1000000)
+	else if (lsize>1e6)
     {
-        fsize=lsize/1048576.0;
+        fsize=lsize/1e6;
         strlcpy(suf,_("MB"),sizeof(suf));
         flag=1;
     }
-    else if(lsize>1000)
+    else if (lsize>1e3)
     {
-        fsize=lsize/1024.0;
+        fsize=lsize/1e3;
         strlcpy(suf,_("KB"),sizeof(suf));
         flag=1;
     }
   	
-	if(flag)
+	if (flag)
     {
-		if(fsize==(int)fsize)
+		if (fsize==(int)fsize)
             snprintf(buf,sizeof(buf),"%.0f %s",fsize,suf);
         else
             snprintf(buf,sizeof(buf),"%.1f %s",fsize,suf);
@@ -763,7 +796,7 @@ FXString filePath(const FXString path)
 	FXString dir=FXSystem::getCurrentDirectory();
 
 	// If absolute path
-	if(ISPATHSEP(out[0]))
+	if (ISPATHSEP(out[0]))
 		return (out);
 	else
 		return (dir+PATHSEPSTRING+out);
@@ -788,7 +821,7 @@ FXString filePath(const FXString path, const FXString dir)
 			break;
 	}
 	// If absolute path
-	if(ISPATHSEP(out[0]))
+	if (ISPATHSEP(out[0]))
 		return (out);
 	else
 		return (dir+PATHSEPSTRING+out);
@@ -799,9 +832,9 @@ FXString filePath(const FXString path, const FXString dir)
 // If no 'file:' prefix is found, return the input string as is
 FXString fileFromURI(FXString uri)
 {
-	if(comparecase("file:",uri,5)==0)
+	if (comparecase("file:",uri,5)==0)
 	{
-		if(uri[5]==PATHSEPCHAR && uri[6]==PATHSEPCHAR)
+		if (uri[5]==PATHSEPCHAR && uri[6]==PATHSEPCHAR)
 			return uri.mid(7,uri.length()-7);
 		return uri.mid(5,uri.length()-5);
 	}
@@ -817,6 +850,92 @@ FXString fileToURI(const FXString& file)
 }
 
 
+// Construct a target name by adding a suffix that tells it's a copy of the original target file name
+FXString buildCopyName(const FXString& target)
+{
+	const FXString suffix = _("copy");
+
+	FXString copytarget;
+	FXString copystr = " (" + suffix;
+	FXString name = FXPath::name(target);
+	
+	// Get file extensions
+	FXString ext1=name.rafter('.',1);
+	FXString ext2=name.rafter('.',2);
+	FXString ext3=ext2.before('.');
+				
+
+	// Handle the special case of compressed tar archive names
+	if (ext3.lower() == "tar")
+	{
+		FXString basename= target.rbefore('.',2);
+		int pos=basename.rfind(copystr);
+		
+		if (pos <0)
+			copytarget = basename + copystr + ")." + ext2;
+
+		else
+		{
+			// Add a number if it's not the first copy 
+			FXString strnum = target.mid(pos+copystr.length(),target.length()-pos-copystr.length()-ext2.length()-1);
+			FXuint num = FXUIntVal(strnum);
+			num = (num == 0 ? num +2 : num +1);
+									
+			copytarget = target.left(pos) + copystr + " " + FXStringVal(num) + ")." + ext2;
+		}
+	}
+	
+	// Other cases
+	else
+	{
+		// File name has no extension
+		if (ext1 == name)
+		{
+			int pos=target.rfind(copystr);
+			
+			// First copy
+			if (pos <0)
+				copytarget = target + copystr + ")";
+
+			// Add a number to the suffix for next copies
+			else
+			{
+				FXString strnum = target.mid(pos+copystr.length(),target.length()-pos-copystr.length());
+				FXuint num = FXUIntVal(strnum);
+				num = (num == 0 ? num +2 : num +1);
+				copytarget = target.left(pos) + copystr + " " + FXStringVal(num) + ")";
+			}
+		}
+		
+		// File name has an extension
+		else
+		{
+			FXString basename= target.rbefore('.',1);					
+			int pos=basename.rfind(copystr);
+			
+			// First copy
+			if (pos <0)
+				copytarget = basename + copystr + ")." + ext1;
+
+			// Add a number to the suffix for next copies
+			else
+			{
+				FXString strnum = target.mid(pos+copystr.length(),target.length()-pos-copystr.length()-ext1.length()-1);
+				FXuint num = FXUIntVal(strnum);
+				num = (num == 0 ? 2 : num +1);
+				copytarget = target.left(pos) + copystr + " " + FXStringVal(num) + ")." + ext1;
+			}
+		}
+	}
+
+	// Recursive call to avoid existing file names
+	if (::exists(copytarget))
+		copytarget=buildCopyName(copytarget);
+	
+	return copytarget;
+}
+
+
 // Convert the deletion date to the number of seconds since the epoch
 // The string representing the deletion date must be in the format YYYY-MM-DDThh:mm:ss
 FXlong deltime(FXString delstr)
@@ -970,20 +1089,20 @@ FXbool isGroupMember(gid_t gid)
 			else
 				fprintf(stderr,_("Error: Can't read group list"));
 			
-			return FALSE;
+			return false;
 		}
 	}
 	if (ngroups == 0)
-		return FALSE;
+		return false;
 
 	// Check if the group id is contained within the group list
 	i = ngroups;
 	while (i--)
 	{
 		if (gid == gids[i])
-			return TRUE;
+			return true;
 	}
-	return FALSE;
+	return false;
 }
 
 
@@ -999,17 +1118,17 @@ FXbool isReadExecutable(const FXString& file)
 	{
 		int ret=access(file.text(),R_OK|X_OK);
 		if (ret==0)
-			return TRUE;
+			return true;
 		else
-			return FALSE;
+			return false;
 	}	
 	
 	// File doesn't exist
 	else
-		return FALSE;
+		return false;
 }
 
-
+// Check if file is readable
 FXbool isReadable(const FXString& file)
 {	
   	struct stat info;
@@ -1019,17 +1138,18 @@ FXbool isReadable(const FXString& file)
 	{
 		int ret=access(file.text(),R_OK);
 		if (ret==0)
-			return TRUE;
+			return true;
 		else
-			return FALSE;
+			return false;
 	}	
 	
 	// File doesn't exist
 	else
-		return FALSE;
+		return false;
 }
 
 
+// Check if file is writable
 FXbool isWritable(const FXString& file)
 {	
   	struct stat info;
@@ -1039,14 +1159,14 @@ FXbool isWritable(const FXString& file)
 	{
 		int ret=access(file.text(),W_OK);
 		if (ret==0)
-			return TRUE;
+			return true;
 		else
-			return FALSE;
+			return false;
 	}	
 	
 	// File doesn't exist
 	else
-		return FALSE;
+		return false;
 }
 
 
@@ -1090,7 +1210,7 @@ FXString readLink(const FXString& file)
 {
 	char lnk[MAXPATHLEN+1];
 	int len=readlink(file.text(),lnk,MAXPATHLEN);
-	if(0<=len)
+	if (0<=len)
   		return FXString(lnk,len);
   	else
   		return FXString::null;
@@ -1101,12 +1221,12 @@ FXString readLink(const FXString& file)
 // Compare file names and inodes for case insensitive filesystems
 FXbool identical(const FXString& file1,const FXString& file2)
 {
-	if(file1!=file2)
+	if (file1!=file2)
 	{
     	struct stat linfo1, linfo2;
     	return !::lstatrep(file1.text(),&linfo1) && !::lstatrep(file2.text(),&linfo2) && linfo1.st_ino==linfo2.st_ino && linfo1.st_dev==linfo2.st_dev;
     }
-  	return TRUE;
+  	return true;
 }
 
 
@@ -1167,7 +1287,7 @@ int runinxvt(FXString cmd)
 		else
 			nbargs++;
 		
-		if(streq(str1.text(),""))
+		if (streq(str1.text(),""))
 			break;
 		
 		i++;
@@ -1198,7 +1318,7 @@ int runinxvt(FXString cmd)
 			nbargs++;
 		}
 		
-		if(streq(str1.text(),""))
+		if (streq(str1.text(),""))
 			break;
 
 		i++;
@@ -1244,3 +1364,128 @@ int runinxvt(FXString cmd)
 	
 	return res;
 }
+
+
+// Get the output of a Unix command
+// Return the command output or the error message id any
+FXString getCommandOutput(FXString cmd)
+{
+	FXString data;
+	FILE *stream;
+
+	const int max_buffer = 1024;
+	char buffer[max_buffer];
+	
+	cmd += " 2>&1";
+
+	stream = popen(cmd.text(), "r");
+	if (stream)
+	{
+		while (!feof(stream))
+		if (fgets(buffer, max_buffer, stream) != NULL)
+			data += buffer;
+		pclose(stream);
+	}
+	return data;
+}
+
+
+// Load a PNG icon from a file in the icon path
+FXIcon* loadiconfile(FXApp *app, const FXString iconpath, const FXString iconname)
+{
+	// Icon name is empty
+	if (iconname.length() == 0)
+		return NULL;
+		
+	// New PNG icon
+	FXIcon *icon=NULL;
+	icon=new FXPNGIcon(app);
+
+	if (icon)
+	{
+		// Find icon in the icon directory
+		FXString iconfile=FXPath::search(iconpath,iconname.text());
+
+		if (!iconfile.empty())
+		{
+			FXFileStream str;
+
+			// Try open the file
+			if (str.open(iconfile,FXStreamLoad))
+			{
+				// Load it
+				icon->loadPixels(str);
+
+				// Create it
+				icon->create();
+
+				// Done
+				str.close();
+
+				return icon;
+			}
+		}
+
+		// Failed, delete the icon
+		delete icon;
+	}
+    return NULL;
+}
+
+
+// Truncate a string to the specified number of UTF-8 characters
+// and adds "..." to the end
+FXString truncLine(FXString str, FXuint maxlinesize)
+{
+	if (str.count() <= (int)maxlinesize)
+		return str;
+		
+	return str.trunc(str.validate(maxlinesize)) + "...";
+}
+
+
+// Insert line breaks as needed to allow displaying string using lines
+// of specified maximum number of UTF-8 characters
+FXString multiLines(FXString str, FXuint maxlinesize)
+{
+	int pos1=0;
+	int pos2;
+
+	while (1)
+	{
+		// No more line breaks found
+		pos2 = str.find('\n',pos1);
+		if (pos2 < 0)
+		{
+			int nbc = str.count(pos1,str.length());
+			if (nbc > (int)maxlinesize)
+			{
+				int nbl = nbc/maxlinesize;
+				for (int n=1; n<=nbl; n++)
+				{
+					str.insert(str.validate(pos1+n*maxlinesize),'\n'); // Use a valid UTF-8 position
+				}
+			}
+			
+			break;	
+		}
+		
+		// Line break found
+		else
+		{
+			int nbc = str.count(pos1,pos2);		
+			if (nbc > (int)maxlinesize)
+			{
+				int nbl = nbc/maxlinesize;
+				for (int n=1; n<=nbl; n++)
+				{
+					str.insert(str.validate(pos1+n*maxlinesize),'\n'); // Use a valid UTF-8 position
+					pos2++;
+				}
+			}		
+			pos1=pos2 + 1;
+		}
+	}
+
+	return str;
+}
