@@ -20,6 +20,10 @@ extern FXStringDict* updevices;
 #endif
 
 
+// Vector of strings
+typedef std::vector<FXString> vector_FXString;
+
+
 // Single click types
 enum
 {
@@ -38,17 +42,42 @@ enum
 };
 
 
-// Note : some inline functions must be declared in the header file or it won't compile!
+// Indexes of default programs
+enum
+{
+	NONE			= 0,
+	TXTVIEWER		= 1,
+	TXTEDITOR		= 2,
+	IMGVIEWER		= 3,
+	IMGEDITOR		= 4,
+	PDFVIEWER		= 5,
+	AUDIOPLAYER		= 6,
+	VIDEOPLAYER		= 7,
+	ARCHIVER		= 8,
+};
+
+
+// Start directory modes
+enum
+{
+	START_HOMEDIR		= 0,
+	START_CURRENTDIR 	= 1,
+	START_LASTDIR 		= 2,
+	
+};
+
+
+// Note : some inline functions must be declared in the header file or they won't compile!
 
 // Convert a character to lower case
-inline int toLower(int c)
+static inline int toLower(int c)
 {
 	return ('A' <= c && c <= 'Z' ? c + 32 : c);
 }
 
 
 // To test if two strings are equal (strcmp replacement, thanks to Francesco Abbate)
-inline int streq(const char*a, const char*b)
+static inline int streq(const char*a, const char*b)
 {
 	if (a == NULL || b == NULL)
 		return 0;
@@ -57,18 +86,18 @@ inline int streq(const char*a, const char*b)
 
 
 // Convert a string to lower cases and returns the string size
-inline void strlow (char* str)
+static inline void strlow (char* str)
 {
     while (*str)
     {
-        *str = toLower( *str );
+        *str = ::toLower( *str );
         ++str;
     }
 } 
 
 
 // Replacement of the stat function
-inline int statrep(const char* filename, struct stat* buf)
+static inline int statrep(const char* filename, struct stat* buf)
 {
 #if defined(linux)
 
@@ -84,8 +113,8 @@ inline int statrep(const char* filename, struct stat* buf)
 		// Mount point is up
 		else
 		{
-			ret=stat(filename,buf);
-			if (ret==-1)
+			ret=stat(filename,buf);	
+			if (ret==-1 && errno != EACCES)
 			{
 				updevices->remove(filename);
 				updevices->insert(filename,"down");
@@ -102,7 +131,7 @@ inline int statrep(const char* filename, struct stat* buf)
 
 
 // Replacement of the lstat function
-inline int lstatrep(const char* filename, struct stat* buf)
+static inline int lstatrep(const char* filename, struct stat* buf)
 {
 #if defined(linux)
 
@@ -119,7 +148,7 @@ inline int lstatrep(const char* filename, struct stat* buf)
 		else
 		{
 			ret=lstat(filename,buf);		
-			if (ret==-1)
+			if (ret==-1 && errno != EACCES)
 			{
 				updevices->remove(filename);
 				updevices->insert(filename,"down");
@@ -159,6 +188,7 @@ FXString filePath(const FXString);
 FXString filePath(const FXString, const FXString);
 FXString fileFromURI(FXString);
 FXString fileToURI(const FXString&);
+FXString buildCopyName(const FXString&);
 FXlong deltime(FXString);
 int isEmptyDir(const FXString);
 int hasSubDirs(const FXString);
@@ -176,6 +206,10 @@ FXString readLink(const FXString&);
 FXbool identical(const FXString& ,const FXString&);
 int setWaitCursor(FXApp*, FXuint);
 int runinxvt(FXString);
+FXString getCommandOutput(FXString);
+FXIcon* loadiconfile(FXApp*, const FXString, const FXString);
+FXString truncLine(FXString, FXuint);
+FXString multiLines(FXString, FXuint);
 
 #endif
 
