@@ -38,11 +38,7 @@
 #include <signal.h>
 #include <fcntl.h>
 #include <sys/param.h>
-#if __FreeBSD_version >= 900007
-#    include <utmpx.h>
-#else
-#    include <utmp.h>
-#endif
+#include <utmp.h>
 #include <grp.h>
 #include <pwd.h>
 #include <errno.h>
@@ -144,6 +140,7 @@
 #include <pty.h>
 #define BSD_PTY
 #define SVR4_UTMP
+#define SCTTY_IOCTL
 #endif /* KFREEBSD */
 
 /* GNU HURD */
@@ -214,10 +211,12 @@ static void write_utmp()
     struct passwd *pw;
 
 #ifdef SVR4_UTMP
+    setutent();
     memset(&utent,0,sizeof(utent));
     utent.ut_type = USER_PROCESS;
     strncpy(utent.ut_id,tty_name + 8,sizeof(utent.ut_id));
     strncpy(utent.ut_line,tty_name + 5,sizeof(utent.ut_line));
+    utent.ut_pid = comm_pid;
     pw = getpwuid(getuid());
     if (pw != NULL)
         strncpy(utent.ut_name,pw->pw_name,sizeof(utent.ut_name));
@@ -225,6 +224,7 @@ static void write_utmp()
     time((time_t*)&utent.ut_time);
     pututline(&utent);
     endutent();
+    updwtmp(WTMP_FILE, &utent);
 #endif /* SVR4_UTMP */
 
 #ifdef SVR4_UTMPX
@@ -322,6 +322,7 @@ static void tidy_utmp()
     utent.ut_type = DEAD_PROCESS;
     time((time_t*)&utent.ut_time);
     pututline(&utent);
+    logwtmp(utent.ut_line, "", "");
 #endif /* SVR4_UTMP || SVR4_UTMPX */
 #ifdef SVR4_UTMPX
     updwtmp(WTMP_FILE,&utent);
@@ -493,11 +494,13 @@ static void set_ttymodes()
     if (!is_eightbit())
         term.c_iflag |= ISTRIP;
     term.c_oflag = OPOST | ONLCR;
-    term.c_cflag = B9600 | CREAD;
+    term.c_cflag = CREAD;
     if (!is_eightbit())
         term.c_cflag |=  PARENB | CS7;
     else
         term.c_cflag |= CS8;
+    cfsetispeed(&term, B9600);
+    cfsetospeed(&term, B9600);
     term.c_lflag = ISIG | IEXTEN | ICANON | ECHO | ECHOE | ECHOK;
 #ifdef ECHOCTL
     term.c_lflag |= ECHOCTL;
